@@ -28,7 +28,7 @@
  */
 class LMSF32Plugin : public KParts::Plugin
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     LMSF32Plugin(TQObject *parent, const char *name, const TQStringList &);
