@@ -73,7 +73,7 @@ public:
 
 
 class KisLevelConfigWidget : public KisFilterConfigWidget {
-Q_OBJECT
+TQ_OBJECT
   
 public:
     KisLevelConfigWidget(TQWidget * parent, KisPaintDeviceSP dev, const char * name = 0, WFlags f = 0 );
