@@ -44,7 +44,7 @@ public:
 };
 
 class KisSmudgeOpSettings : public TQObject, public KisPaintOpSettings {
-    Q_OBJECT
+    TQ_OBJECT
   
     typedef KisPaintOpSettings super;
 public:
