@@ -31,7 +31,7 @@ class KRITATOOL_EXPORT KisToolPan : public KisToolNonPaint
 {
 
     typedef KisToolNonPaint super;
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
