@@ -181,7 +181,7 @@ void KisToolTransform::deactivate()
 
     paintOutline();
 
-   disconnect(m_subject->currentImg().data(), TQT_SIGNAL(sigLayerActivated(KisLayerSP)), this, TQT_SLOT(slotLayerActivated(KisLayerSP)));
+   disconnect(m_subject->currentImg().data(), TQ_SIGNAL(sigLayerActivated(KisLayerSP)), this, TQ_SLOT(slotLayerActivated(KisLayerSP)));
 }
 
 void KisToolTransform::activate()
@@ -222,7 +222,7 @@ void KisToolTransform::activate()
                 initHandles();
         }
     }
-    connect(m_subject->currentImg(), TQT_SIGNAL(sigLayerActivated(KisLayerSP)), this, TQT_SLOT(slotLayerActivated(KisLayerSP)));
+    connect(m_subject->currentImg(), TQ_SIGNAL(sigLayerActivated(KisLayerSP)), this, TQ_SLOT(slotLayerActivated(KisLayerSP)));
 }
 
 void KisToolTransform::initHandles()
@@ -275,14 +275,14 @@ void KisToolTransform::paint(KisCanvasPainter& gc, const TQRect& rc)
 
 void KisToolTransform::buttonPress(KisButtonPressEvent *e)
 {
-    if (m_subject && e->button() == Qt::LeftButton) {
+    if (m_subject && e->button() == TQt::LeftButton) {
         m_wasPressed = true;
     }
 
     if (m_subject) {
         KisImageSP img = m_subject->currentImg();
 
-        if (img && img->activeDevice() && e->button() == Qt::LeftButton) {
+        if (img && img->activeDevice() && e->button() == TQt::LeftButton) {
             switch(m_function)
             {
                 case ROTATE:
@@ -646,7 +646,7 @@ void KisToolTransform::move(KisMoveEvent *e)
 
 void KisToolTransform::buttonRelease(KisButtonReleaseEvent *e)
 {
-    if (m_subject && e->button() == Qt::LeftButton) {
+    if (m_subject && e->button() == TQt::LeftButton) {
         if(!m_wasPressed) return;
         m_wasPressed = false;
 
@@ -866,17 +866,17 @@ TQWidget* KisToolTransform::createOptionWidget(TQWidget* parent)
     m_optWidget->cmbFilter->setIDList(KisFilterStrategyRegistry::instance()->listKeys());
 
     m_optWidget->cmbFilter->setCurrentText("Mitchell");
-    connect(m_optWidget->cmbFilter, TQT_SIGNAL(activated(const KisID &)),
-        this, TQT_SLOT(slotSetFilter(const KisID &)));
+    connect(m_optWidget->cmbFilter, TQ_SIGNAL(activated(const KisID &)),
+        this, TQ_SLOT(slotSetFilter(const KisID &)));
 
     KisID filterID = m_optWidget->cmbFilter->currentItem();
     m_filter = KisFilterStrategyRegistry::instance()->get(filterID);
 
 /*
-    connect(m_optWidget->intStartX, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(setStartX(int)));
-    connect(m_optWidget->intStartY, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(setStartY(int)));
-    connect(m_optWidget->intEndX, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(setEndX(int)));
-    connect(m_optWidget->intEndY, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(setEndY(int)));
+    connect(m_optWidget->intStartX, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(setStartX(int)));
+    connect(m_optWidget->intStartY, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(setStartY(int)));
+    connect(m_optWidget->intEndX, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(setEndX(int)));
+    connect(m_optWidget->intEndY, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(setEndY(int)));
 */
     m_optWidget->intStartX->hide();
     m_optWidget->intStartY->hide();
@@ -903,7 +903,7 @@ void KisToolTransform::setup(TDEActionCollection *collection)
                         "tool_transform",
                         0,
                         this,
-                        TQT_SLOT(activate()),
+                        TQ_SLOT(activate()),
                         collection,
                         name());
         TQ_CHECK_PTR(m_action);
