@@ -26,7 +26,7 @@ class KisView;
 
 class ModifySelection : public KParts::Plugin
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     ModifySelection(TQObject *parent, const char *name, const TQStringList &);
