@@ -34,7 +34,7 @@
 #include <kstandarddirs.h>
 #include <tdetempfile.h>
 
-#define KROSS_MAIN_EXPORT KDE_EXPORT
+#define KROSS_MAIN_EXPORT TDE_EXPORT
 #include <main/manager.h>
 #include <main/scriptguiclient.h>
 #include <main/wdgscriptsmanager.h>
