@@ -35,7 +35,7 @@
 class DlgSubstrate: public KDialogBase {
 
     typedef KDialogBase super;
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
