@@ -34,8 +34,7 @@ TDEAboutData * newChalkAboutData()
             TDEAboutData::License_GPL,
             I18N_NOOP("(c) 1999-2006 The Chalk team.\n"),
             "",
-            "http://www.koffice.org/chalk",
-            "submit@bugs.kde.org");
+            "bugs.trinitydesktop.org");
     aboutData->addAuthor("Adrian Page", 0, "Adrian.Page@tesco.net");
     aboutData->addAuthor("Alan Horkan", 0, "", "http://www.openclipart.org");
     aboutData->addAuthor("Bart Coppens", 0, "kde@bartcoppens.be");
