@@ -33,7 +33,7 @@ class KisColorSpace;
 
 class KisBirdEyeBox : public TQWidget
 { 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
