@@ -73,7 +73,7 @@
 #include "kis_input_device.h"
 #include "fixx11h.h"
 
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 
 #include <tqdesktopwidget.h>
 #include <tqapplication.h>
@@ -98,14 +98,14 @@ std::map<XID, KisCanvasWidget::X11TabletDevice> KisCanvasWidget::X11TabletDevice
 
 #endif // EXTENDED_X11_TABLET_SUPPORT
 
-#endif // Q_WS_X11
+#endif // TQ_WS_X11
 
 KisCanvasWidget::KisCanvasWidget()
 {
     m_enableMoveEventCompressionHint = false;
     m_lastPressure = 0;
 
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
     if (!X11SupportInitialised) {
         initX11Support();
     }
@@ -169,18 +169,18 @@ void KisCanvasWidget::widgetGotTabletEvent(TQTabletEvent *e)
     double pressure = e->pressure() / 255.0;
 
     if (e->type() == TQEvent::TabletPress) {
-        KisButtonPressEvent ke(device, KisPoint(e->pos()), KisPoint(e->globalPos()), pressure, e->xTilt(), e->yTilt(), Qt::LeftButton, Qt::NoButton);
+        KisButtonPressEvent ke(device, KisPoint(e->pos()), KisPoint(e->globalPos()), pressure, e->xTilt(), e->yTilt(), TQt::LeftButton, TQt::NoButton);
         translateTabletEvent(&ke);
     }
     else
     if (e->type() == TQEvent::TabletRelease) {
-        KisButtonReleaseEvent ke(device, KisPoint(e->pos()), KisPoint(e->globalPos()), pressure, e->xTilt(), e->yTilt(), Qt::LeftButton, Qt::NoButton);
+        KisButtonReleaseEvent ke(device, KisPoint(e->pos()), KisPoint(e->globalPos()), pressure, e->xTilt(), e->yTilt(), TQt::LeftButton, TQt::NoButton);
         translateTabletEvent(&ke);
     }
     else {
-        KisMoveEvent ke(device, KisPoint(e->pos()), KisPoint(e->globalPos()), pressure, e->xTilt(), e->yTilt(), Qt::NoButton);
+        KisMoveEvent ke(device, KisPoint(e->pos()), KisPoint(e->globalPos()), pressure, e->xTilt(), e->yTilt(), TQt::NoButton);
         translateTabletEvent(&ke);
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
         // Fix the problem that when you change from using a tablet device to the mouse,
         // the first mouse button event is not recognised. This is because we handle
         // X11 core mouse move events directly so TQt does not get to see them. This breaks
@@ -263,7 +263,7 @@ void KisCanvasWidget::translateTabletEvent(KisEvent *e)
     if (e->type() == KisEvent::ButtonPressEvent || e->type() == KisEvent::ButtonReleaseEvent) {
         KisButtonEvent *b = static_cast<KisButtonEvent *>(e);
 
-        if (b->button() == Qt::MidButton || b->button() == Qt::RightButton) {
+        if (b->button() == TQt::MidButton || b->button() == TQt::RightButton) {
 
             if (e->type() == KisEvent::ButtonPressEvent) {
                 buttonPressEvent(static_cast<KisButtonPressEvent *>(e));
@@ -277,10 +277,10 @@ void KisCanvasWidget::translateTabletEvent(KisEvent *e)
 
     // Use pressure threshold to detect 'left button' press/release
     if (e->pressure() >= PRESSURE_THRESHOLD && m_lastPressure < PRESSURE_THRESHOLD) {
-        KisButtonPressEvent ke(e->device(), e->pos(), e->globalPos(), e->pressure(), e->xTilt(), e->yTilt(), Qt::LeftButton, e->state());
+        KisButtonPressEvent ke(e->device(), e->pos(), e->globalPos(), e->pressure(), e->xTilt(), e->yTilt(), TQt::LeftButton, e->state());
         buttonPressEvent(&ke);
     } else if (e->pressure() < PRESSURE_THRESHOLD && m_lastPressure >= PRESSURE_THRESHOLD) {
-        KisButtonReleaseEvent ke(e->device(), e->pos(), e->globalPos(), e->pressure(), e->xTilt(), e->yTilt(), Qt::LeftButton, e->state());
+        KisButtonReleaseEvent ke(e->device(), e->pos(), e->globalPos(), e->pressure(), e->xTilt(), e->yTilt(), TQt::LeftButton, e->state());
         buttonReleaseEvent(&ke);
     } else {
         if (!checkThresholdOnly) {
@@ -292,7 +292,7 @@ void KisCanvasWidget::translateTabletEvent(KisEvent *e)
     m_lastPressure = e->pressure();
 }
 
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 
 void KisCanvasWidget::initX11Support()
 {
@@ -417,11 +417,11 @@ TQt::ButtonState KisCanvasWidget::translateX11ButtonState(int state)
     int buttonState = 0;
 
     if (state & Button1Mask)
-        buttonState |= Qt::LeftButton;
+        buttonState |= TQt::LeftButton;
     if (state & Button2Mask)
-        buttonState |= Qt::MidButton;
+        buttonState |= TQt::MidButton;
     if (state & Button3Mask)
-        buttonState |= Qt::RightButton;
+        buttonState |= TQt::RightButton;
     if (state & ShiftMask)
         buttonState |= TQt::ShiftButton;
     if (state & ControlMask)
@@ -440,16 +440,16 @@ TQt::ButtonState KisCanvasWidget::translateX11Button(unsigned int X11Button)
 
     switch (X11Button) {
     case Button1:
-        qtButton = Qt::LeftButton;
+        qtButton = TQt::LeftButton;
         break;
     case Button2:
-        qtButton = Qt::MidButton;
+        qtButton = TQt::MidButton;
         break;
     case Button3:
-        qtButton = Qt::RightButton;
+        qtButton = TQt::RightButton;
         break;
     default:
-        qtButton = Qt::NoButton;
+        qtButton = TQt::NoButton;
     }
 
     return qtButton;
@@ -735,7 +735,7 @@ void KisCanvasWidget::X11TabletDevice::writeSettingsToConfig()
 void KisCanvasWidget::X11TabletDevice::enableEvents(TQWidget *widget) const
 {
     if (!m_eventClassList.isEmpty()) {
-        int result = XSelectExtensionEvent(TQT_TQPAINTDEVICE(widget)->x11AppDisplay(), widget->handle(), 
+        int result = XSelectExtensionEvent(widget->x11AppDisplay(), widget->handle(), 
                                            const_cast<XEventClass*>(&m_eventClassList[0]), 
                                            m_eventClassList.count());
     
@@ -853,7 +853,7 @@ bool KisCanvasWidget::x11Event(XEvent *event, Display *x11Display, WId winId, TQ
 
                 int state = translateX11ButtonState(motion.state);
                 TQPoint pos(motion.x, motion.y);
-                TQMouseEvent e(TQEvent::MouseMove, pos, globalPos, Qt::NoButton, state);
+                TQMouseEvent e(TQEvent::MouseMove, pos, globalPos, TQt::NoButton, state);
 
                 widgetGotMouseMoveEvent(&e);
             }
@@ -911,7 +911,7 @@ bool KisCanvasWidget::x11Event(XEvent *event, Display *x11Display, WId winId, TQ
 
             deviceId = motion->deviceid;
             axisData = motion->axis_data;
-            button = Qt::NoButton;
+            button = TQt::NoButton;
             buttonState = translateX11ButtonState(motion->state);
         }
         else
@@ -1058,7 +1058,7 @@ KisInputDevice KisCanvasWidget::findActiveInputDevice()
 #endif // EXTENDED_X11_TABLET_SUPPORT
 
 
-#endif // Q_WS_X11
+#endif // TQ_WS_X11
 
 /*************************************************************************/
 
@@ -1118,18 +1118,18 @@ void KisCanvas::createCanvasWidget(bool useOpenGL)
     selectTabletDeviceEvents();
 #endif
 
-    connect(m_canvasWidget, TQT_SIGNAL(sigGotPaintEvent(TQPaintEvent *)), TQT_SIGNAL(sigGotPaintEvent(TQPaintEvent *)));
-    connect(m_canvasWidget, TQT_SIGNAL(sigGotEnterEvent(TQEvent*)), TQT_SIGNAL(sigGotEnterEvent(TQEvent*)));
-    connect(m_canvasWidget, TQT_SIGNAL(sigGotLeaveEvent(TQEvent*)), TQT_SIGNAL(sigGotLeaveEvent(TQEvent*)));
-    connect(m_canvasWidget, TQT_SIGNAL(sigGotMouseWheelEvent(TQWheelEvent*)), TQT_SIGNAL(sigGotMouseWheelEvent(TQWheelEvent*)));
-    connect(m_canvasWidget, TQT_SIGNAL(sigGotKeyPressEvent(TQKeyEvent*)), TQT_SIGNAL(sigGotKeyPressEvent(TQKeyEvent*)));
-    connect(m_canvasWidget, TQT_SIGNAL(sigGotKeyReleaseEvent(TQKeyEvent*)), TQT_SIGNAL(sigGotKeyReleaseEvent(TQKeyEvent*)));
-    connect(m_canvasWidget, TQT_SIGNAL(sigGotDragEnterEvent(TQDragEnterEvent*)), TQT_SIGNAL(sigGotDragEnterEvent(TQDragEnterEvent*)));
-    connect(m_canvasWidget, TQT_SIGNAL(sigGotDropEvent(TQDropEvent*)), TQT_SIGNAL(sigGotDropEvent(TQDropEvent*)));
-    connect(m_canvasWidget, TQT_SIGNAL(sigGotMoveEvent(KisMoveEvent *)), TQT_SIGNAL(sigGotMoveEvent(KisMoveEvent *)));
-    connect(m_canvasWidget, TQT_SIGNAL(sigGotButtonPressEvent(KisButtonPressEvent *)), TQT_SIGNAL(sigGotButtonPressEvent(KisButtonPressEvent *)));
-    connect(m_canvasWidget, TQT_SIGNAL(sigGotButtonReleaseEvent(KisButtonReleaseEvent *)), TQT_SIGNAL(sigGotButtonReleaseEvent(KisButtonReleaseEvent *)));
-    connect(m_canvasWidget, TQT_SIGNAL(sigGotDoubleClickEvent(KisDoubleClickEvent *)), TQT_SIGNAL(sigGotDoubleClickEvent(KisDoubleClickEvent *)));
+    connect(m_canvasWidget, TQ_SIGNAL(sigGotPaintEvent(TQPaintEvent *)), TQ_SIGNAL(sigGotPaintEvent(TQPaintEvent *)));
+    connect(m_canvasWidget, TQ_SIGNAL(sigGotEnterEvent(TQEvent*)), TQ_SIGNAL(sigGotEnterEvent(TQEvent*)));
+    connect(m_canvasWidget, TQ_SIGNAL(sigGotLeaveEvent(TQEvent*)), TQ_SIGNAL(sigGotLeaveEvent(TQEvent*)));
+    connect(m_canvasWidget, TQ_SIGNAL(sigGotMouseWheelEvent(TQWheelEvent*)), TQ_SIGNAL(sigGotMouseWheelEvent(TQWheelEvent*)));
+    connect(m_canvasWidget, TQ_SIGNAL(sigGotKeyPressEvent(TQKeyEvent*)), TQ_SIGNAL(sigGotKeyPressEvent(TQKeyEvent*)));
+    connect(m_canvasWidget, TQ_SIGNAL(sigGotKeyReleaseEvent(TQKeyEvent*)), TQ_SIGNAL(sigGotKeyReleaseEvent(TQKeyEvent*)));
+    connect(m_canvasWidget, TQ_SIGNAL(sigGotDragEnterEvent(TQDragEnterEvent*)), TQ_SIGNAL(sigGotDragEnterEvent(TQDragEnterEvent*)));
+    connect(m_canvasWidget, TQ_SIGNAL(sigGotDropEvent(TQDropEvent*)), TQ_SIGNAL(sigGotDropEvent(TQDropEvent*)));
+    connect(m_canvasWidget, TQ_SIGNAL(sigGotMoveEvent(KisMoveEvent *)), TQ_SIGNAL(sigGotMoveEvent(KisMoveEvent *)));
+    connect(m_canvasWidget, TQ_SIGNAL(sigGotButtonPressEvent(KisButtonPressEvent *)), TQ_SIGNAL(sigGotButtonPressEvent(KisButtonPressEvent *)));
+    connect(m_canvasWidget, TQ_SIGNAL(sigGotButtonReleaseEvent(KisButtonReleaseEvent *)), TQ_SIGNAL(sigGotButtonReleaseEvent(KisButtonReleaseEvent *)));
+    connect(m_canvasWidget, TQ_SIGNAL(sigGotDoubleClickEvent(KisDoubleClickEvent *)), TQ_SIGNAL(sigGotDoubleClickEvent(KisDoubleClickEvent *)));
 }
 
 void KisCanvas::createTQPaintDeviceCanvas()
@@ -1284,7 +1284,7 @@ void KisCanvas::updateGeometry()
     dynamic_cast<TQWidget *>(m_canvasWidget)->updateGeometry();
 }
 
-void KisCanvas::setFocusPolicy(TQ_FocusPolicy focusPolicy)
+void KisCanvas::setFocusPolicy(TQWidget::FocusPolicy focusPolicy)
 {
     Q_ASSERT(m_canvasWidget);
     dynamic_cast<TQWidget *>(m_canvasWidget)->setFocusPolicy(focusPolicy);
