@@ -105,7 +105,7 @@ KisControlFrame::KisControlFrame( TDEMainWindow * /*window*/, KisView * view, co
     TDEAction * action = new KWidgetAction(m_brushWidget,
                                          i18n("&Brush"),
                                          0,
-                                         TQT_TQOBJECT(view),
+                                         view,
                                          0,
                                          view->actionCollection(),
                                          "brushes");
@@ -116,7 +116,7 @@ KisControlFrame::KisControlFrame( TDEMainWindow * /*window*/, KisView * view, co
     action = new KWidgetAction(m_patternWidget,
                                i18n("&Patterns"),
                                0,
-                               TQT_TQOBJECT(view),
+                               view,
                                0,
                                view->actionCollection(),
                                "patterns");
@@ -126,7 +126,7 @@ KisControlFrame::KisControlFrame( TDEMainWindow * /*window*/, KisView * view, co
     action = new KWidgetAction(m_gradientWidget,
                                i18n("&Gradients"),
                                0,
-                               TQT_TQOBJECT(view),
+                               view,
                                0,
                                view->actionCollection(),
                                "gradients");
@@ -135,7 +135,7 @@ KisControlFrame::KisControlFrame( TDEMainWindow * /*window*/, KisView * view, co
     action = new KWidgetAction(m_paintopBox,
                                i18n("&Painter's Tools"),
                                0,
-                               TQT_TQOBJECT(view),
+                               view,
                                0,
                                view->actionCollection(),
                                "paintops");
@@ -230,7 +230,7 @@ void KisControlFrame::createBrushesChooser(KisView * view)
 
     KisAutobrush * m_autobrush = new KisAutobrush(m_brushesTab, "autobrush", i18n("Autobrush"));
     m_brushesTab->addTab( m_autobrush, i18n("Autobrush"));
-    connect(m_autobrush, TQT_SIGNAL(activatedResource(KisResource*)), m_view, TQT_SLOT(brushActivated( KisResource* )));
+    connect(m_autobrush, TQ_SIGNAL(activatedResource(KisResource*)), m_view, TQ_SLOT(brushActivated( KisResource* )));
 
     KisBrushChooser * m_brushChooser = new KisBrushChooser(m_brushesTab, "brush_chooser");
     m_brushesTab->addTab( m_brushChooser, i18n("Predefined Brushes"));
@@ -238,19 +238,19 @@ void KisControlFrame::createBrushesChooser(KisView * view)
     KisCustomBrush* customBrushes = new KisCustomBrush(m_brushesTab, "custombrush",
             i18n("Custom Brush"), m_view);
     m_brushesTab->addTab( customBrushes, i18n("Custom Brush"));
-    connect(customBrushes, TQT_SIGNAL(activatedResource(KisResource*)),
-            m_view, TQT_SLOT(brushActivated(KisResource*)));
+    connect(customBrushes, TQ_SIGNAL(activatedResource(KisResource*)),
+            m_view, TQ_SLOT(brushActivated(KisResource*)));
 #ifdef HAVE_TEXT_BRUSH
     KisTextBrush* textBrushes = new KisTextBrush(m_brushesTab, "textbrush",
             i18n("Text Brush")/*, m_view*/);
     m_brushesTab->addTab( textBrushes, i18n("Text Brush"));
-    connect(textBrushes, TQT_SIGNAL(activatedResource(KisResource*)),
-            m_view, TQT_SLOT(brushActivated(KisResource*)));
+    connect(textBrushes, TQ_SIGNAL(activatedResource(KisResource*)),
+            m_view, TQ_SLOT(brushActivated(KisResource*)));
 #endif
 
     m_brushChooser->setFont(m_font);
     m_brushMediator = new KisResourceMediator( m_brushChooser, this);
-    connect(m_brushMediator, TQT_SIGNAL(activatedResource(KisResource*)), m_view, TQT_SLOT(brushActivated(KisResource*)));
+    connect(m_brushMediator, TQ_SIGNAL(activatedResource(KisResource*)), m_view, TQ_SLOT(brushActivated(KisResource*)));
 
     KisResourceServerBase* rServer;
     rServer = KisResourceServerRegistry::instance()->get("ImagePipeBrushServer");
@@ -258,7 +258,7 @@ void KisControlFrame::createBrushesChooser(KisView * view)
     rServer = KisResourceServerRegistry::instance()->get("BrushServer");
     m_brushMediator->connectServer(rServer);
 
-    KisControlFrame::connect(view, TQT_SIGNAL(brushChanged(KisBrush *)), this, TQT_SLOT(slotBrushChanged( KisBrush *)));
+    KisControlFrame::connect(view, TQ_SIGNAL(brushChanged(KisBrush *)), this, TQ_SLOT(slotBrushChanged( KisBrush *)));
     m_brushChooser->setCurrent( 0 );
     m_brushMediator->setActiveItem( m_brushChooser->currentItem() );
     customBrushes->setResourceServer(rServer);
@@ -290,16 +290,16 @@ void KisControlFrame::createPatternsChooser(KisView * view)
     m_patternsTab->addTab( customPatterns, i18n("Custom Pattern"));
 
 
-    m_patternMediator = new KisResourceMediator( chooser, TQT_TQOBJECT(view));
-    connect( m_patternMediator, TQT_SIGNAL(activatedResource(KisResource*)), view, TQT_SLOT(patternActivated(KisResource*)));
-    connect(customPatterns, TQT_SIGNAL(activatedResource(KisResource*)),
-            TQT_TQOBJECT(view), TQT_SLOT(patternActivated(KisResource*)));
+    m_patternMediator = new KisResourceMediator( chooser, view);
+    connect( m_patternMediator, TQ_SIGNAL(activatedResource(KisResource*)), view, TQ_SLOT(patternActivated(KisResource*)));
+    connect(customPatterns, TQ_SIGNAL(activatedResource(KisResource*)),
+            view, TQ_SLOT(patternActivated(KisResource*)));
 
     KisResourceServerBase* rServer;
     rServer = KisResourceServerRegistry::instance()->get("PatternServer");
     m_patternMediator->connectServer(rServer);
 
-    KisControlFrame::connect(view, TQT_SIGNAL(patternChanged(KisPattern *)), this, TQT_SLOT(slotPatternChanged( KisPattern *)));
+    KisControlFrame::connect(view, TQ_SIGNAL(patternChanged(KisPattern *)), this, TQ_SLOT(slotPatternChanged( KisPattern *)));
     chooser->setCurrent( 0 );
     m_patternMediator->setActiveItem( chooser->currentItem() );
 
@@ -326,14 +326,14 @@ void KisControlFrame::createGradientsChooser(KisView * view)
     m_gradientChooser->setMinimumSize(200, 150);
     m_gradientTab->addTab( m_gradientChooser, i18n("Gradients"));
 
-    m_gradientMediator = new KisResourceMediator( m_gradientChooser, TQT_TQOBJECT(view));
-    connect(m_gradientMediator, TQT_SIGNAL(activatedResource(KisResource*)), view, TQT_SLOT(gradientActivated(KisResource*)));
+    m_gradientMediator = new KisResourceMediator( m_gradientChooser, view);
+    connect(m_gradientMediator, TQ_SIGNAL(activatedResource(KisResource*)), view, TQ_SLOT(gradientActivated(KisResource*)));
 
     KisResourceServerBase* rServer;
     rServer = KisResourceServerRegistry::instance()->get("GradientServer");
     m_gradientMediator->connectServer(rServer);
 
-    connect(view, TQT_SIGNAL(gradientChanged(KisGradient *)), this, TQT_SLOT(slotGradientChanged( KisGradient *)));
+    connect(view, TQ_SIGNAL(gradientChanged(KisGradient *)), this, TQ_SLOT(slotGradientChanged( KisGradient *)));
     m_gradientChooser->setCurrent( 0 );
     m_gradientMediator->setActiveItem( m_gradientChooser->currentItem() );
 }
