@@ -38,7 +38,7 @@ class KisDoc;
  */
 class KisImportCatcher : TQObject {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
