@@ -21,7 +21,7 @@
 #include <tqlabel.h>
 
 class KisLabelZoom : public TQLabel {
-    Q_OBJECT
+    TQ_OBJECT
   
         
     KisLabelZoom( TQWidget *parent, const char *name = 0, WFlags f = 0 ) :
