@@ -43,7 +43,7 @@ class KisCanvasSubject;
 
 class KisLayerBox : public TQFrame {
         typedef TQFrame super;
-        Q_OBJECT
+        TQ_OBJECT
   
 
 public:
