@@ -35,7 +35,7 @@ class KisResourceServerBase;
  * resource type.
  */
 class KisResourceMediator : public TQObject {
-    Q_OBJECT
+    TQ_OBJECT
   
     typedef TQObject super;
 
