@@ -35,7 +35,7 @@ class KisClipboard;
  */
 class KRITACORE_EXPORT KisSelectionManager : public TQObject {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
