@@ -22,7 +22,7 @@
 #include <KoFilter.h>
 
 class XCFImport : public KoFilter {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
