@@ -27,7 +27,7 @@ class TQStringList;
 
 class LATEXExport : public KoFilter
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     LATEXExport( KoFilter *parent, const char *name, const TQStringList& );
