@@ -27,7 +27,7 @@
 
 class ExcelImport : public KoFilter {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
