@@ -57,7 +57,7 @@ class KSpreadKexiImportDialog;
  */
 class KSpreadKexiImport : public KoFilter
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   protected:
