@@ -42,7 +42,7 @@
 
 class ABIWORDImport : public KoFilter {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
