@@ -43,7 +43,7 @@ typedef struct
 
 class APPLIXWORDImport : public KoFilter {
 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
