@@ -75,7 +75,7 @@ namespace KWord
 
 class KWordTableHandler : public TQObject, public wvWare::TableHandler
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KWordTableHandler();
