@@ -519,21 +519,21 @@ void OOWriterWorker::writeMetaXml(void)
     if (m_varSet.creationTime.isValid())
     {
         zipWriteData("  <meta:creation-date>");
-        zipWriteData(escapeOOText(m_varSet.creationTime.toString(Qt::ISODate)));
+        zipWriteData(escapeOOText(m_varSet.creationTime.toString(TQt::ISODate)));
         zipWriteData("</meta:creation-date>\n");
     }
 
     if (m_varSet.modificationTime.isValid())
     {
         zipWriteData("  <dc:date>");
-        zipWriteData(escapeOOText(m_varSet.modificationTime.toString(Qt::ISODate)));
+        zipWriteData(escapeOOText(m_varSet.modificationTime.toString(TQt::ISODate)));
         zipWriteData("</dc:date>\n");
     }
 
     if (m_varSet.printTime.isValid())
     {
         zipWriteData("  <meta:print-date>");
-        zipWriteData(escapeOOText(m_varSet.printTime.toString(Qt::ISODate)));
+        zipWriteData(escapeOOText(m_varSet.printTime.toString(TQt::ISODate)));
         zipWriteData("</meta:print-date>\n");
     }
 
@@ -1400,7 +1400,7 @@ bool OOWriterWorker::makePicture( const FrameAnchor& anchor, const AnchorType an
         TQBuffer buffer( image.copy() ); // Be more safe than sorry and do not allow shallow copy
         KoPicture pic;
         buffer.open( IO_ReadOnly );
-        if ( pic.load( TQT_TQIODEVICE(&buffer), strExtension ) )
+        if ( pic.load( &buffer, strExtension ) )
         {
             const TQSize size ( pic.getOriginalSize() );
             height = size.height();
@@ -1577,7 +1577,7 @@ void OOWriterWorker::processNote( const VariableData& variable )
     // We use the document creation date as creation date for the annotation
     // (OOWriter uses only the date part, there is no time part)
     if ( m_varSet.creationTime.isValid() )
-        *m_streamOut << escapeOOText( m_varSet.creationTime.date().toString( Qt::ISODate ) );
+        *m_streamOut << escapeOOText( m_varSet.creationTime.date().toString( TQt::ISODate ) );
     else
         *m_streamOut << "1970-01-01";
 
@@ -2217,7 +2217,7 @@ TQString OOWriterWorker::makeAutomaticStyleName(const TQString& prefix, ulong& c
         return str2;
 
     // If it is still not unique, try a time stamp.
-    const TQDateTime dt(TQDateTime::currentDateTime(Qt::UTC));
+    const TQDateTime dt(TQDateTime::currentDateTime(TQt::UTC));
 
     str2 = str + "_" + TQString::number(dt.toTime_t(),16);
     if (m_styleMap.find(str2)==m_styleMap.end())
