@@ -33,7 +33,7 @@ class VStroke;
 
 class VSmallPreview : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	VSmallPreview( TQWidget* parent = 0L, const char* name = 0L );
