@@ -29,7 +29,7 @@ class DialogUI;
 
 class CSVImportDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     enum Header
