@@ -40,7 +40,7 @@ class KChartParams;
 
 class KChartColorConfigPage : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
