@@ -33,7 +33,7 @@ class KChartParams;
 
 class KChartParameter3dConfigPage : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
