@@ -49,12 +49,11 @@ TDEAboutData* Kexi::createAboutData()
 		TDEAboutData::License_LGPL_V2,
 		I18N_NOOP(	"(c) 2002-2007, Kexi Team\n"
 					"(c) 2003-2007, OpenOffice Polska LLC\n"),
-		I18N_NOOP(	"This software is developed by Kexi Team - an international group\n"
+		I18N_NOOP(	"This software was developed by Kexi Team - an international group\n"
 					"of independent developers, with additional assistance and support\n"
-					"from the OpenOffice Polska company.\n\n"
+					"from the OpenOffice Polska company and now maintained by the TDE team.\n\n"
 					"Visit the company Home Page: http://www.openoffice.com.pl"),
-		"http://www.koffice.org/kexi",
-		"submit@bugs.kde.org"
+		"bugs.trinitydesktop.org"
 	);
 	// authors sorted by last contribution date
 	aboutData->addAuthor("Jarosław Staniek / OpenOffice Polska", I18N_NOOP("Project maintainer & developer, design, KexiDB, commercially supported version, win32 port"), "js@iidea.pl");
