@@ -79,14 +79,13 @@ namespace KexiDB
 */
 class KEXICORE_EXPORT KexiBLOBBuffer : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	private:
 		class Item;
 	public:
 		//! long integer for unique identifying blobs
-//! @todo TQt4: will be changed
 		typedef long Id_t;
 
 		//! Access to KexiBLOBBuffer singleton
