@@ -12,11 +12,11 @@
 #include "kexiuseraction.h"
 
 KexiUserAction::KexiUserAction(KexiMainWindow *win, TDEActionCollection *parent, const TQString &name, const TQString &text, const TQString &pixmap)
- : TDEAction(text, pixmap, TDEShortcut::null(), this, TQT_SLOT(execute()), parent, name.latin1())
+ : TDEAction(text, pixmap, TDEShortcut::null(), this, TQ_SLOT(execute()), parent, name.latin1())
 {
 	m_win = win;
 	m_method = 0;
-	connect(this, TQT_SIGNAL(activated()), this, TQT_SLOT(execute()));
+	connect(this, TQ_SIGNAL(activated()), this, TQ_SLOT(execute()));
 }
 
 void
