@@ -25,17 +25,17 @@
 #include <kpushbutton.h>
 #include <knuminput.h>
 #include <kcombobox.h>
-#include <klistbox.h>
+#include <tdelistbox.h>
 #include <ktextedit.h>
-#include <klistview.h>
+#include <tdelistview.h>
 #include <kprogress.h>
 #include <kiconloader.h>
 #include <kgenericfactory.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
-#include <kdeversion.h>
+#include <tdeversion.h>
 
-#if KDE_VERSION < KDE_MAKE_VERSION(3,1,9)
+#if TDE_VERSION < TDE_MAKE_VERSION(3,1,9)
 # include <tqdatetimeedit.h>
 # define KTimeWidget TQTimeEdit
 # define KDateWidget TQDateEdit
@@ -72,32 +72,32 @@ KexiPictureLabel::setProperty(const char *name, const TQVariant &value)
 	return TQLabel::setProperty(name, value);
 }
 
-Line::Line(Qt::Orientation orient, TQWidget *parent, const char *name)
+Line::Line(TQt::Orientation orient, TQWidget *parent, const char *name)
  : TQFrame(parent, name)
 {
 	setFrameShadow(Sunken);
-	if(orient ==Qt::Horizontal)
+	if(orient ==TQt::Horizontal)
 		setFrameShape(HLine);
 	else
 		setFrameShape(VLine);
 }
 
 void
-Line::setOrientation(Qt::Orientation orient)
+Line::setOrientation(TQt::Orientation orient)
 {
-	if(orient ==Qt::Horizontal)
+	if(orient ==TQt::Horizontal)
 		setFrameShape(HLine);
 	else
 		setFrameShape(VLine);
 }
 
-Qt::Orientation
+TQt::Orientation
 Line::orientation() const
 {
 	if(frameShape() == HLine)
-		return Qt::Horizontal;
+		return TQt::Horizontal;
 	else
-		return Qt::Vertical;
+		return TQt::Vertical;
 }
 
 // The factory itself
@@ -125,7 +125,7 @@ StdWidgetFactory::StdWidgetFactory(TQObject *parent, const char *, const TQStrin
 
 	KFormDesigner::WidgetInfo *wLabel = new KFormDesigner::WidgetInfo(this);
 	wLabel->setPixmap("label");
-	wLabel->setClassName(TQLABEL_OBJECT_NAME_STRING);
+	wLabel->setClassName("TQLabel");
 	wLabel->setName(i18n("Text Label"));
 	wLabel->setNamePrefix(
 		i18n("Widget name. This string will be used to name widgets of this class. It must _not_ contain white spaces and non latin1 characters.", "label"));
@@ -137,7 +137,7 @@ StdWidgetFactory::StdWidgetFactory(TQObject *parent, const char *, const TQStrin
 	wPixLabel->setClassName("KexiPictureLabel");
 	wPixLabel->setName(i18n("Picture Label"));
 //! @todo TQt designer compatibility: maybe use this class when TQLabel has a pixmap set...?
-	//wPixLabel->addAlternateClassName(TQLABEL_OBJECT_NAME_STRING);
+	//wPixLabel->addAlternateClassName("TQLabel");
 	wPixLabel->setSavingName("KexiPictureLabel");
 	wPixLabel->setNamePrefix(
 		i18n("Widget name. This string will be used to name widgets of this class. It must _not_ contain white spaces and non latin1 characters.", "picture"));
@@ -147,7 +147,7 @@ StdWidgetFactory::StdWidgetFactory(TQObject *parent, const char *, const TQStrin
 	KFormDesigner::WidgetInfo *wLineEdit = new KFormDesigner::WidgetInfo(this);
 	wLineEdit->setPixmap("lineedit");
 	wLineEdit->setClassName("KLineEdit");
-	wLineEdit->addAlternateClassName(TQLINEEDIT_OBJECT_NAME_STRING);
+	wLineEdit->addAlternateClassName("TQLineEdit");
 	wLineEdit->setIncludeFileName("klineedit.h");
 	wLineEdit->setName(i18n("Line Edit"));
 	wLineEdit->setNamePrefix(
@@ -167,7 +167,7 @@ StdWidgetFactory::StdWidgetFactory(TQObject *parent, const char *, const TQStrin
 	KFormDesigner::WidgetInfo *wPushButton = new KFormDesigner::WidgetInfo(this);
 	wPushButton->setPixmap("button");
 	wPushButton->setClassName("KPushButton");
-	wPushButton->addAlternateClassName(TQPUSHBUTTON_OBJECT_NAME_STRING);
+	wPushButton->addAlternateClassName("TQPushButton");
 	wPushButton->setIncludeFileName("kpushbutton.h");
 	wPushButton->setName(i18n("Push Button"));
 	wPushButton->setNamePrefix(
@@ -177,7 +177,7 @@ StdWidgetFactory::StdWidgetFactory(TQObject *parent, const char *, const TQStrin
 
 	KFormDesigner::WidgetInfo *wRadioButton = new KFormDesigner::WidgetInfo(this);
 	wRadioButton->setPixmap("radio");
-	wRadioButton->setClassName(TQRADIOBUTTON_OBJECT_NAME_STRING);
+	wRadioButton->setClassName("TQRadioButton");
 	wRadioButton->setName(i18n("Option Button"));
 	wRadioButton->setNamePrefix(
 		i18n("Widget name. This string will be used to name widgets of this class. It must _not_ contain white spaces and non latin1 characters.", "optionButton"));
@@ -186,7 +186,7 @@ StdWidgetFactory::StdWidgetFactory(TQObject *parent, const char *, const TQStrin
 
 	KFormDesigner::WidgetInfo *wCheckBox = new KFormDesigner::WidgetInfo(this);
 	wCheckBox->setPixmap("check");
-	wCheckBox->setClassName(TQCHECKBOX_OBJECT_NAME_STRING);
+	wCheckBox->setClassName("TQCheckBox");
 	wCheckBox->setName(i18n("Check Box"));
 	wCheckBox->setNamePrefix(
 		i18n("Widget name. This string will be used to name widgets of this class. It must _not_ contain white spaces and non latin1 characters.", "checkBox"));
@@ -196,7 +196,7 @@ StdWidgetFactory::StdWidgetFactory(TQObject *parent, const char *, const TQStrin
 	KFormDesigner::WidgetInfo *wSpinBox = new KFormDesigner::WidgetInfo(this);
 	wSpinBox->setPixmap("spin");
 	wSpinBox->setClassName("KIntSpinBox");
-	wSpinBox->addAlternateClassName(TQSPINBOX_OBJECT_NAME_STRING);
+	wSpinBox->addAlternateClassName("TQSpinBox");
 	wSpinBox->setIncludeFileName("knuminput.h");
 	wSpinBox->setName(i18n("Spin Box"));
 	wSpinBox->setNamePrefix(
@@ -207,7 +207,7 @@ StdWidgetFactory::StdWidgetFactory(TQObject *parent, const char *, const TQStrin
 	KFormDesigner::WidgetInfo *wComboBox = new KFormDesigner::WidgetInfo(this);
 	wComboBox->setPixmap("combo");
 	wComboBox->setClassName("KComboBox");
-	wComboBox->addAlternateClassName(TQCOMBOBOX_OBJECT_NAME_STRING);
+	wComboBox->addAlternateClassName("TQComboBox");
 	wComboBox->setIncludeFileName("kcombobox.h");
 	wComboBox->setName(i18n("Combo Box"));
 	wComboBox->setNamePrefix(
@@ -217,9 +217,9 @@ StdWidgetFactory::StdWidgetFactory(TQObject *parent, const char *, const TQStrin
 
 	KFormDesigner::WidgetInfo *wListBox = new KFormDesigner::WidgetInfo(this);
 	wListBox->setPixmap("listbox");
-	wListBox->setClassName("KListBox");
-	wListBox->addAlternateClassName(TQLISTBOX_OBJECT_NAME_STRING);
-	wListBox->setIncludeFileName("klistbox.h");
+	wListBox->setClassName("TDEListBox");
+	wListBox->addAlternateClassName("TQListBox");
+	wListBox->setIncludeFileName("tdelistbox.h");
 	wListBox->setName(i18n("List Box"));
 	wListBox->setNamePrefix(
 		i18n("Widget name. This string will be used to name widgets of this class. It must _not_ contain white spaces and non latin1 characters.", "listBox"));
@@ -229,7 +229,7 @@ StdWidgetFactory::StdWidgetFactory(TQObject *parent, const char *, const TQStrin
 	KFormDesigner::WidgetInfo *wTextEdit = new KFormDesigner::WidgetInfo(this);
 	wTextEdit->setPixmap("textedit");
 	wTextEdit->setClassName("KTextEdit");
-	wTextEdit->addAlternateClassName(TQTEXTEDIT_OBJECT_NAME_STRING);
+	wTextEdit->addAlternateClassName("TQTextEdit");
 	wTextEdit->setIncludeFileName("ktextedit.h");
 	wTextEdit->setName(i18n("Text Editor"));
 	wTextEdit->setNamePrefix(
@@ -239,9 +239,9 @@ StdWidgetFactory::StdWidgetFactory(TQObject *parent, const char *, const TQStrin
 
 	KFormDesigner::WidgetInfo *wListView = new KFormDesigner::WidgetInfo(this);
 	wListView->setPixmap("listview");
-	wListView->setClassName("KListView");
-	wListView->addAlternateClassName(TQLISTVIEW_OBJECT_NAME_STRING);
-	wListView->setIncludeFileName("klistview.h");
+	wListView->setClassName("TDEListView");
+	wListView->addAlternateClassName("TQListView");
+	wListView->setIncludeFileName("tdelistview.h");
 	wListView->setName(i18n("List View"));
 	wListView->setNamePrefix(
 		i18n("Widget name. This string will be used to name widgets of this class. It must _not_ contain white spaces and non latin1 characters.", "listView"));
@@ -250,7 +250,7 @@ StdWidgetFactory::StdWidgetFactory(TQObject *parent, const char *, const TQStrin
 
 	KFormDesigner::WidgetInfo *wSlider = new KFormDesigner::WidgetInfo(this);
 	wSlider->setPixmap("slider");
-	wSlider->setClassName(TQSLIDER_OBJECT_NAME_STRING);
+	wSlider->setClassName("TQSlider");
 	wSlider->setName(i18n("Slider"));
 	wSlider->setNamePrefix(
 		i18n("Widget name. This string will be used to name widgets of this class. It must _not_ contain white spaces and non latin1 characters.", "slider"));
@@ -260,7 +260,7 @@ StdWidgetFactory::StdWidgetFactory(TQObject *parent, const char *, const TQStrin
 	KFormDesigner::WidgetInfo *wProgressBar = new KFormDesigner::WidgetInfo(this);
 	wProgressBar->setPixmap("progress");
 	wProgressBar->setClassName("KProgress");
-	wProgressBar->addAlternateClassName(TQPROGRESSBAR_OBJECT_NAME_STRING);
+	wProgressBar->addAlternateClassName("TQProgressBar");
 	wProgressBar->setIncludeFileName("kprogress.h");
 	wProgressBar->setName(i18n("Progress Bar"));
 	wProgressBar->setNamePrefix(
@@ -280,8 +280,8 @@ StdWidgetFactory::StdWidgetFactory(TQObject *parent, const char *, const TQStrin
 	KFormDesigner::WidgetInfo *wDate = new KFormDesigner::WidgetInfo(this);
 	wDate->setPixmap("dateedit");
 	wDate->setClassName("KDateWidget");
-#if KDE_VERSION >= KDE_MAKE_VERSION(3,1,9)
-	wDate->addAlternateClassName(TQDATEEDIT_OBJECT_NAME_STRING);
+#if TDE_VERSION >= TDE_MAKE_VERSION(3,1,9)
+	wDate->addAlternateClassName("TQDateEdit");
 	wDate->setIncludeFileName("kdatewidget.h");
 #endif
 	wDate->setName(i18n("Date Widget"));
@@ -293,8 +293,8 @@ StdWidgetFactory::StdWidgetFactory(TQObject *parent, const char *, const TQStrin
 	KFormDesigner::WidgetInfo *wTime = new KFormDesigner::WidgetInfo(this);
 	wTime->setPixmap("timeedit");
 	wTime->setClassName("KTimeWidget");
-#if KDE_VERSION >= KDE_MAKE_VERSION(3,1,9)
-	wTime->addAlternateClassName(TQTIMEEDIT_OBJECT_NAME_STRING);
+#if TDE_VERSION >= TDE_MAKE_VERSION(3,1,9)
+	wTime->addAlternateClassName("TQTimeEdit");
 	wTime->setIncludeFileName("ktimewidget.h");
 #endif
 	wTime->setName(i18n("Time Widget"));
@@ -306,8 +306,8 @@ StdWidgetFactory::StdWidgetFactory(TQObject *parent, const char *, const TQStrin
 	KFormDesigner::WidgetInfo *wDateTime = new KFormDesigner::WidgetInfo(this);
 	wDateTime->setPixmap("datetimeedit");
 	wDateTime->setClassName("KDateTimeWidget");
-#if KDE_VERSION >= KDE_MAKE_VERSION(3,1,9)
-	wDateTime->addAlternateClassName(TQDATETIMEEDIT_OBJECT_NAME_STRING);
+#if TDE_VERSION >= TDE_MAKE_VERSION(3,1,9)
+	wDateTime->addAlternateClassName("TQDateTimeEdit");
 	wDateTime->setIncludeFileName("kdatetimewidget.h");
 #endif
 	wDateTime->setName(i18n("Date/Time Widget"));
@@ -385,10 +385,10 @@ StdWidgetFactory::createWidget(const TQCString &c, TQWidget *p, const char *n,
 	TQString text( container->form()->library()->textForWidgetName(n, c) );
 	const bool designMode = options & KFormDesigner::WidgetFactory::DesignViewMode;
 
-	if(c == TQLABEL_OBJECT_NAME_STRING)
+	if(c == "TQLabel")
 		w = new TQLabel(text, p, n);
 	else if(c == "KexiPictureLabel")
-		w = new KexiPictureLabel(DesktopIcon("image"), p, n);
+		w = new KexiPictureLabel(DesktopIcon("image-x-generic"), p, n);
 
 	else if(c == "KLineEdit")
 	{
@@ -399,10 +399,10 @@ StdWidgetFactory::createWidget(const TQCString &c, TQWidget *p, const char *n,
 	else if(c == "KPushButton")
 		w = new KPushButton(/*i18n("Button")*/text, p, n);
 
-	else if(c == TQRADIOBUTTON_OBJECT_NAME_STRING)
+	else if(c == "TQRadioButton")
 		w = new TQRadioButton(/*i18n("Radio Button")*/text, p, n);
 
-	else if(c == TQCHECKBOX_OBJECT_NAME_STRING)
+	else if(c == "TQCheckBox")
 		w = new TQCheckBox(/*i18n("Check Box")*/text, p, n);
 
 	else if(c == "KIntSpinBox")
@@ -411,21 +411,21 @@ StdWidgetFactory::createWidget(const TQCString &c, TQWidget *p, const char *n,
 	else if(c == "KComboBox")
 		w = new KComboBox(p, n);
 
-	else if(c == "KListBox")
-		w = new KListBox(p, n);
+	else if(c == "TDEListBox")
+		w = new TDEListBox(p, n);
 
 	else if(c == "KTextEdit")
 		w = new KTextEdit(/*i18n("Enter your text here")*/text, TQString(), p, n);
 
-	else if(c == "KListView")
+	else if(c == "TDEListView")
 	{
-		w = new KListView(p, n);
+		w = new TDEListView(p, n);
 		if(container->form()->interactiveMode())
-			((KListView*)w)->addColumn(i18n("Column 1"));
-		((KListView*)w)->setRootIsDecorated(true);
+			((TDEListView*)w)->addColumn(i18n("Column 1"));
+		((TDEListView*)w)->setRootIsDecorated(true);
 	}
-	else if(c == TQSLIDER_OBJECT_NAME_STRING)
-		w = new TQSlider(Qt::Horizontal, p, n);
+	else if(c == "TQSlider")
+		w = new TQSlider(TQt::Horizontal, p, n);
 
 	else if(c == "KProgress")
 		w = new KProgress(p, n);
@@ -440,13 +440,13 @@ StdWidgetFactory::createWidget(const TQCString &c, TQWidget *p, const char *n,
 		w = new KDateTimeWidget(TQDateTime::currentDateTime(), p, n);
 
 	else if(c == "Line")
-		w = new Line(options & WidgetFactory::VerticalOrientation ? Qt::Vertical : Qt::Horizontal, p, n);
+		w = new Line(options & WidgetFactory::VerticalOrientation ? TQt::Vertical : TQt::Horizontal, p, n);
 
 	else if(c == "Spring") {
 		w = new Spring(p, n);
 		if (0 == (options & WidgetFactory::AnyOrientation))
 			static_cast<Spring*>(w)->setOrientation(
-				(options & WidgetFactory::VerticalOrientation) ? Qt::Vertical : Qt::Horizontal);
+				(options & WidgetFactory::VerticalOrientation) ? TQt::Vertical : TQt::Horizontal);
 	}
 
 	if(w)
@@ -470,14 +470,14 @@ bool
 StdWidgetFactory::createMenuActions(const TQCString &classname, TQWidget *, TQPopupMenu *menu,
 	KFormDesigner::Container *)
 {
-	if((classname == TQLABEL_OBJECT_NAME_STRING) || (classname == "KTextEdit"))
+	if((classname == "TQLabel") || (classname == "KTextEdit"))
 	{
-		menu->insertItem(SmallIconSet("edit"), i18n("Edit Rich Text"), this, TQT_SLOT(editText()));
+		menu->insertItem(SmallIconSet("edit"), i18n("Edit Rich Text"), this, TQ_SLOT(editText()));
 		return true;
 	}
-	else if(classname == "KListView")
+	else if(classname == "TDEListView")
 	{
-		menu->insertItem(SmallIconSet("edit"), i18n("Edit Listview Contents"), this, TQT_SLOT(editListContents()));
+		menu->insertItem(SmallIconSet("edit"), i18n("Edit Listview Contents"), this, TQ_SLOT(editListContents()));
 		return true;
 	}
 
@@ -495,7 +495,7 @@ StdWidgetFactory::startEditing(const TQCString &classname, TQWidget *w, KFormDes
 		createEditor(classname, lineedit->text(), lineedit, container, lineedit->geometry(), lineedit->alignment(), true);
 		return true;
 	}
-	else if(classname == TQLABEL_OBJECT_NAME_STRING)
+	else if(classname == "TQLabel")
 	{
 		TQLabel *label = static_cast<TQLabel*>(w);
 		if(label->textFormat() == RichText)
@@ -520,7 +520,7 @@ StdWidgetFactory::startEditing(const TQCString &classname, TQWidget *w, KFormDes
 		createEditor(classname, push->text(), push, container, editorRect, TQt::AlignCenter, false, false, TQt::PaletteButton);
 		return true;
 	}
-	else if(classname == TQRADIOBUTTON_OBJECT_NAME_STRING)
+	else if(classname == "TQRadioButton")
 	{
 		TQRadioButton *radio = static_cast<TQRadioButton*>(w);
 		TQRect r = w->style().subRect(TQStyle::SR_RadioButtonContents, w);
@@ -528,7 +528,7 @@ StdWidgetFactory::startEditing(const TQCString &classname, TQWidget *w, KFormDes
 		createEditor(classname, radio->text(), radio, container, editorRect, TQt::AlignAuto);
 		return true;
 	}
-	else if(classname == TQCHECKBOX_OBJECT_NAME_STRING)
+	else if(classname == "TQCheckBox")
 	{
 		TQCheckBox *check = static_cast<TQCheckBox*>(w);
 		//TQRect r(check->geometry());
@@ -538,12 +538,12 @@ StdWidgetFactory::startEditing(const TQCString &classname, TQWidget *w, KFormDes
 		createEditor(classname, check->text(), check, container, editorRect, TQt::AlignAuto);
 		return true;
 	}
-	else if((classname == "KComboBox") || (classname == "KListBox"))
+	else if((classname == "KComboBox") || (classname == "TDEListBox"))
 	{
 		TQStringList list;
-		if(classname == "KListBox")
+		if(classname == "TDEListBox")
 		{
-			KListBox *listbox = (KListBox*)w;
+			TDEListBox *listbox = (TDEListBox*)w;
 			for(uint i=0; i < listbox->count(); i++)
 				list.append(listbox->text(i));
 		}
@@ -556,10 +556,10 @@ StdWidgetFactory::startEditing(const TQCString &classname, TQWidget *w, KFormDes
 
 		if(editList(w, list))
 		{
-			if(classname == "KListBox")
+			if(classname == "TDEListBox")
 			{
-				((KListBox*)w)->clear();
-				((KListBox*)w)->insertStringList(list);
+				((TDEListBox*)w)->clear();
+				((TDEListBox*)w)->insertStringList(list);
 			}
 			else if(classname == "KComboBox")
 			{
@@ -582,10 +582,10 @@ StdWidgetFactory::clearWidgetContent(const TQCString &classname, TQWidget *w)
 {
 	if(classname == "KLineEdit")
 		((KLineEdit*)w)->clear();
-	else if(classname == "KListBox")
-		((KListBox*)w)->clear();
-	else if(classname == "KListView")
-		((KListView*)w)->clear();
+	else if(classname == "TDEListBox")
+		((TDEListBox*)w)->clear();
+	else if(classname == "TDEListView")
+		((TDEListView*)w)->clear();
 	else if(classname == "KComboBox")
 		((KComboBox*)w)->clear();
 	else if(classname == "KTextEdit")
@@ -609,7 +609,7 @@ StdWidgetFactory::changeText(const TQString &text)
 	TQFontMetrics fm = w->fontMetrics();
 	TQSize s(fm.width( text ), fm.height());
 	int width;
-	if(n == TQLABEL_OBJECT_NAME_STRING) // labels are resized to fit the text
+	if(n == "TQLabel") // labels are resized to fit the text
 	{
 		w->resize(w->sizeHint());
 		WidgetFactory::m_editor->resize(w->size());
@@ -618,9 +618,9 @@ StdWidgetFactory::changeText(const TQString &text)
 	// and other widgets are just enlarged if needed
 	else if(n == "KPushButton")
 		width = w->style().sizeFromContents( TQStyle::CT_PushButton, w, s).width();
-	else if(n == TQCHECKBOX_OBJECT_NAME_STRING)
+	else if(n == "TQCheckBox")
 		width = w->style().sizeFromContents( TQStyle::CT_CheckBox, w, s).width();
-	else if(n == TQRADIOBUTTON_OBJECT_NAME_STRING)
+	else if(n == "TQRadioButton")
 		width = w->style().sizeFromContents( TQStyle::CT_RadioButton, w, s).width();
 	else
 		return;
@@ -643,13 +643,13 @@ StdWidgetFactory::resizeEditor(TQWidget *editor, TQWidget *widget, const TQCStri
 	TQPoint p = widget->pos();
 	TQRect r;
 
-	if(classname == TQRADIOBUTTON_OBJECT_NAME_STRING)
+	if(classname == "TQRadioButton")
 	{
 		r = widget->style().subRect(TQStyle::SR_RadioButtonContents, widget);
 		p += r.topLeft();
 		s.setWidth(r.width());
 	}
-	else if(classname == TQCHECKBOX_OBJECT_NAME_STRING)
+	else if(classname == "TQCheckBox")
 	{
 		r = widget->style().subRect(TQStyle::SR_CheckBoxContents, widget);
 		p += r.topLeft();
@@ -680,9 +680,9 @@ StdWidgetFactory::saveSpecialProperty(const TQCString &classname, const TQString
 		}
 		return true;
 	}
-	else if(name == "list_items" && classname == "KListBox")
+	else if(name == "list_items" && classname == "TDEListBox")
 	{
-		KListBox *listbox = (KListBox*)w;
+		TDEListBox *listbox = (TDEListBox*)w;
 		for(uint i=0; i < listbox->count(); i++)
 		{
 			TQDomElement item = domDoc.createElement("item");
@@ -691,9 +691,9 @@ StdWidgetFactory::saveSpecialProperty(const TQCString &classname, const TQString
 		}
 		return true;
 	}
-	else if(name == "list_contents" && classname == "KListView")
+	else if(name == "list_contents" && classname == "TDEListView")
 	{
-		KListView *listview = (KListView*)w;
+		TDEListView *listview = (TDEListView*)w;
 		// First we save the columns
 		for(int i = 0; i < listview->columns(); i++)
 		{
@@ -747,7 +747,7 @@ StdWidgetFactory::readSpecialProperty(const TQCString &classname, TQDomElement &
 	if((tag == "item") && (classname == "KComboBox"))
 	{
 		KComboBox *combo = (KComboBox*)w;
-		TQVariant val = KFormDesigner::FormIO::readPropertyValue(node.firstChild().firstChild(), TQT_TQOBJECT(w), name);
+		TQVariant val = KFormDesigner::FormIO::readPropertyValue(node.firstChild().firstChild(), w, name);
 		if(val.canCast(TQVariant::Pixmap))
 			combo->insertItem(val.toPixmap());
 		else
@@ -755,10 +755,10 @@ StdWidgetFactory::readSpecialProperty(const TQCString &classname, TQDomElement &
 		return true;
 	}
 
-	if((tag == "item") && (classname == "KListBox"))
+	if((tag == "item") && (classname == "TDEListBox"))
 	{
-		KListBox *listbox = (KListBox*)w;
-		TQVariant val = KFormDesigner::FormIO::readPropertyValue(node.firstChild().firstChild(), TQT_TQOBJECT(w), name);
+		TDEListBox *listbox = (TDEListBox*)w;
+		TQVariant val = KFormDesigner::FormIO::readPropertyValue(node.firstChild().firstChild(), w, name);
 		if(val.canCast(TQVariant::Pixmap))
 			listbox->insertItem(val.toPixmap());
 		else
@@ -766,14 +766,14 @@ StdWidgetFactory::readSpecialProperty(const TQCString &classname, TQDomElement &
 		return true;
 	}
 
-	if((tag == "column") && (classname == "KListView"))
+	if((tag == "column") && (classname == "TDEListView"))
 	{
-		KListView *listview = (KListView*)w;
+		TDEListView *listview = (TDEListView*)w;
 		int id=0;
 		for(TQDomNode n = node.firstChild(); !n.isNull(); n = n.nextSibling())
 		{
 			TQString prop = n.toElement().attribute("name");
-			TQVariant val = KFormDesigner::FormIO::readPropertyValue(n.firstChild(), TQT_TQOBJECT(w), name);
+			TQVariant val = KFormDesigner::FormIO::readPropertyValue(n.firstChild(), w, name);
 			if(prop == "text")
 				id = listview->addColumn(val.toString());
 			else if(prop == "width")
@@ -787,9 +787,9 @@ StdWidgetFactory::readSpecialProperty(const TQCString &classname, TQDomElement &
 		}
 		return true;
 	}
-	else if((tag == "item") && (classname == "KListView"))
+	else if((tag == "item") && (classname == "TDEListView"))
 	{
-		KListView *listview = (KListView*)w;
+		TDEListView *listview = (TDEListView*)w;
 		readListItem(node, 0, listview);
 		return true;
 	}
@@ -798,13 +798,13 @@ StdWidgetFactory::readSpecialProperty(const TQCString &classname, TQDomElement &
 }
 
 void
-StdWidgetFactory::readListItem(TQDomElement &node, TQListViewItem *parent, KListView *listview)
+StdWidgetFactory::readListItem(TQDomElement &node, TQListViewItem *parent, TDEListView *listview)
 {
 	TQListViewItem *item;
 	if(parent)
-		item = new KListViewItem(parent);
+		item = new TDEListViewItem(parent);
 	else
-		item = new KListViewItem(listview);
+		item = new TDEListViewItem(listview);
 
 	// We need to move the item at the end of the list
 	TQListViewItem *last;
@@ -833,7 +833,7 @@ StdWidgetFactory::readListItem(TQDomElement &node, TQListViewItem *parent, KList
 		// and column texts
 		else if((tag == "property") && (prop == "text"))
 		{
-			TQVariant val = KFormDesigner::FormIO::readPropertyValue(n.firstChild(), TQT_TQOBJECT(listview), "item");
+			TQVariant val = KFormDesigner::FormIO::readPropertyValue(n.firstChild(), listview, "item");
 			item->setText(i, val.toString());
 			i++;
 		}
@@ -863,7 +863,7 @@ StdWidgetFactory::isPropertyVisibleInternal(const TQCString &classname,
 		if((property == "text") || (property == "indent") || (property == "textFormat") || (property == "font") || (property == "alignment"))
 			return false;
 	}
-	else if(classname == TQLABEL_OBJECT_NAME_STRING)
+	else if(classname == "TQLabel")
 	{
 		if(property == "pixmap")
 			return false;
@@ -890,11 +890,11 @@ StdWidgetFactory::isPropertyVisibleInternal(const TQCString &classname,
 		if((property == "frameShape") || (property == "font") || (property == "margin"))
 			return false;
 	}
-	else if(classname==TQCHECKBOX_OBJECT_NAME_STRING)
+	else if(classname=="TQCheckBox")
 	{
 		ok = m_showAdvancedProperties || (property != "autoRepeat");
 	}
-	else if(classname==TQRADIOBUTTON_OBJECT_NAME_STRING)
+	else if(classname=="TQRadioButton")
 	{
 		ok = m_showAdvancedProperties || (property != "autoRepeat");
 	}
@@ -911,7 +911,7 @@ StdWidgetFactory::autoSaveProperties(const TQCString &classname)
 {
 	TQValueList<TQCString> l;
 
-	if(classname == TQLABEL_OBJECT_NAME_STRING)
+	if(classname == "TQLabel")
 		l << "text";
 	if(classname == "KPushButton")
 		l << "text";
@@ -919,9 +919,9 @@ StdWidgetFactory::autoSaveProperties(const TQCString &classname)
 		l << "pixmap";
 	else if(classname == "KComboBox")
 		l << "list_items";
-	else if(classname == "KListBox")
+	else if(classname == "TDEListBox")
 		l << "list_items";
-	else if(classname == "KListView")
+	else if(classname == "TDEListView")
 		l << "list_contents";
 	else if(classname == "Line")
 		l << "orientation";
@@ -946,7 +946,7 @@ StdWidgetFactory::editText()
 	TQString text;
 	if(classname == "KTextEdit")
 		text = ((KTextEdit*)widget())->text();
-	else if(classname == TQLABEL_OBJECT_NAME_STRING)
+	else if(classname == "TQLabel")
 		text = ((TQLabel*)widget())->text();
 
 	if(editRichText(widget(), text))
@@ -955,14 +955,14 @@ StdWidgetFactory::editText()
 		changeProperty("text", text, m_container->form());
 	}
 
-	if(classname == TQLABEL_OBJECT_NAME_STRING)
+	if(classname == "TQLabel")
 		widget()->resize(widget()->sizeHint());
 }
 
 void
 StdWidgetFactory::editListContents()
 {
-	if(widget()->inherits(TQLISTVIEW_OBJECT_NAME_STRING))
+	if(widget()->inherits("TQListView"))
 		editListView((TQListView*)widget());
 }
 
