@@ -34,7 +34,7 @@ class WidgetInfo;
  */
 class KFORMEDITOR_EXPORT LibActionWidget : public TDEToggleAction
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		/** LibActionWidget object is initialized to be mutually
