@@ -51,24 +51,24 @@ TabStopDialog::TabStopDialog(TQWidget *parent)
 	l->addWidget(m_treeview, 0, 0);
 
 	m_treeview->m_form = 0;
-	connect(m_treeview, TQT_SIGNAL(currentChanged(TQListViewItem*)), this, TQT_SLOT(updateButtons(TQListViewItem*)));
-	connect(m_treeview, TQT_SIGNAL(moved(TQListViewItem*, TQListViewItem*, TQListViewItem*)), this, TQT_SLOT(updateButtons(TQListViewItem*)));
+	connect(m_treeview, TQ_SIGNAL(currentChanged(TQListViewItem*)), this, TQ_SLOT(updateButtons(TQListViewItem*)));
+	connect(m_treeview, TQ_SIGNAL(moved(TQListViewItem*, TQListViewItem*, TQListViewItem*)), this, TQ_SLOT(updateButtons(TQListViewItem*)));
 
 	TQVBoxLayout *vbox = new TQVBoxLayout();
 	l->addLayout(vbox, 0, 1);
 	m_btnUp = new KPushButton(SmallIconSet("1uparrow"), i18n("Move Up"), frame);
 	TQToolTip::add( m_btnUp, i18n("Move widget up") );
 	vbox->addWidget(m_btnUp);
-	connect(m_btnUp, TQT_SIGNAL(clicked()), this, TQT_SLOT(moveItemUp()));
+	connect(m_btnUp, TQ_SIGNAL(clicked()), this, TQ_SLOT(moveItemUp()));
 
 	m_btnDown = new KPushButton(SmallIconSet("1downarrow"), i18n("Move Down"), frame);
 	TQToolTip::add( m_btnDown, i18n("Move widget down") );
 	vbox->addWidget(m_btnDown);
-	connect(m_btnDown, TQT_SIGNAL(clicked()), this, TQT_SLOT(moveItemDown()));
+	connect(m_btnDown, TQ_SIGNAL(clicked()), this, TQ_SLOT(moveItemDown()));
 	vbox->addStretch();
 
 	m_check = new TQCheckBox(i18n("Handle tab order automatically"), frame, "tabstops_check");
-	connect(m_check, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(slotRadioClicked(bool)));
+	connect(m_check, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(slotRadioClicked(bool)));
 	l->addMultiCellWidget(m_check, 1, 1, 0, 1);
 
 	updateGeometry();
