@@ -172,21 +172,21 @@ KFormDesignerKDevPart::KFormDesignerKDevPart(TQWidget *parent, const char *name,
 		setModified(false);
 
 		// action stuff
-		connect(KFormDesigner::FormManager::self(), TQT_SIGNAL(widgetSelected(KFormDesigner::Form*, bool)), TQT_SLOT(slotWidgetSelected(KFormDesigner::Form*, bool)));
-		connect(KFormDesigner::FormManager::self(), TQT_SIGNAL(formWidgetSelected(KFormDesigner::Form*)), TQT_SLOT(slotFormWidgetSelected(KFormDesigner::Form*)));
-		connect(KFormDesigner::FormManager::self(), TQT_SIGNAL(noFormSelected()), TQT_SLOT(slotNoFormSelected()));
-		connect(KFormDesigner::FormManager::self(), TQT_SIGNAL(undoEnabled(bool, const TQString&)), TQT_SLOT(setUndoEnabled(bool, const TQString&)));
-		connect(KFormDesigner::FormManager::self(), TQT_SIGNAL(redoEnabled(bool, const TQString&)), TQT_SLOT(setRedoEnabled(bool, const TQString&)));
+		connect(KFormDesigner::FormManager::self(), TQ_SIGNAL(widgetSelected(KFormDesigner::Form*, bool)), TQ_SLOT(slotWidgetSelected(KFormDesigner::Form*, bool)));
+		connect(KFormDesigner::FormManager::self(), TQ_SIGNAL(formWidgetSelected(KFormDesigner::Form*)), TQ_SLOT(slotFormWidgetSelected(KFormDesigner::Form*)));
+		connect(KFormDesigner::FormManager::self(), TQ_SIGNAL(noFormSelected()), TQ_SLOT(slotNoFormSelected()));
+		connect(KFormDesigner::FormManager::self(), TQ_SIGNAL(undoEnabled(bool, const TQString&)), TQ_SLOT(setUndoEnabled(bool, const TQString&)));
+		connect(KFormDesigner::FormManager::self(), TQ_SIGNAL(redoEnabled(bool, const TQString&)), TQ_SLOT(setRedoEnabled(bool, const TQString&)));
 
-		connect(KFormDesigner::FormManager::self(), TQT_SIGNAL(dirty(KFormDesigner::Form*, bool)), this, TQT_SLOT(slotFormModified(KFormDesigner::Form*, bool)));
+		connect(KFormDesigner::FormManager::self(), TQ_SIGNAL(dirty(KFormDesigner::Form*, bool)), this, TQ_SLOT(slotFormModified(KFormDesigner::Form*, bool)));
 
-		connect(KFormDesigner::FormManager::self(), TQT_SIGNAL(createFormSlot(KFormDesigner::Form*, const TQString&, const TQString&)),
-			this, TQT_SLOT(slotCreateFormSlot(KFormDesigner::Form*, const TQString&, const TQString &)));
+		connect(KFormDesigner::FormManager::self(), TQ_SIGNAL(createFormSlot(KFormDesigner::Form*, const TQString&, const TQString&)),
+			this, TQ_SLOT(slotCreateFormSlot(KFormDesigner::Form*, const TQString&, const TQString &)));
 	}
 
 	container->show();
 	setWidget(container);
-	connect(m_workspace, TQT_SIGNAL(windowActivated(TQWidget*)), KFormDesigner::FormManager::self(), TQT_SLOT(windowChanged(TQWidget*)));
+	connect(m_workspace, TQ_SIGNAL(windowActivated(TQWidget*)), KFormDesigner::FormManager::self(), TQ_SLOT(windowChanged(TQWidget*)));
 	slotNoFormSelected();
 }
 
@@ -198,45 +198,45 @@ KFormDesigner::WidgetLibrary* KFormDesignerKDevPart::formsLibrary()
 void
 KFormDesignerKDevPart::setupActions()
 {
-	KStdAction::open(this, TQT_SLOT(open()), actionCollection());
-	KStdAction::openNew(this, TQT_SLOT(createBlankForm()), actionCollection());
-	KStdAction::save(this, TQT_SLOT(save()), actionCollection());
-	KStdAction::saveAs(this, TQT_SLOT(saveAs()), actionCollection());
-	KStdAction::cut(KFormDesigner::FormManager::self(), TQT_SLOT(cutWidget()), actionCollection());
-	KStdAction::copy(KFormDesigner::FormManager::self(), TQT_SLOT(copyWidget()), actionCollection());
-	KStdAction::paste(KFormDesigner::FormManager::self(), TQT_SLOT(pasteWidget()), actionCollection());
-	KStdAction::undo(KFormDesigner::FormManager::self(), TQT_SLOT(undo()), actionCollection());
-	KStdAction::redo(KFormDesigner::FormManager::self(), TQT_SLOT(redo()), actionCollection());
-	KStdAction::selectAll(KFormDesigner::FormManager::self(), TQT_SLOT(selectAll()), actionCollection());
-	new TDEAction(i18n("Clear Widget Contents"), "edit-clear", TDEShortcut(0), KFormDesigner::FormManager::self(), TQT_SLOT(clearWidgetContent()), actionCollection(), "clear_contents");
-	new TDEAction(i18n("Delete Widget"), "edit-delete", TDEShortcut(0), KFormDesigner::FormManager::self(), TQT_SLOT(deleteWidget()), actionCollection(), "edit_delete");
-	new TDEAction(i18n("Preview Form"), "document-print-preview", "Ctrl+T", this, TQT_SLOT(slotPreviewForm()), actionCollection(), "preview_form");
-	new TDEAction(i18n("Edit Tab Order"), "tab_order", TDEShortcut(0), KFormDesigner::FormManager::self(), TQT_SLOT(editTabOrder()), actionCollection(), "taborder");
-	new TDEAction(i18n("Edit Pixmap Collection"), "icons", TDEShortcut(0), KFormDesigner::FormManager::self(), TQT_SLOT(editFormPixmapCollection()), actionCollection(), "pixmap_collection");
-	new TDEAction(i18n("Edit Form Connections"), "connections", TDEShortcut(0), KFormDesigner::FormManager::self(), TQT_SLOT(editConnections()), actionCollection(), "form_connections");
+	KStdAction::open(this, TQ_SLOT(open()), actionCollection());
+	KStdAction::openNew(this, TQ_SLOT(createBlankForm()), actionCollection());
+	KStdAction::save(this, TQ_SLOT(save()), actionCollection());
+	KStdAction::saveAs(this, TQ_SLOT(saveAs()), actionCollection());
+	KStdAction::cut(KFormDesigner::FormManager::self(), TQ_SLOT(cutWidget()), actionCollection());
+	KStdAction::copy(KFormDesigner::FormManager::self(), TQ_SLOT(copyWidget()), actionCollection());
+	KStdAction::paste(KFormDesigner::FormManager::self(), TQ_SLOT(pasteWidget()), actionCollection());
+	KStdAction::undo(KFormDesigner::FormManager::self(), TQ_SLOT(undo()), actionCollection());
+	KStdAction::redo(KFormDesigner::FormManager::self(), TQ_SLOT(redo()), actionCollection());
+	KStdAction::selectAll(KFormDesigner::FormManager::self(), TQ_SLOT(selectAll()), actionCollection());
+	new TDEAction(i18n("Clear Widget Contents"), "edit-clear", TDEShortcut(0), KFormDesigner::FormManager::self(), TQ_SLOT(clearWidgetContent()), actionCollection(), "clear_contents");
+	new TDEAction(i18n("Delete Widget"), "edit-delete", TDEShortcut(0), KFormDesigner::FormManager::self(), TQ_SLOT(deleteWidget()), actionCollection(), "edit_delete");
+	new TDEAction(i18n("Preview Form"), "document-print-preview", "Ctrl+T", this, TQ_SLOT(slotPreviewForm()), actionCollection(), "preview_form");
+	new TDEAction(i18n("Edit Tab Order"), "tab_order", TDEShortcut(0), KFormDesigner::FormManager::self(), TQ_SLOT(editTabOrder()), actionCollection(), "taborder");
+	new TDEAction(i18n("Edit Pixmap Collection"), "icons", TDEShortcut(0), KFormDesigner::FormManager::self(), TQ_SLOT(editFormPixmapCollection()), actionCollection(), "pixmap_collection");
+	new TDEAction(i18n("Edit Form Connections"), "connections", TDEShortcut(0), KFormDesigner::FormManager::self(), TQ_SLOT(editConnections()), actionCollection(), "form_connections");
 
-	new TDEAction(i18n("Lay Out Widgets &Horizontally"), TQString(), TDEShortcut(0), KFormDesigner::FormManager::self(), TQT_SLOT(layoutHBox()), actionCollection(), "layout_hbox");
-	new TDEAction(i18n("Lay Out Widgets &Vertically"), TQString(), TDEShortcut(0), KFormDesigner::FormManager::self(), TQT_SLOT(layoutVBox()), actionCollection(), "layout_vbox");
-	new TDEAction(i18n("Lay Out Widgets in &Grid"), TQString(), TDEShortcut(0), KFormDesigner::FormManager::self(), TQT_SLOT(layoutGrid()), actionCollection(), "layout_grid");
-	new TDEAction(i18n("&Break Layout"), TQString(), TDEShortcut(0), KFormDesigner::FormManager::self(), TQT_SLOT(breakLayout()), actionCollection(), "break_layout");
+	new TDEAction(i18n("Lay Out Widgets &Horizontally"), TQString(), TDEShortcut(0), KFormDesigner::FormManager::self(), TQ_SLOT(layoutHBox()), actionCollection(), "layout_hbox");
+	new TDEAction(i18n("Lay Out Widgets &Vertically"), TQString(), TDEShortcut(0), KFormDesigner::FormManager::self(), TQ_SLOT(layoutVBox()), actionCollection(), "layout_vbox");
+	new TDEAction(i18n("Lay Out Widgets in &Grid"), TQString(), TDEShortcut(0), KFormDesigner::FormManager::self(), TQ_SLOT(layoutGrid()), actionCollection(), "layout_grid");
+	new TDEAction(i18n("&Break Layout"), TQString(), TDEShortcut(0), KFormDesigner::FormManager::self(), TQ_SLOT(breakLayout()), actionCollection(), "break_layout");
 
-	new TDEAction(i18n("Bring Widget to Front"), "raise", TDEShortcut(0), KFormDesigner::FormManager::self(), TQT_SLOT(bringWidgetToFront()), actionCollection(), "format_raise");
-	new TDEAction(i18n("Send Widget to Back"), "lower", TDEShortcut(0), KFormDesigner::FormManager::self(), TQT_SLOT(sendWidgetToBack()), actionCollection(), "format_lower");
+	new TDEAction(i18n("Bring Widget to Front"), "raise", TDEShortcut(0), KFormDesigner::FormManager::self(), TQ_SLOT(bringWidgetToFront()), actionCollection(), "format_raise");
+	new TDEAction(i18n("Send Widget to Back"), "lower", TDEShortcut(0), KFormDesigner::FormManager::self(), TQ_SLOT(sendWidgetToBack()), actionCollection(), "format_lower");
 
 	TDEActionMenu *alignMenu = new TDEActionMenu(i18n("Align Widgets' Positions"), "aopos2grid", actionCollection(), "align_menu");
-	alignMenu->insert( new TDEAction(i18n("To Left"), "aoleft", TDEShortcut(0), KFormDesigner::FormManager::self(), TQT_SLOT(alignWidgetsToLeft()), actionCollection(), "align_to_left") );
-	alignMenu->insert( new TDEAction(i18n("To Right"), "aoright", TDEShortcut(0), KFormDesigner::FormManager::self(), TQT_SLOT(alignWidgetsToRight()), actionCollection(), "align_to_right") );
-	alignMenu->insert( new TDEAction(i18n("To Top"), "aotop", TDEShortcut(0), KFormDesigner::FormManager::self(), TQT_SLOT(alignWidgetsToTop()), actionCollection(), "align_to_top") );
-	alignMenu->insert( new TDEAction(i18n("To Bottom"), "aobottom", TDEShortcut(0), KFormDesigner::FormManager::self(), TQT_SLOT(alignWidgetsToBottom()), actionCollection(), "align_to_bottom") );
-	alignMenu->insert( new TDEAction(i18n("To Grid"), "aopos2grid", TDEShortcut(0), KFormDesigner::FormManager::self(), TQT_SLOT(alignWidgetsToGrid()), actionCollection(), "align_to_grid") );
+	alignMenu->insert( new TDEAction(i18n("To Left"), "aoleft", TDEShortcut(0), KFormDesigner::FormManager::self(), TQ_SLOT(alignWidgetsToLeft()), actionCollection(), "align_to_left") );
+	alignMenu->insert( new TDEAction(i18n("To Right"), "aoright", TDEShortcut(0), KFormDesigner::FormManager::self(), TQ_SLOT(alignWidgetsToRight()), actionCollection(), "align_to_right") );
+	alignMenu->insert( new TDEAction(i18n("To Top"), "aotop", TDEShortcut(0), KFormDesigner::FormManager::self(), TQ_SLOT(alignWidgetsToTop()), actionCollection(), "align_to_top") );
+	alignMenu->insert( new TDEAction(i18n("To Bottom"), "aobottom", TDEShortcut(0), KFormDesigner::FormManager::self(), TQ_SLOT(alignWidgetsToBottom()), actionCollection(), "align_to_bottom") );
+	alignMenu->insert( new TDEAction(i18n("To Grid"), "aopos2grid", TDEShortcut(0), KFormDesigner::FormManager::self(), TQ_SLOT(alignWidgetsToGrid()), actionCollection(), "align_to_grid") );
 
 	TDEActionMenu *sizeMenu = new TDEActionMenu(i18n("Adjust Widgets' Sizes"), "aogrid", actionCollection(), "adjust_size_menu");
-	sizeMenu->insert( new TDEAction(i18n("To Fit"), "aofit", TDEShortcut(0), KFormDesigner::FormManager::self(), TQT_SLOT(adjustWidgetSize()), actionCollection(), "adjust_to_fit") );
-	sizeMenu->insert( new TDEAction(i18n("To Grid"), "aogrid", TDEShortcut(0), KFormDesigner::FormManager::self(), TQT_SLOT(adjustSizeToGrid()), actionCollection(), "adjust_size_grid") );
-	sizeMenu->insert( new TDEAction(i18n("To Shortest"), "aoshortest", TDEShortcut(0), KFormDesigner::FormManager::self(), TQT_SLOT(adjustHeightToSmall()), actionCollection(), "adjust_height_small") );
-	sizeMenu->insert( new TDEAction(i18n("To Tallest"), "aotallest", TDEShortcut(0), KFormDesigner::FormManager::self(), TQT_SLOT(adjustHeightToBig()), actionCollection(), "adjust_height_big") );
-	sizeMenu->insert( new TDEAction(i18n("To Narrowest"), "aonarrowest", TDEShortcut(0), KFormDesigner::FormManager::self(), TQT_SLOT(adjustWidthToSmall()), actionCollection(), "adjust_width_small") );
-	sizeMenu->insert( new TDEAction(i18n("To Widest"), "aowidest", TDEShortcut(0), KFormDesigner::FormManager::self(), TQT_SLOT(adjustWidthToBig()), actionCollection(), "adjust_width_big") );
+	sizeMenu->insert( new TDEAction(i18n("To Fit"), "aofit", TDEShortcut(0), KFormDesigner::FormManager::self(), TQ_SLOT(adjustWidgetSize()), actionCollection(), "adjust_to_fit") );
+	sizeMenu->insert( new TDEAction(i18n("To Grid"), "aogrid", TDEShortcut(0), KFormDesigner::FormManager::self(), TQ_SLOT(adjustSizeToGrid()), actionCollection(), "adjust_size_grid") );
+	sizeMenu->insert( new TDEAction(i18n("To Shortest"), "aoshortest", TDEShortcut(0), KFormDesigner::FormManager::self(), TQ_SLOT(adjustHeightToSmall()), actionCollection(), "adjust_height_small") );
+	sizeMenu->insert( new TDEAction(i18n("To Tallest"), "aotallest", TDEShortcut(0), KFormDesigner::FormManager::self(), TQ_SLOT(adjustHeightToBig()), actionCollection(), "adjust_height_big") );
+	sizeMenu->insert( new TDEAction(i18n("To Narrowest"), "aonarrowest", TDEShortcut(0), KFormDesigner::FormManager::self(), TQ_SLOT(adjustWidthToSmall()), actionCollection(), "adjust_width_small") );
+	sizeMenu->insert( new TDEAction(i18n("To Widest"), "aowidest", TDEShortcut(0), KFormDesigner::FormManager::self(), TQ_SLOT(adjustWidthToBig()), actionCollection(), "adjust_width_big") );
 
 	if(m_inShell)
 		setXMLFile("kformdesigner_part_shell.rc");
