@@ -24,7 +24,7 @@
 
 class KFDMainWindow : public KParts::MainWindow
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
