@@ -55,7 +55,7 @@ typedef TQPtrList<TDEAction> ActionList;
  */
 class KFORMEDITOR_EXPORT WidgetLibrary : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
