@@ -40,7 +40,7 @@ class ODBCDriverPrivate;
  */
 class ODBCDriver : public Driver
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	KEXIDB_DRIVER
 
