@@ -71,8 +71,8 @@ tristate SQLiteVacuum::run()
 	args << ksqlite_app << "-verbose-vacuum" << m_filePath << "vacuum";
 	m_process = new TQProcess(args, this, "process");
 	m_process->setWorkingDirectory( TQFileInfo(m_filePath).dir(true) );
-	connect( m_process, TQT_SIGNAL(readyReadStdout()), this, TQT_SLOT(readFromStdout()) );
-	connect( m_process, TQT_SIGNAL(processExited()), this, TQT_SLOT(processExited()) );
+	connect( m_process, TQ_SIGNAL(readyReadStdout()), this, TQ_SLOT(readFromStdout()) );
+	connect( m_process, TQ_SIGNAL(processExited()), this, TQ_SLOT(processExited()) );
 	if (!m_process->start()) {
 		m_result = false;
 		return m_result;
@@ -83,7 +83,7 @@ tristate SQLiteVacuum::run()
 	);
 	m_dlg->adjustSize();
 	m_dlg->resize(300, m_dlg->height());
-	connect(m_dlg, TQT_SIGNAL(cancelClicked()), this, TQT_SLOT(cancelClicked()));
+	connect(m_dlg, TQ_SIGNAL(cancelClicked()), this, TQ_SLOT(cancelClicked()));
 	m_dlg->setMinimumDuration(1000);
 	m_dlg->setAutoClose(true);
 	m_dlg->progressBar()->setTotalSteps(100);
