@@ -304,7 +304,7 @@ namespace KexiDB
 	   For example, "12.345" becomes "12.345000" if N=6.
 
 	 No rounding is actually performed.
-	 KLocale::formatNumber() and KLocale::decimalSymbol() are used to get locale settings.
+	 TDELocale::formatNumber() and TDELocale::decimalSymbol() are used to get locale settings.
 
 	 @see KexiDB::Field::visibleDecimalPlaces() */
 	KEXI_DB_EXPORT TQString formatNumberForVisibleDecimalPlaces(double value, int decimalPlaces);
@@ -379,7 +379,7 @@ namespace KexiDB
 	 "notEmpty" property set. It works in a similar way as 
 	 @ref TQVariant emptyValueForType( KexiDB::Field::Type type ) with the following differences:
 	 - " " string (a single space) is returned for Text and LongText types
-	 - a byte array with saved "filenew" PNG image (icon) for BLOB type
+	 - a byte array with saved "document-new" PNG image (icon) for BLOB type
 	 Returns null TQVariant for unsupported values like KexiDB::Field::InvalidType. 
 	 This function is efficient (uses a cache) and is heavily used by the AlterTableHandler
 	 for filling new columns. */
