@@ -67,7 +67,7 @@ void KexiUtils::addKexiDBDebug(const TQString& text)
 		hbox->addWidget(btn_clear);
 
 		kexiDBDebugPage = new TDEListView(page, "kexiDbDebugPage");
-		TQObject::connect(btn_clear, TQT_SIGNAL(clicked()), kexiDBDebugPage, TQT_SLOT(clear()));
+		TQObject::connect(btn_clear, TQ_SIGNAL(clicked()), kexiDBDebugPage, TQ_SLOT(clear()));
 		vbox->addWidget(kexiDBDebugPage);
 		kexiDBDebugPage->addColumn("");
 		kexiDBDebugPage->header()->hide();
@@ -107,7 +107,7 @@ void KexiUtils::addAlterTableActionDebug(const TQString& text, int nestingLevel)
 		hbox->addWidget(btn_sim);
 
 		kexiAlterTableActionDebugPage = new TDEListView(page, "kexiAlterTableActionDebugPage");
-		TQObject::connect(btn_clear, TQT_SIGNAL(clicked()), kexiAlterTableActionDebugPage, TQT_SLOT(clear()));
+		TQObject::connect(btn_clear, TQ_SIGNAL(clicked()), kexiAlterTableActionDebugPage, TQ_SLOT(clear()));
 		vbox->addWidget(kexiAlterTableActionDebugPage);
 		kexiAlterTableActionDebugPage->addColumn("");
 		kexiAlterTableActionDebugPage->header()->hide();
@@ -165,7 +165,7 @@ void KexiUtils::connectPushButtonActionForDebugWindow(const char* actionName,
 	if (debugWindow) {
 		KPushButton* btn = findFirstChild<KPushButton>(debugWindow, "KPushButton", actionName);
 		if (btn)
-			TQObject::connect(btn, TQT_SIGNAL(clicked()), receiver, slot);
+			TQObject::connect(btn, TQ_SIGNAL(clicked()), receiver, slot);
 	}
 }
 
