@@ -44,7 +44,7 @@ namespace KexiPart {
  */
 class KEXIMAIN_EXPORT KexiMainWindowImpl : public KexiMainWindow, public KexiGUIMessageHandler
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
