@@ -31,7 +31,7 @@ class MultiValidator;
 
 class KEXIMAIN_EXPORT KexiNameWidget : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
