@@ -481,7 +481,7 @@ void KexiSimplePrintingEngine::paintRecord(TQPainter& painter, KexiTableItem *it
 							int( (rect.y()+m_mainLineSpacing/4) / m_SCALE), 
 							pixmap.convertToImage().smoothScale( 
 								int(pixmapWidth / m_SCALE), int(pixmapHeight / m_SCALE),
-								TQ_ScaleMin ));
+								TQImage::ScaleMin ));
 						painter.restore(); // back to m_SCALE:1 scale
 					}
 				}
