@@ -36,7 +36,7 @@ class KexiProjectSelectorWidget;
 
 class KEXIMAIN_EXPORT KexiNewProjectWizard : public KWizard
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		KexiNewProjectWizard(KexiDBConnectionSet& conn_set, TQWidget *parent=0, 
