@@ -194,7 +194,7 @@ KexiStartupDialog::KexiStartupDialog(
 #endif
 
 	if (!d->singlePage) {
-		connect(this, TQT_SIGNAL(aboutToShowPage(TQWidget*)), this, TQT_SLOT(slotPageShown(TQWidget*)));
+		connect(this, TQ_SIGNAL(aboutToShowPage(TQWidget*)), this, TQ_SLOT(slotPageShown(TQWidget*)));
 		d->templatesWidget->setFocus();
 	}
 	showPage(0);
@@ -304,7 +304,7 @@ void KexiStartupDialog::setupPageTemplates()
 			d->templatesWidget_IconListBox->installEventFilter(this);
 	}
 	lyr->addWidget(d->templatesWidget);
-	connect(d->templatesWidget, TQT_SIGNAL(aboutToShowPage(TQWidget*)), this, TQT_SLOT(slotPageShown(TQWidget*)));
+	connect(d->templatesWidget, TQ_SIGNAL(aboutToShowPage(TQWidget*)), this, TQ_SLOT(slotPageShown(TQWidget*)));
 
 	if (d->dialogOptions & CheckBoxDoNotShowAgain) {
 		d->chkDoNotShow = new TQCheckBox(i18n("Don't show me this dialog again"), d->pageTemplates, "chkDoNotShow");
@@ -348,21 +348,21 @@ void KexiStartupDialog::setupPageTemplates()
 
 	d->viewTemplates = new KexiStartupDialogTemplatesPage( templPageFrame );
 	tmplyr->addWidget( d->viewTemplates );
-	connect(d->viewTemplates,TQT_SIGNAL(selected(const TQString&)),
-		this,TQT_SLOT(templateSelected(const TQString&)));
-/*	connect(d->viewTemplates->templates,TQT_SIGNAL(returnPressed(TQIconViewItem*)),
-		this,TQT_SLOT(templateItemExecuted(TQIconViewItem*)));
-	connect(d->viewTemplates->templates,TQT_SIGNAL(currentChanged(TQIconViewItem*)),
-		this,TQT_SLOT(templateItemSelected(TQIconViewItem*)));*/
+	connect(d->viewTemplates,TQ_SIGNAL(selected(const TQString&)),
+		this,TQ_SLOT(templateSelected(const TQString&)));
+/*	connect(d->viewTemplates->templates,TQ_SIGNAL(returnPressed(TQIconViewItem*)),
+		this,TQ_SLOT(templateItemExecuted(TQIconViewItem*)));
+	connect(d->viewTemplates->templates,TQ_SIGNAL(currentChanged(TQIconViewItem*)),
+		this,TQ_SLOT(templateItemSelected(TQIconViewItem*)));*/
 /*later
 	templPageFrame = d->templatesWidget->addPage (
 		i18n("Personal Databases"), i18n("New Personal Database Project Templates"), DesktopIcon("folder_home") );
 	tmplyr = new TQVBoxLayout(templPageFrame, 0, KDialogBase::spacingHint());
-	d->viewPersonalTempl = new TemplatesPage(Qt::Vertical, templPageFrame, "personal_page" );
+	d->viewPersonalTempl = new TemplatesPage(TQt::Vertical, templPageFrame, "personal_page" );
 	tmplyr->addWidget( d->viewPersonalTempl );
-	connect(d->viewPersonalTempl->templates,TQT_SIGNAL(doubleClicked(TQIconViewItem*)),this,TQT_SLOT(templateItemExecuted(TQIconViewItem*)));
-	connect(d->viewPersonalTempl->templates,TQT_SIGNAL(returnPressed(TQIconViewItem*)),this,TQT_SLOT(templateItemExecuted(TQIconViewItem*)));
-	connect(d->viewPersonalTempl->templates,TQT_SIGNAL(currentChanged(TQIconViewItem*)),this,TQT_SLOT(templateItemSelected(TQIconViewItem*)));
+	connect(d->viewPersonalTempl->templates,TQ_SIGNAL(doubleClicked(TQIconViewItem*)),this,TQ_SLOT(templateItemExecuted(TQIconViewItem*)));
+	connect(d->viewPersonalTempl->templates,TQ_SIGNAL(returnPressed(TQIconViewItem*)),this,TQ_SLOT(templateItemExecuted(TQIconViewItem*)));
+	connect(d->viewPersonalTempl->templates,TQ_SIGNAL(currentChanged(TQIconViewItem*)),this,TQ_SLOT(templateItemSelected(TQIconViewItem*)));
 */
 
 	//- page "business db"
@@ -372,11 +372,11 @@ void KexiStartupDialog::setupPageTemplates()
 		i18n("Business Databases"), i18n("New Business Database Project Templates"),
 		DesktopIcon( "business_user" ));
 	tmplyr = new TQVBoxLayout(templPageFrame, 0, KDialogBase::spacingHint());
-	d->viewBusinessTempl = new TemplatesPage(Qt::Vertical, templPageFrame, "business_page" );
+	d->viewBusinessTempl = new TemplatesPage(TQt::Vertical, templPageFrame, "business_page" );
 	tmplyr->addWidget( d->viewBusinessTempl );
-	connect(d->viewBusinessTempl->templates,TQT_SIGNAL(doubleClicked(TQIconViewItem*)),this,TQT_SLOT(templateItemExecuted(TQIconViewItem*)));
-	connect(d->viewBusinessTempl->templates,TQT_SIGNAL(returnPressed(TQIconViewItem*)),this,TQT_SLOT(templateItemExecuted(TQIconViewItem*)));
-	connect(d->viewBusinessTempl->templates,TQT_SIGNAL(currentChanged(TQIconViewItem*)),this,TQT_SLOT(templateItemSelected(TQIconViewItem*)));
+	connect(d->viewBusinessTempl->templates,TQ_SIGNAL(doubleClicked(TQIconViewItem*)),this,TQ_SLOT(templateItemExecuted(TQIconViewItem*)));
+	connect(d->viewBusinessTempl->templates,TQ_SIGNAL(returnPressed(TQIconViewItem*)),this,TQ_SLOT(templateItemExecuted(TQIconViewItem*)));
+	connect(d->viewBusinessTempl->templates,TQ_SIGNAL(currentChanged(TQIconViewItem*)),this,TQ_SLOT(templateItemSelected(TQIconViewItem*)));
 */
 #endif //DB_TEMPLATES
 
@@ -413,7 +413,7 @@ void KexiStartupDialog::slotPageShown(TQWidget *page)
 			//add items (on demand):
 			d->viewTemplates->addItem("cd_catalog", i18n("CD Catalog"),
 				i18n("Easy-to-use database for storing information about your CD collection."),
-				DesktopIcon("media-optical-cdrom"));
+				DesktopIcon("media-optical-cdrom-unmounted"));
 			d->viewTemplates->addItem("expenses", i18n("Expenses"),
 				i18n("A database for managing your personal expenses."),
 				DesktopIcon("kcalc"));
@@ -559,11 +559,11 @@ void KexiStartupDialog::setupPageOpenExisting()
 		d->openExistingConnWidget->showAdvancedConn();
 	}
 	d->openExistingFileDlg = d->openExistingConnWidget->m_fileDlg;
-	connect(d->openExistingFileDlg,TQT_SIGNAL(accepted()),this,TQT_SLOT(accept()));
-	connect(d->openExistingConnWidget,TQT_SIGNAL(connectionItemExecuted(ConnectionDataLVItem*)),
-		this,TQT_SLOT(connectionItemForOpenExistingExecuted(ConnectionDataLVItem*)));
-	connect(d->openExistingConnWidget,TQT_SIGNAL(connectionItemHighlighted(ConnectionDataLVItem*)),
-		this,TQT_SLOT(connectionItemForOpenExistingHighlighted(ConnectionDataLVItem*)));
+	connect(d->openExistingFileDlg,TQ_SIGNAL(accepted()),this,TQ_SLOT(accept()));
+	connect(d->openExistingConnWidget,TQ_SIGNAL(connectionItemExecuted(ConnectionDataLVItem*)),
+		this,TQ_SLOT(connectionItemForOpenExistingExecuted(ConnectionDataLVItem*)));
+	connect(d->openExistingConnWidget,TQ_SIGNAL(connectionItemHighlighted(ConnectionDataLVItem*)),
+		this,TQ_SLOT(connectionItemForOpenExistingHighlighted(ConnectionDataLVItem*)));
 }
 
 void KexiStartupDialog::connectionItemForOpenExistingExecuted(ConnectionDataLVItem *item)
@@ -632,8 +632,8 @@ void KexiStartupDialog::setupPageOpenRecent()
 	TQVBoxLayout *lyr = new TQVBoxLayout( d->pageOpenRecent, 0, KDialogBase::spacingHint() );
 	lyr->addWidget( d->prj_selector = new KexiProjectSelectorWidget(
 		d->pageOpenRecent, "prj_selector", d->recentProjects ) );
-	connect(d->prj_selector,TQT_SIGNAL(projectExecuted(KexiProjectData*)),
-		this,TQT_SLOT(recentProjectItemExecuted(KexiProjectData*)));
+	connect(d->prj_selector,TQ_SIGNAL(projectExecuted(KexiProjectData*)),
+		this,TQ_SLOT(recentProjectItemExecuted(KexiProjectData*)));
 #endif
 }
 
@@ -658,7 +658,7 @@ bool KexiStartupDialog::eventFilter( TQObject *o, TQEvent *e )
 {
 	if (o==d->templatesWidget_IconListBox && d->templatesWidget_IconListBox) {
 		if (e->type()==TQEvent::KeyPress 
-			&& (TQT_TQKEYEVENT(e)->key()==Key_Enter || TQT_TQKEYEVENT(e)->key()==Key_Return)
+			&& (static_cast<TQKeyEvent*>(e)->key()==Key_Enter || static_cast<TQKeyEvent*>(e)->key()==Key_Return)
 			|| e->type()==TQEvent::MouseButtonDblClick) 
 		{
 			const int t_id = d->templatesWidget->activePageIndex();
