@@ -45,7 +45,7 @@ class ConnectionDataLVItem;
  */
 class KEXIMAIN_EXPORT KexiStartupDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
