@@ -32,7 +32,7 @@ namespace KexiMigration {
 //! @todo Hardcoded. Move such code to KexiMigrate drivers.
 class OptionsDialog : public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		OptionsDialog( const TQString& databaseFile, const TQString& selectedEncoding, TQWidget* parent = 0 );
