@@ -83,8 +83,8 @@ ImportWizard::ImportWizard(TQWidget *parent, TQMap<TQString,TQString>* args)
 	setupImporting();
 	setupFinish();
 
-	connect(this, TQT_SIGNAL(selected(const TQString &)), this, TQT_SLOT(pageSelected(const TQString &)));
-	connect(this, TQT_SIGNAL(helpClicked()), this, TQT_SLOT(helpClicked()));
+	connect(this, TQ_SIGNAL(selected(const TQString &)), this, TQ_SLOT(pageSelected(const TQString &)));
+	connect(this, TQ_SIGNAL(helpClicked()), this, TQ_SLOT(helpClicked()));
 
 	if (m_predefinedConnectionData) {
 		// setup wizard for predefined server source
@@ -291,11 +291,11 @@ void ImportWizard::setupDst()
 		":ProjectMigrationDestinationDir", m_dstPage, "m_dstConnSelector");
 	m_dstConn->hideHelpers();
 	//me: Can't connect m_dstConn->m_fileDlg here, it doesn't exist yet
-	//connect(this, TQT_SLOT(next()), m_dstConn->m_fileDlg, TQT_SIGNAL(accepted()));
+	//connect(this, TQ_SLOT(next()), m_dstConn->m_fileDlg, TQ_SIGNAL(accepted()));
 
 	vbox->addWidget( m_dstConn );
-	connect(m_dstConn,TQT_SIGNAL(connectionItemExecuted(ConnectionDataLVItem*)),
-		this,TQT_SLOT(next()));
+	connect(m_dstConn,TQ_SIGNAL(connectionItemExecuted(ConnectionDataLVItem*)),
+		this,TQ_SLOT(next()));
 
 //	m_dstConn->hideHelpers();
 	m_dstConn->showSimpleConn();
@@ -353,7 +353,7 @@ void ImportWizard::setupImporting()
 
 	KButtonBox *optionsBox = new KButtonBox(m_importingPage);
 	vbox->addWidget( optionsBox );
-	m_importOptionsButton = optionsBox->addButton(i18n("Advanced Options"), TQT_TQOBJECT(this), TQT_SLOT(slotOptionsButtonClicked()));
+	m_importOptionsButton = optionsBox->addButton(i18n("Advanced Options"), this, TQ_SLOT(slotOptionsButtonClicked()));
 	m_importOptionsButton->setIconSet(SmallIconSet("configure"));
 	optionsBox->addStretch(1);
 
@@ -736,10 +736,10 @@ KexiMigrate* ImportWizard::prepareImport(Kexi::ObjectStatus& result)
 		// Setup progress feedback for the GUI
 		if(sourceDriver->progressSupported()) {
 			m_progressBar->updateGeometry();
-			disconnect(sourceDriver, TQT_SIGNAL(progressPercent(int)), 
-				this, TQT_SLOT(progressUpdated(int)));
-			connect(sourceDriver, TQT_SIGNAL(progressPercent(int)),
-				this, TQT_SLOT(progressUpdated(int)));
+			disconnect(sourceDriver, TQ_SIGNAL(progressPercent(int)), 
+				this, TQ_SLOT(progressUpdated(int)));
+			connect(sourceDriver, TQ_SIGNAL(progressPercent(int)),
+				this, TQ_SLOT(progressUpdated(int)));
 			progressUpdated(0);
 		}
 
