@@ -37,7 +37,7 @@ class TQFrame;
 //! A page within form designer's property tabbed pane, providing data source editor
 class KEXIFORMUTILS_EXPORT KexiDataSourcePage : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
