@@ -101,7 +101,7 @@ KexiDBFactory::KexiDBFactory(TQObject *parent, const char *name, const TQStringL
 	wi = new KexiDataAwareWidgetInfo(this, "stdwidgets", "KLineEdit");
 	wi->setPixmap("lineedit");
 	wi->setClassName("KexiDBLineEdit");
-	wi->addAlternateClassName(TQLINEEDIT_OBJECT_NAME_STRING, true/*override*/);
+	wi->addAlternateClassName("TQLineEdit", true/*override*/);
 	wi->addAlternateClassName("KLineEdit", true/*override*/);
 	wi->setIncludeFileName("klineedit.h");
 	wi->setName(i18n("Text Box"));
@@ -115,7 +115,7 @@ KexiDBFactory::KexiDBFactory(TQObject *parent, const char *name, const TQStringL
 	wi = new KexiDataAwareWidgetInfo(this, "stdwidgets", "KTextEdit");
 	wi->setPixmap("textedit");
 	wi->setClassName("KexiDBTextEdit");
-	wi->addAlternateClassName(TQTEXTEDIT_OBJECT_NAME_STRING, true/*override*/);
+	wi->addAlternateClassName("TQTextEdit", true/*override*/);
 	wi->addAlternateClassName("KTextEdit", true/*override*/);
 	wi->setIncludeFileName("ktextedit.h");
 	wi->setName(i18n("Text Editor"));
@@ -126,10 +126,10 @@ KexiDBFactory::KexiDBFactory(TQObject *parent, const char *name, const TQStringL
 	addClass(wi);
 
 	wi = new KFormDesigner::WidgetInfo(
-		this, "containers", TQFRAME_OBJECT_NAME_STRING /*we're inheriting to get i18n'd strings already translated there*/);
+		this, "containers", "TQFrame" /*we're inheriting to get i18n'd strings already translated there*/);
 	wi->setPixmap("frame");
 	wi->setClassName("KexiFrame");
-	wi->addAlternateClassName(TQFRAME_OBJECT_NAME_STRING, true/*override*/);
+	wi->addAlternateClassName("TQFrame", true/*override*/);
 	wi->setName(i18n("Frame"));
 	wi->setNamePrefix(
 		i18n("Widget name. This string will be used to name widgets of this class. "
@@ -138,10 +138,10 @@ KexiDBFactory::KexiDBFactory(TQObject *parent, const char *name, const TQStringL
 	addClass(wi);
 
 	wi = new KexiDataAwareWidgetInfo(
-		this, "stdwidgets", TQLABEL_OBJECT_NAME_STRING /*we're inheriting to get i18n'd strings already translated there*/);
+		this, "stdwidgets", "TQLabel" /*we're inheriting to get i18n'd strings already translated there*/);
 	wi->setPixmap("label");
 	wi->setClassName("KexiDBLabel");
-	wi->addAlternateClassName(TQLABEL_OBJECT_NAME_STRING, true/*override*/);
+	wi->addAlternateClassName("TQLabel", true/*override*/);
 	wi->addAlternateClassName("KexiLabel", true/*override*/); //older
 	wi->setName(i18n("Text Label", "Label"));
 	wi->setNamePrefix(
@@ -184,10 +184,10 @@ KexiDBFactory::KexiDBFactory(TQObject *parent, const char *name, const TQStringL
 	addClass(wi);
 #endif
 
-	wi = new KexiDataAwareWidgetInfo(this, "stdwidgets", TQCHECKBOX_OBJECT_NAME_STRING);
+	wi = new KexiDataAwareWidgetInfo(this, "stdwidgets", "TQCheckBox");
 	wi->setPixmap("check");
 	wi->setClassName("KexiDBCheckBox");
-	wi->addAlternateClassName(TQCHECKBOX_OBJECT_NAME_STRING, true/*override*/);
+	wi->addAlternateClassName("TQCheckBox", true/*override*/);
 	wi->setName(i18n("Check Box"));
 	wi->setNamePrefix(
 		i18n("Widget name. This string will be used to name widgets of this class. "
@@ -213,11 +213,11 @@ KexiDBFactory::KexiDBFactory(TQObject *parent, const char *name, const TQStringL
 #if TDE_VERSION >= TDE_MAKE_VERSION(3,1,9)
 	KexiDataAwareWidgetInfo *wDate = new KexiDataAwareWidgetInfo(this, "stdwidgets", "KDateWidget");
 #else
-	KexiDataAwareWidgetInfo *wDate = new KexiDataAwareWidgetInfo(this, "stdwidgets", TQDATEEDIT_OBJECT_NAME_STRING);
+	KexiDataAwareWidgetInfo *wDate = new KexiDataAwareWidgetInfo(this, "stdwidgets", "TQDateEdit");
 #endif
 	wDate->setPixmap("dateedit");
 	wDate->setClassName("KexiDBDateEdit");
-	wDate->addAlternateClassName(TQDATEEDIT_OBJECT_NAME_STRING, true);//override
+	wDate->addAlternateClassName("TQDateEdit", true);//override
 	wDate->addAlternateClassName("KDateWidget", true);//override
 	wDate->setName(i18n("Date Widget"));
 	wDate->setNamePrefix(
@@ -228,11 +228,11 @@ KexiDBFactory::KexiDBFactory(TQObject *parent, const char *name, const TQStringL
 #if TDE_VERSION >= TDE_MAKE_VERSION(3,1,9)
 	KexiDataAwareWidgetInfo *wTime = new KexiDataAwareWidgetInfo(this, "stdwidgets", "KTimeWidget");
 #else
-	KexiDataAwareWidgetInfo *wTime = new KexiDataAwareWidgetInfo(this, "stdwidgets", TQTIMEEDIT_OBJECT_NAME_STRING);
+	KexiDataAwareWidgetInfo *wTime = new KexiDataAwareWidgetInfo(this, "stdwidgets", "TQTimeEdit");
 #endif
 	wTime->setPixmap("timeedit");
 	wTime->setClassName("KexiDBTimeEdit");
-	wTime->addAlternateClassName(TQTIMEEDIT_OBJECT_NAME_STRING, true);//override
+	wTime->addAlternateClassName("TQTimeEdit", true);//override
 	wTime->addAlternateClassName("KTimeWidget", true);//override
 	wTime->setName(i18n("Time Widget"));
 	wTime->setNamePrefix(
@@ -247,7 +247,7 @@ KexiDBFactory::KexiDBFactory(TQObject *parent, const char *name, const TQStringL
 #endif
 	wDateTime->setPixmap("datetimeedit");
 	wDateTime->setClassName("KexiDBDateTimeEdit");
-	wDateTime->addAlternateClassName(TQDATETIMEEDIT_OBJECT_NAME_STRING, true);//override
+	wDateTime->addAlternateClassName("TQDateTimeEdit", true);//override
 	wDateTime->addAlternateClassName("KDateTimeWidget", true);//override
 	wDateTime->setName(i18n("Date/Time Widget"));
 	wDateTime->setNamePrefix(
@@ -259,7 +259,7 @@ KexiDBFactory::KexiDBFactory(TQObject *parent, const char *name, const TQStringL
 /*	KexiDataAwareWidgetInfo *wIntSpinBox = new KexiDataAwareWidgetInfo(this, "stdwidgets", "KIntSpinBox");
 	wIntSpinBox->setPixmap("spin");
 	wIntSpinBox->setClassName("KexiDBIntSpinBox");
-	wIntSpinBox->addAlternateClassName(TQSPINBOX_OBJECT_NAME_STRING, true);
+	wIntSpinBox->addAlternateClassName("TQSpinBox", true);
 	wIntSpinBox->addAlternateClassName("KIntSpinBox", true);
 	wIntSpinBox->setName(i18n("Integer Number Spin Box"));
 	wIntSpinBox->setNamePrefix(
@@ -374,7 +374,7 @@ KexiDBFactory::createWidget(const TQCString &c, TQWidget *p, const char *n,
 		if (designMode)
 			w->setCursor(TQCursor(TQt::ArrowCursor));
 	}
-	else if(c == TQFRAME_OBJECT_NAME_STRING || c == "KexiFrame")
+	else if(c == "TQFrame" || c == "KexiFrame")
 	{
 		w = new KexiFrame(p, n);
 		new KFormDesigner::Container(container, w, container);
@@ -384,7 +384,7 @@ KexiDBFactory::createWidget(const TQCString &c, TQWidget *p, const char *n,
 #ifndef KEXI_NO_IMAGEBOX_WIDGET
 	else if(c == "KexiDBImageBox") {
 		w = new KexiDBImageBox(designMode, p, n);
-		connect(w, TQT_SIGNAL(idChanged(long)), this, TQT_SLOT(slotImageBoxIdChanged(long)));
+		connect(w, TQ_SIGNAL(idChanged(long)), this, TQ_SLOT(slotImageBoxIdChanged(long)));
 	}
 #endif
 #ifndef KEXI_NO_AUTOFIELD_WIDGET
@@ -415,7 +415,7 @@ bool
 KexiDBFactory::createMenuActions(const TQCString &classname, TQWidget *w, TQPopupMenu *menu,
 		   KFormDesigner::Container *)
 {
-	if(classname == TQPUSHBUTTON_OBJECT_NAME_STRING || classname == "KPushButton" || classname == "KexiPushButton")
+	if(classname == "TQPushButton" || classname == "KPushButton" || classname == "KexiPushButton")
 	{
 /*! @todo also call createMenuActions() for inherited factory! */
 		m_assignAction->plug( menu );
