@@ -174,14 +174,14 @@ void KexiFormEventHandler::setMainWidgetForEventHandling(KexiMainWindow *mainWin
 			TDEAction *action = mainWin->actionCollection()->action( actionArg.latin1() );
 			if (!action)
 				continue;
-			TQObject::disconnect( obj, TQT_SIGNAL(clicked()), action, TQT_SLOT(activate()) ); //safety
-			TQObject::connect( obj, TQT_SIGNAL(clicked()), action, TQT_SLOT(activate()) );
+			TQObject::disconnect( obj, TQ_SIGNAL(clicked()), action, TQ_SLOT(activate()) ); //safety
+			TQObject::connect( obj, TQ_SIGNAL(clicked()), action, TQ_SLOT(activate()) );
 		}
 		else if (partInfo) { //'open or execute' action
 			KexiFormEventAction* action = new KexiFormEventAction(mainWin, obj, actionType, actionArg, 
 				data.option);
-			TQObject::disconnect( obj, TQT_SIGNAL(clicked()), action, TQT_SLOT(activate()) );
-			TQObject::connect( obj, TQT_SIGNAL(clicked()), action, TQT_SLOT(activate()) );
+			TQObject::disconnect( obj, TQ_SIGNAL(clicked()), action, TQ_SLOT(activate()) );
+			TQObject::connect( obj, TQ_SIGNAL(clicked()), action, TQ_SLOT(activate()) );
 		}
 	}
 	delete l;
