@@ -91,67 +91,67 @@ KexiFormView::KexiFormView(KexiMainWindow *mainWin, TQWidget *parent,
 	if (viewMode()==Kexi::DataViewMode) {
 		m_scrollView->recordNavigator()->setRecordHandler( m_scrollView );
 		m_scrollView->viewport()->setPaletteBackgroundColor(m_dbform->palette().active().background());
-//moved to formmanager		connect(formPart()->manager(), TQT_SIGNAL(noFormSelected()), TQT_SLOT(slotNoFormSelected()));
+//moved to formmanager		connect(formPart()->manager(), TQ_SIGNAL(noFormSelected()), TQ_SLOT(slotNoFormSelected()));
 	}
 	else
 	{
-		connect(KFormDesigner::FormManager::self(), TQT_SIGNAL(propertySetSwitched(KoProperty::Set*, bool, const TQCString&)),
-			this, TQT_SLOT(slotPropertySetSwitched(KoProperty::Set*, bool, const TQCString&)));
-		connect(KFormDesigner::FormManager::self(), TQT_SIGNAL(dirty(KFormDesigner::Form *, bool)),
-			this, TQT_SLOT(slotDirty(KFormDesigner::Form *, bool)));
+		connect(KFormDesigner::FormManager::self(), TQ_SIGNAL(propertySetSwitched(KoProperty::Set*, bool, const TQCString&)),
+			this, TQ_SLOT(slotPropertySetSwitched(KoProperty::Set*, bool, const TQCString&)));
+		connect(KFormDesigner::FormManager::self(), TQ_SIGNAL(dirty(KFormDesigner::Form *, bool)),
+			this, TQ_SLOT(slotDirty(KFormDesigner::Form *, bool)));
 
-		connect(m_dbform, TQT_SIGNAL(handleDragMoveEvent(TQDragMoveEvent*)), 
-			this, TQT_SLOT(slotHandleDragMoveEvent(TQDragMoveEvent*)));
-		connect(m_dbform, TQT_SIGNAL(handleDropEvent(TQDropEvent*)), 
-			this, TQT_SLOT(slotHandleDropEvent(TQDropEvent*)));
+		connect(m_dbform, TQ_SIGNAL(handleDragMoveEvent(TQDragMoveEvent*)), 
+			this, TQ_SLOT(slotHandleDragMoveEvent(TQDragMoveEvent*)));
+		connect(m_dbform, TQ_SIGNAL(handleDropEvent(TQDropEvent*)), 
+			this, TQ_SLOT(slotHandleDropEvent(TQDropEvent*)));
 
 		// action stuff
-		plugSharedAction("formpart_taborder", KFormDesigner::FormManager::self(), TQT_SLOT(editTabOrder()));
-		plugSharedAction("formpart_adjust_size", KFormDesigner::FormManager::self(), TQT_SLOT(adjustWidgetSize()));
-//TODO		plugSharedAction("formpart_pixmap_collection", formPart()->manager(), TQT_SLOT(editFormPixmapCollection()));
-//TODO		plugSharedAction("formpart_connections", formPart()->manager(), TQT_SLOT(editConnections()));
+		plugSharedAction("formpart_taborder", KFormDesigner::FormManager::self(), TQ_SLOT(editTabOrder()));
+		plugSharedAction("formpart_adjust_size", KFormDesigner::FormManager::self(), TQ_SLOT(adjustWidgetSize()));
+//TODO		plugSharedAction("formpart_pixmap_collection", formPart()->manager(), TQ_SLOT(editFormPixmapCollection()));
+//TODO		plugSharedAction("formpart_connections", formPart()->manager(), TQ_SLOT(editConnections()));
 
-		plugSharedAction("edit_copy", KFormDesigner::FormManager::self(), TQT_SLOT(copyWidget()));
-		plugSharedAction("edit_cut", KFormDesigner::FormManager::self(), TQT_SLOT(cutWidget()));
-		plugSharedAction("edit_paste", KFormDesigner::FormManager::self(), TQT_SLOT(pasteWidget()));
-		plugSharedAction("edit_delete", KFormDesigner::FormManager::self(), TQT_SLOT(deleteWidget()));
-		plugSharedAction("edit_select_all", KFormDesigner::FormManager::self(), TQT_SLOT(selectAll()));
-		plugSharedAction("formpart_clear_contents", KFormDesigner::FormManager::self(), TQT_SLOT(clearWidgetContent()));
-		plugSharedAction("edit_undo", KFormDesigner::FormManager::self(), TQT_SLOT(undo()));
-		plugSharedAction("edit_redo", KFormDesigner::FormManager::self(), TQT_SLOT(redo()));
+		plugSharedAction("edit_copy", KFormDesigner::FormManager::self(), TQ_SLOT(copyWidget()));
+		plugSharedAction("edit_cut", KFormDesigner::FormManager::self(), TQ_SLOT(cutWidget()));
+		plugSharedAction("edit_paste", KFormDesigner::FormManager::self(), TQ_SLOT(pasteWidget()));
+		plugSharedAction("edit_delete", KFormDesigner::FormManager::self(), TQ_SLOT(deleteWidget()));
+		plugSharedAction("edit_select_all", KFormDesigner::FormManager::self(), TQ_SLOT(selectAll()));
+		plugSharedAction("formpart_clear_contents", KFormDesigner::FormManager::self(), TQ_SLOT(clearWidgetContent()));
+		plugSharedAction("edit_undo", KFormDesigner::FormManager::self(), TQ_SLOT(undo()));
+		plugSharedAction("edit_redo", KFormDesigner::FormManager::self(), TQ_SLOT(redo()));
 
 		plugSharedAction("formpart_layout_menu", KFormDesigner::FormManager::self(), 0 );
-		plugSharedAction("formpart_layout_hbox", KFormDesigner::FormManager::self(), TQT_SLOT(layoutHBox()) );
-		plugSharedAction("formpart_layout_vbox", KFormDesigner::FormManager::self(), TQT_SLOT(layoutVBox()) );
-		plugSharedAction("formpart_layout_grid", KFormDesigner::FormManager::self(), TQT_SLOT(layoutGrid()) );
+		plugSharedAction("formpart_layout_hbox", KFormDesigner::FormManager::self(), TQ_SLOT(layoutHBox()) );
+		plugSharedAction("formpart_layout_vbox", KFormDesigner::FormManager::self(), TQ_SLOT(layoutVBox()) );
+		plugSharedAction("formpart_layout_grid", KFormDesigner::FormManager::self(), TQ_SLOT(layoutGrid()) );
 #ifdef KEXI_SHOW_SPLITTER_WIDGET
-		plugSharedAction("formpart_layout_hsplitter", KFormDesigner::FormManager::self(), TQT_SLOT(layoutHSplitter()) );
-		plugSharedAction("formpart_layout_vsplitter", KFormDesigner::FormManager::self(), TQT_SLOT(layoutVSplitter()) );
+		plugSharedAction("formpart_layout_hsplitter", KFormDesigner::FormManager::self(), TQ_SLOT(layoutHSplitter()) );
+		plugSharedAction("formpart_layout_vsplitter", KFormDesigner::FormManager::self(), TQ_SLOT(layoutVSplitter()) );
 #endif
-		plugSharedAction("formpart_break_layout", KFormDesigner::FormManager::self(), TQT_SLOT(breakLayout()) );
+		plugSharedAction("formpart_break_layout", KFormDesigner::FormManager::self(), TQ_SLOT(breakLayout()) );
 
-		plugSharedAction("formpart_format_raise", KFormDesigner::FormManager::self(), TQT_SLOT(bringWidgetToFront()) );
-		plugSharedAction("formpart_format_lower", KFormDesigner::FormManager::self(), TQT_SLOT(sendWidgetToBack()) );
+		plugSharedAction("formpart_format_raise", KFormDesigner::FormManager::self(), TQ_SLOT(bringWidgetToFront()) );
+		plugSharedAction("formpart_format_lower", KFormDesigner::FormManager::self(), TQ_SLOT(sendWidgetToBack()) );
 
 		plugSharedAction("other_widgets_menu", KFormDesigner::FormManager::self(), 0 );
 		setAvailable("other_widgets_menu", true);
 
 		plugSharedAction("formpart_align_menu", KFormDesigner::FormManager::self(), 0 );
-		plugSharedAction("formpart_align_to_left", KFormDesigner::FormManager::self(),TQT_SLOT(alignWidgetsToLeft()) );
-		plugSharedAction("formpart_align_to_right", KFormDesigner::FormManager::self(), TQT_SLOT(alignWidgetsToRight()) );
-		plugSharedAction("formpart_align_to_top", KFormDesigner::FormManager::self(), TQT_SLOT(alignWidgetsToTop()) );
-		plugSharedAction("formpart_align_to_bottom", KFormDesigner::FormManager::self(), TQT_SLOT(alignWidgetsToBottom()) );
-		plugSharedAction("formpart_align_to_grid", KFormDesigner::FormManager::self(), TQT_SLOT(alignWidgetsToGrid()) );
+		plugSharedAction("formpart_align_to_left", KFormDesigner::FormManager::self(),TQ_SLOT(alignWidgetsToLeft()) );
+		plugSharedAction("formpart_align_to_right", KFormDesigner::FormManager::self(), TQ_SLOT(alignWidgetsToRight()) );
+		plugSharedAction("formpart_align_to_top", KFormDesigner::FormManager::self(), TQ_SLOT(alignWidgetsToTop()) );
+		plugSharedAction("formpart_align_to_bottom", KFormDesigner::FormManager::self(), TQ_SLOT(alignWidgetsToBottom()) );
+		plugSharedAction("formpart_align_to_grid", KFormDesigner::FormManager::self(), TQ_SLOT(alignWidgetsToGrid()) );
 
 		plugSharedAction("formpart_adjust_size_menu", KFormDesigner::FormManager::self(), 0 );
-		plugSharedAction("formpart_adjust_to_fit", KFormDesigner::FormManager::self(), TQT_SLOT(adjustWidgetSize()) );
-		plugSharedAction("formpart_adjust_size_grid", KFormDesigner::FormManager::self(), TQT_SLOT(adjustSizeToGrid()) );
-		plugSharedAction("formpart_adjust_height_small", KFormDesigner::FormManager::self(),  TQT_SLOT(adjustHeightToSmall()) );
-		plugSharedAction("formpart_adjust_height_big", KFormDesigner::FormManager::self(), TQT_SLOT(adjustHeightToBig()) );
-		plugSharedAction("formpart_adjust_width_small", KFormDesigner::FormManager::self(), TQT_SLOT(adjustWidthToSmall()) );
-		plugSharedAction("formpart_adjust_width_big", KFormDesigner::FormManager::self(), TQT_SLOT(adjustWidthToBig()) );
+		plugSharedAction("formpart_adjust_to_fit", KFormDesigner::FormManager::self(), TQ_SLOT(adjustWidgetSize()) );
+		plugSharedAction("formpart_adjust_size_grid", KFormDesigner::FormManager::self(), TQ_SLOT(adjustSizeToGrid()) );
+		plugSharedAction("formpart_adjust_height_small", KFormDesigner::FormManager::self(),  TQ_SLOT(adjustHeightToSmall()) );
+		plugSharedAction("formpart_adjust_height_big", KFormDesigner::FormManager::self(), TQ_SLOT(adjustHeightToBig()) );
+		plugSharedAction("formpart_adjust_width_small", KFormDesigner::FormManager::self(), TQ_SLOT(adjustWidthToSmall()) );
+		plugSharedAction("formpart_adjust_width_big", KFormDesigner::FormManager::self(), TQ_SLOT(adjustWidthToBig()) );
 
-		plugSharedAction("format_font", KFormDesigner::FormManager::self(), TQT_SLOT(changeFont()) );
+		plugSharedAction("format_font", KFormDesigner::FormManager::self(), TQ_SLOT(changeFont()) );
 	}
 
 	initForm();
@@ -159,7 +159,7 @@ KexiFormView::KexiFormView(KexiMainWindow *mainWin, TQWidget *parent,
 	KexiDataAwareView::init( m_scrollView, m_scrollView, m_scrollView,
 		/* skip data-awarness if design mode */ viewMode()==Kexi::DesignViewMode );
 
-	connect(this, TQT_SIGNAL(focus(bool)), this, TQT_SLOT(slotFocus(bool)));
+	connect(this, TQ_SIGNAL(focus(bool)), this, TQ_SLOT(slotFocus(bool)));
 	/// @todo skip this if ther're no borders
 //	m_dbform->resize( m_dbform->size()+TQSize(m_scrollView->verticalScrollBar()->width(), m_scrollView->horizontalScrollBar()->height()) );
 }
@@ -225,8 +225,8 @@ KexiFormView::initForm()
 
 	if (viewMode()==Kexi::DesignViewMode) {
 		//we want to be informed about executed commands
-		connect(form()->commandHistory(), TQT_SIGNAL(commandExecuted()),
-			KFormDesigner::FormManager::self(), TQT_SLOT(slotHistoryCommandExecuted()));
+		connect(form()->commandHistory(), TQ_SIGNAL(commandExecuted()),
+			KFormDesigner::FormManager::self(), TQ_SLOT(slotHistoryCommandExecuted()));
 	}
 
 	const bool newForm = parentDialog()->id() < 0;
@@ -340,8 +340,8 @@ void KexiFormView::updateValuesForSubproperties()
 			= dynamic_cast<KFormDesigner::WidgetWithSubpropertiesInterface*>( it.current()->widget() );
 		if (subpropIface && subpropIface->subwidget() && it.current()->subproperties() ) {
 			TQWidget *subwidget = subpropIface->subwidget();
-			TQMap<TQString, TQVariant>* subprops = it.current()->subproperties();
-			for (TQMapConstIterator<TQString, TQVariant> subpropIt = subprops->constBegin(); subpropIt!=subprops->constEnd(); ++subpropIt) {
+			TQStringVariantMap* subprops = it.current()->subproperties();
+			for (TQStringVariantMapConstIterator subpropIt = subprops->constBegin(); subpropIt!=subprops->constEnd(); ++subpropIt) {
 				kexipluginsdbg << "KexiFormView::loadForm(): delayed setting of the subproperty: widget="
 					<< it.current()->widget()->name() << " prop=" << subpropIt.key() << " val=" << subpropIt.data() << endl;
 
@@ -374,7 +374,7 @@ static void setUnsavedBLOBIdsForDataViewMode(
 	if (-1 != widget->metaObject()->findProperty("pixmapId")) {
 		const KexiBLOBBuffer::Id_t blobID = unsavedLocalBLOBsByName[ widget->name() ];
 		if (blobID > 0)
-			widget->setProperty("pixmapId", (uint /* KexiBLOBBuffer::Id_t is unsafe and unsupported by TQVariant - will be fixed in TQt4*/)blobID);
+			widget->setProperty("pixmapId", (uint)blobID);
 	}
 	const TQObjectList list = widget->childrenListObject();
 	if (list.isEmpty())
@@ -803,11 +803,11 @@ KexiFormView::storeData(bool dontAsk)
 				return false;
 			}
 			kexipluginsdbg << " storedDataID=" << storedBLOBID << endl;
-			h.setStoredWidthID((KexiBLOBBuffer::Id_t /*unsafe - will be fixed in TQt4*/)storedBLOBID);
+			h.setStoredWidthID((KexiBLOBBuffer::Id_t)storedBLOBID);
 			//set widget's internal property so it can be saved...
 			const TQVariant oldStoredPixmapId( it.key()->property("storedPixmapId") );
 			it.key()->setProperty("storedPixmapId", 
-				TQVariant((uint /* KexiBLOBBuffer::Id_t is unsafe and unsupported by TQVariant - will be fixed in TQt4*/)storedBLOBID));
+				TQVariant((uint)storedBLOBID));
 			KFormDesigner::ObjectTreeItem *widgetItem = designFormView->form()->objectTree()->lookup(it.key()->name()); //form()->objectTree()->lookup(it.key()->name());
 			if (widgetItem)
 				widgetItem->addModifiedProperty( "storedPixmapId", oldStoredPixmapId );
