@@ -42,7 +42,7 @@ class KEXIFORMUTILS_EXPORT KexiDBForm :
 	public KFormDesigner::FormWidget,
 	public KexiFormDataItemInterface
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	TQ_PROPERTY(TQString dataSource READ dataSource WRITE setDataSource DESIGNABLE true)
 	TQ_PROPERTY(TQCString dataSourceMimeType READ dataSourceMimeType WRITE setDataSourceMimeType DESIGNABLE true)
