@@ -190,7 +190,7 @@ KexiCSVImportDialog::KexiCSVImportDialog( Mode mode, KexiMainWindow* mainWin,
 	m_uniquenessTest.setAutoDelete(true);
 
 	setIcon(DesktopIcon(_IMPORT_ICON));
-	setSizeGripEnabled( TRUE );
+	setSizeGripEnabled( true );
 
 //	m_encoding = TQString::fromLatin1(TDEGlobal::locale()->encoding());
 //	m_stripWhiteSpaceInTextValuesChecked = true;
