@@ -28,7 +28,7 @@ class TQVBox;
 
 class KexiDynamicQueryParameterDialog : public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KexiDynamicQueryParameterDialog(TQWidget *parent,KexiDataProvider::Parameters *, const KexiDataProvider::ParameterList &);
