@@ -104,11 +104,11 @@ KexiQueryDesignerSQLView::KexiQueryDesignerSQLView(KexiMainWindow *mainWin, TQWi
  , d( new Private() )
 {
 	d->splitter = new TQSplitter(this);
-	d->splitter->setOrientation(Qt::Vertical);
-	d->head = new KexiSectionHeader(i18n("SQL Query Text"),Qt::Vertical, d->splitter);
+	d->splitter->setOrientation(TQt::Vertical);
+	d->head = new KexiSectionHeader(i18n("SQL Query Text"),TQt::Vertical, d->splitter);
 	d->editor = new KexiQueryDesignerSQLEditor(mainWin, d->head, "sqle");
 //	d->editor->installEventFilter(this);//for keys
-	connect(d->editor, TQT_SIGNAL(textChanged()), TQT_TQOBJECT(this), TQT_SLOT(slotTextChanged()));
+	connect(d->editor, TQ_SIGNAL(textChanged()), this, TQ_SLOT(slotTextChanged()));
 	addChildView(d->editor);
 	setViewWidget(d->editor);
 	d->splitter->setFocusProxy(d->editor);
@@ -136,21 +136,21 @@ KexiQueryDesignerSQLView::KexiQueryDesignerSQLView(KexiMainWindow *mainWin, TQWi
 	TQHBoxLayout *b = new TQHBoxLayout(this);
 	b->addWidget(d->splitter);
 
-	plugSharedAction("querypart_check_query", TQT_TQOBJECT(this), TQT_SLOT(slotCheckQuery())); 
-	plugSharedAction("querypart_view_toggle_history", TQT_TQOBJECT(this), TQT_SLOT(slotUpdateMode()));
+	plugSharedAction("querypart_check_query", this, TQ_SLOT(slotCheckQuery())); 
+	plugSharedAction("querypart_view_toggle_history", this, TQ_SLOT(slotUpdateMode()));
 	d->action_toggle_history = static_cast<TDEToggleAction*>( sharedAction( "querypart_view_toggle_history" ) );
 
-	d->historyHead = new KexiSectionHeader(i18n("SQL Query History"),Qt::Vertical, d->history_section);
+	d->historyHead = new KexiSectionHeader(i18n("SQL Query History"),TQt::Vertical, d->history_section);
 	d->historyHead->installEventFilter(this);
 	d->history = new KexiQueryDesignerSQLHistory(d->historyHead, "sql_history");
 
 	static const TQString msg_back = i18n("Back to Selected Query");
 	static const TQString msg_clear = i18n("Clear History");
-	d->historyHead->addButton("select_item", msg_back, TQT_TQOBJECT(this), TQT_SLOT(slotSelectQuery()));
-	d->historyHead->addButton("edit-clear", msg_clear, TQT_TQOBJECT(d->history), TQT_SLOT(clear()));
-	d->history->popupMenu()->insertItem(SmallIcon("select_item"), msg_back, TQT_TQOBJECT(this), TQT_SLOT(slotSelectQuery()));
-	d->history->popupMenu()->insertItem(SmallIcon("edit-clear"), msg_clear, d->history, TQT_SLOT(clear()));
-	connect(d->history, TQT_SIGNAL(currentItemDoubleClicked()), TQT_TQOBJECT(this), TQT_SLOT(slotSelectQuery()));
+	d->historyHead->addButton("select_item", msg_back, this, TQ_SLOT(slotSelectQuery()));
+	d->historyHead->addButton("edit-clear", msg_clear, d->history, TQ_SLOT(clear()));
+	d->history->popupMenu()->insertItem(SmallIcon("select_item"), msg_back, this, TQ_SLOT(slotSelectQuery()));
+	d->history->popupMenu()->insertItem(SmallIcon("edit-clear"), msg_clear, d->history, TQ_SLOT(clear()));
+	connect(d->history, TQ_SIGNAL(currentItemDoubleClicked()), this, TQ_SLOT(slotSelectQuery()));
 
 	d->heightForHistoryMode = -1; //height() / 2;
 	//d->historyHead->hide();
@@ -320,7 +320,7 @@ KexiQueryDesignerSQLView::afterSwitchFrom(int mode)
 	d->slotTextChangedEnabled = false;
 	 d->editor->setText( d->origStatement );
 	d->slotTextChangedEnabled = true;
-	TQTimer::singleShot(100, d->editor, TQT_SLOT(setFocus()));
+	TQTimer::singleShot(100, d->editor, TQ_SLOT(setFocus()));
 	return true;
 }
 
@@ -410,10 +410,10 @@ void KexiQueryDesignerSQLView::slotTextChanged()
 bool KexiQueryDesignerSQLView::eventFilter( TQObject *o, TQEvent *e )
 {
 	if (d->eventFilterForSplitterEnabled) {
-		if (e->type()==TQEvent::Resize && o && TQT_BASE_OBJECT(o)==TQT_BASE_OBJECT(d->historyHead) && d->historyHead->isVisible()) {
+		if (e->type()==TQEvent::Resize && o && o==d->historyHead && d->historyHead->isVisible()) {
 			d->heightForHistoryMode = d->historyHead->height();
 		}
-		else if (e->type()==TQEvent::Resize && o && TQT_BASE_OBJECT(o)==TQT_BASE_OBJECT(d->status_hbox) && d->status_hbox->isVisible()) {
+		else if (e->type()==TQEvent::Resize && o && o==d->status_hbox && d->status_hbox->isVisible()) {
 			d->heightForStatusMode = d->status_hbox->height();
 		}
 	}
