@@ -93,7 +93,7 @@ void KexiTablePart::initInstanceActions()
 
 KexiDialogTempData* KexiTablePart::createTempData(KexiDialogBase* dialog)
 {
-	return new KexiTablePart::TempData(TQT_TQOBJECT(dialog));
+	return new KexiTablePart::TempData(dialog);
 }
 
 KexiViewBase* KexiTablePart::createView(TQWidget *parent, KexiDialogBase* dialog, 
@@ -222,18 +222,18 @@ void KexiTablePart::setupCustomPropertyPanelTabs(KTabWidget *tab, KexiMainWindow
 {
 	if (!d->lookupColumnPage) {
 		d->lookupColumnPage = new KexiLookupColumnPage(0);
-		connect(d->lookupColumnPage, TQT_SIGNAL(jumpToObjectRequested(const TQCString&, const TQCString&)),
-			mainWin, TQT_SLOT(highlightObject(const TQCString&, const TQCString&)));
+		connect(d->lookupColumnPage, TQ_SIGNAL(jumpToObjectRequested(const TQCString&, const TQCString&)),
+			mainWin, TQ_SLOT(highlightObject(const TQCString&, const TQCString&)));
 
 //! @todo add "Table" tab
 
 	/*
-		connect(d->dataSourcePage, TQT_SIGNAL(formDataSourceChanged(const TQCString&, const TQCString&)),
-			KFormDesigner::FormManager::self(), TQT_SLOT(setFormDataSource(const TQCString&, const TQCString&)));
-		connect(d->dataSourcePage, TQT_SIGNAL(dataSourceFieldOrExpressionChanged(const TQString&, const TQString&, KexiDB::Field::Type)),
-			KFormDesigner::FormManager::self(), TQT_SLOT(setDataSourceFieldOrExpression(const TQString&, const TQString&, KexiDB::Field::Type)));
-		connect(d->dataSourcePage, TQT_SIGNAL(insertAutoFields(const TQString&, const TQString&, const TQStringList&)),
-			KFormDesigner::FormManager::self(), TQT_SLOT(insertAutoFields(const TQString&, const TQString&, const TQStringList&)));*/
+		connect(d->dataSourcePage, TQ_SIGNAL(formDataSourceChanged(const TQCString&, const TQCString&)),
+			KFormDesigner::FormManager::self(), TQ_SLOT(setFormDataSource(const TQCString&, const TQCString&)));
+		connect(d->dataSourcePage, TQ_SIGNAL(dataSourceFieldOrExpressionChanged(const TQString&, const TQString&, KexiDB::Field::Type)),
+			KFormDesigner::FormManager::self(), TQ_SLOT(setDataSourceFieldOrExpression(const TQString&, const TQString&, KexiDB::Field::Type)));
+		connect(d->dataSourcePage, TQ_SIGNAL(insertAutoFields(const TQString&, const TQString&, const TQStringList&)),
+			KFormDesigner::FormManager::self(), TQ_SLOT(insertAutoFields(const TQString&, const TQString&, const TQStringList&)));*/
 	}
 
 	KexiProject *prj = mainWin->project();
