@@ -67,7 +67,7 @@ int main(int argc, char** argv)
   vbLayout->addWidget(quit);
 
   // Show the whole lot
-  TQObject::connect(quit, TQT_SIGNAL(clicked()), app, TQT_SLOT(quit()));
+  TQObject::connect(quit, TQ_SIGNAL(clicked()), app, TQ_SLOT(quit()));
   vbox->show();
   app->exec();
 
