@@ -91,7 +91,7 @@ KexiBrowser::KexiBrowser(TQWidget* parent, KexiMainWindow *mainWin, int features
 	lyr->addWidget(m_list);
 	m_list->installEventFilter(this);
 	m_list->renameLineEdit()->installEventFilter(this);
-	connect( kapp, TQT_SIGNAL( settingsChanged(int) ), TQT_SLOT( slotSettingsChanged(int) ) );
+	connect( kapp, TQ_SIGNAL( settingsChanged(int) ), TQ_SLOT( slotSettingsChanged(int) ) );
 	slotSettingsChanged(0);
 
 	m_list->header()->hide();
@@ -101,30 +101,30 @@ KexiBrowser::KexiBrowser(TQWidget* parent, KexiMainWindow *mainWin, int features
 	m_list->sort();
 	m_list->setAllColumnsShowFocus(true);
 	m_list->setTooltipColumn(0);
-	m_list->renameLineEdit()->setValidator( new KexiUtils::IdentifierValidator(TQT_TQOBJECT(this)) );
+	m_list->renameLineEdit()->setValidator( new KexiUtils::IdentifierValidator(this) );
 	m_list->setResizeMode(TQListView::LastColumn);
-	connect(m_list, TQT_SIGNAL(contextMenu(TDEListView *, TQListViewItem *, const TQPoint &)),
-		TQT_TQOBJECT(this), TQT_SLOT(slotContextMenu(TDEListView*, TQListViewItem *, const TQPoint&)));
-	connect(m_list, TQT_SIGNAL(selectionChanged(TQListViewItem*)), this,
-		TQT_SLOT(slotSelectionChanged(TQListViewItem*)));
+	connect(m_list, TQ_SIGNAL(contextMenu(TDEListView *, TQListViewItem *, const TQPoint &)),
+		this, TQ_SLOT(slotContextMenu(TDEListView*, TQListViewItem *, const TQPoint&)));
+	connect(m_list, TQ_SIGNAL(selectionChanged(TQListViewItem*)), this,
+		TQ_SLOT(slotSelectionChanged(TQListViewItem*)));
 	
 	TDEConfig *config = kapp->config();
 	config->setGroup("MainWindow");
 	if ((m_features & SingleClickOpensItemOptionEnabled) 
 		&& config->readBoolEntry("SingleClickOpensItem", false))
 	{
-		connect(m_list, TQT_SIGNAL(executed(TQListViewItem*)), this,
-			TQT_SLOT(slotExecuteItem(TQListViewItem*)));
+		connect(m_list, TQ_SIGNAL(executed(TQListViewItem*)), this,
+			TQ_SLOT(slotExecuteItem(TQListViewItem*)));
 	}
 	else {
-		connect(m_list, TQT_SIGNAL(doubleClicked(TQListViewItem*)), this,
-			TQT_SLOT(slotExecuteItem(TQListViewItem*)));
+		connect(m_list, TQ_SIGNAL(doubleClicked(TQListViewItem*)), this,
+			TQ_SLOT(slotExecuteItem(TQListViewItem*)));
 		m_list->enableExecuteArea = false;
 	}
 
 	// actions
-	m_openAction = new TDEAction(i18n("&Open"), "document-open", 0/*TQt::Key_Enter conflict!*/, TQT_TQOBJECT(this), 
-		TQT_SLOT(slotOpenObject()), TQT_TQOBJECT(this), "open_object");
+	m_openAction = new TDEAction(i18n("&Open"), "document-open", 0/*TQt::Key_Enter conflict!*/, this, 
+		TQ_SLOT(slotOpenObject()), this, "open_object");
 	m_openAction->setToolTip(i18n("Open object"));
 	m_openAction->setWhatsThis(i18n("Opens object selected in the list"));
 
@@ -146,20 +146,20 @@ KexiBrowser::KexiBrowser(TQWidget* parent, KexiMainWindow *mainWin, int features
 	}
 	else {
 		m_deleteAction = new TDEAction(i18n("&Delete"), "edit-delete", 0/*TQt::Key_Delete*/, 
-			TQT_TQOBJECT(this), TQT_SLOT(slotRemove()), m_actions, "edit_delete");
+			this, TQ_SLOT(slotRemove()), m_actions, "edit_delete");
 	//! @todo 1.1: just add "Delete" tooltip and what's this
 		m_deleteAction->setToolTip(i18n("&Delete").replace("&",""));
 
 		m_renameAction = new TDEAction(i18n("&Rename"), "", 0, 
-			TQT_TQOBJECT(this), TQT_SLOT(slotRename()), m_actions, "edit_rename");
+			this, TQ_SLOT(slotRename()), m_actions, "edit_rename");
 #ifdef KEXI_SHOW_UNIMPLEMENTED
-		//todo	plugSharedAction("edit_cut",TQT_SLOT(slotCut()));
-		//todo	plugSharedAction("edit_copy",TQT_SLOT(slotCopy()));
-		//todo	plugSharedAction("edit_paste",TQT_SLOT(slotPaste()));
+		//todo	plugSharedAction("edit_cut",TQ_SLOT(slotCut()));
+		//todo	plugSharedAction("edit_copy",TQ_SLOT(slotCopy()));
+		//todo	plugSharedAction("edit_paste",TQ_SLOT(slotPaste()));
 #endif
 
-		m_designAction = new TDEAction(i18n("&Design"), "edit", 0/*TQt::CTRL + TQt::Key_Enter conflict!*/, TQT_TQOBJECT(this), 
-			TQT_SLOT(slotDesignObject()), TQT_TQOBJECT(this), "design_object");
+		m_designAction = new TDEAction(i18n("&Design"), "edit", 0/*TQt::CTRL + TQt::Key_Enter conflict!*/, this, 
+			TQ_SLOT(slotDesignObject()), this, "design_object");
 		m_designAction->setToolTip(i18n("Design object"));
 		m_designAction->setWhatsThis(i18n("Starts designing of the object selected in the list"));
 		if (m_features & Toolbar) {
@@ -167,21 +167,21 @@ KexiBrowser::KexiBrowser(TQWidget* parent, KexiMainWindow *mainWin, int features
 			buttons_flyr->add(btn);
 		}
 
-		m_editTextAction = new TDEAction(i18n("Open in &Text View"), "", 0, TQT_TQOBJECT(this), 
-			TQT_SLOT(slotEditTextObject()), TQT_TQOBJECT(this), "editText_object");
+		m_editTextAction = new TDEAction(i18n("Open in &Text View"), "", 0, this, 
+			TQ_SLOT(slotEditTextObject()), this, "editText_object");
 		m_editTextAction->setToolTip(i18n("Open object in text view"));
 		m_editTextAction->setWhatsThis(i18n("Opens selected object in the list in text view"));
 
-		m_newObjectAction = new TDEAction("", "document-new", 0, TQT_TQOBJECT(this), TQT_SLOT(slotNewObject()), TQT_TQOBJECT(this), "new_object");
+		m_newObjectAction = new TDEAction("", "document-new", 0, this, TQ_SLOT(slotNewObject()), this, "new_object");
 		if (m_features & Toolbar) {
 			m_newObjectToolButton = new KexiSmallToolButton(this, "", TQIconSet(), "new_object");
 			m_newObjectPopup = new TDEPopupMenu(this, "newObjectPopup");
-			connect(m_newObjectPopup, TQT_SIGNAL(aboutToShow()), TQT_TQOBJECT(this), TQT_SLOT(slotNewObjectPopupAboutToShow()));
+			connect(m_newObjectPopup, TQ_SIGNAL(aboutToShow()), this, TQ_SLOT(slotNewObjectPopupAboutToShow()));
 		//	KexiPart::Part* part = Kexi::partManager().part("kexi/table");
 		//	m_newObjectPopup->insertItem( SmallIconSet(part->info()->createItemIcon()), part->instanceName() );
 			m_newObjectToolButton->setPopup(m_newObjectPopup);
 			m_newObjectToolButton->setPopupDelay(TQApplication::startDragTime());
-			connect(m_newObjectToolButton, TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(slotNewObject()));
+			connect(m_newObjectToolButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotNewObject()));
 			buttons_flyr->add(m_newObjectToolButton);
 
 			m_deleteObjectToolButton = new KexiSmallToolButton(this, m_deleteAction);
@@ -190,22 +190,22 @@ KexiBrowser::KexiBrowser(TQWidget* parent, KexiMainWindow *mainWin, int features
 		}
 	}
 
-	m_executeAction = new TDEAction(i18n("Execute"), "media-playback-start", 0, TQT_TQOBJECT(this),
-		TQT_SLOT(slotExecuteObject()), TQT_TQOBJECT(this), "data_execute");
+	m_executeAction = new TDEAction(i18n("Execute"), "media-playback-start", 0, this,
+		TQ_SLOT(slotExecuteObject()), this, "data_execute");
 
 	m_exportActionMenu = new TDEActionMenu(i18n("Export"));
 	m_dataExportAction = new TDEAction(i18n("Export->To File as Data &Table... ", "To &File as Data Table..."), 
-		"table", 0, TQT_TQOBJECT(this), TQT_SLOT(slotExportAsDataTable()), TQT_TQOBJECT(this), "exportAsDataTable");
+		"table", 0, this, TQ_SLOT(slotExportAsDataTable()), this, "exportAsDataTable");
 	m_dataExportAction->setWhatsThis(
 		i18n("Exports data from the currently selected table or query data to a file."));
 	m_exportActionMenu->insert( m_dataExportAction );
 
-	m_printAction = new TDEAction(i18n("&Print..."), "document-print", 0, TQT_TQOBJECT(this), 
-		TQT_SLOT(slotPrintItem()), TQT_TQOBJECT(this), "printItem");
+	m_printAction = new TDEAction(i18n("&Print..."), "document-print", 0, this, 
+		TQ_SLOT(slotPrintItem()), this, "printItem");
 	m_printAction->setWhatsThis(
 		i18n("Prints data from the currently selected table or query."));
-	m_pageSetupAction = new TDEAction(i18n("Page Setup..."), "", 0, TQT_TQOBJECT(this), 
-		TQT_SLOT(slotPageSetupForItem()), TQT_TQOBJECT(this), "pageSetupForItem");
+	m_pageSetupAction = new TDEAction(i18n("Page Setup..."), "", 0, this, 
+		TQ_SLOT(slotPageSetupForItem()), this, "pageSetupForItem");
 	m_pageSetupAction->setWhatsThis(
 		i18n("Shows page setup for printing the active table or query."));
 
@@ -553,21 +553,21 @@ void KexiBrowser::installEventFilter ( const TQObject * filterObj )
 {
 	if (!filterObj)
 		return;
-	m_list->installEventFilter ( const_cast<TQObject*>(filterObj) );
-	TQWidget::installEventFilter ( const_cast<TQObject*>(filterObj) );
+	m_list->installEventFilter ( filterObj );
+	TQWidget::installEventFilter ( filterObj );
 }
 
 bool KexiBrowser::eventFilter ( TQObject *o, TQEvent * e )
 {
-	if (TQT_BASE_OBJECT(o)==TQT_BASE_OBJECT(m_list) && e->type()==TQEvent::Resize) {
+	if (o==m_list && e->type()==TQEvent::Resize) {
 		kdDebug() << "resize!" << endl;
 	}
-	if (TQT_BASE_OBJECT(o)==TQT_BASE_OBJECT(m_list->renameLineEdit())) {
+	if (o==m_list->renameLineEdit()) {
 		if (e->type()==TQEvent::Hide) 
 			itemRenameDone();
 	}
 	else if (e->type()==TQEvent::KeyPress) {
-		TQKeyEvent *ke = TQT_TQKEYEVENT(e);
+		TQKeyEvent *ke = static_cast<TQKeyEvent*>(e);
 		if (ke->key()==TQt::Key_Enter || ke->key()==TQt::Key_Return) {
 			if (0==(ke->state() & (TQt::ShiftButton|TQt::ControlButton|TQt::AltButton))) {
 				TQListViewItem *it = m_list->selectedItem();
@@ -580,15 +580,15 @@ bool KexiBrowser::eventFilter ( TQObject *o, TQEvent * e )
 		}
 	}
 	else if (e->type()==TQEvent::AccelOverride) {
-		TQKeyEvent *ke = TQT_TQKEYEVENT(e);
+		TQKeyEvent *ke = static_cast<TQKeyEvent*>(e);
 		//override delete action
-		if (ke->key()==TQt::Key_Delete && ke->state()==Qt::NoButton) {
+		if (ke->key()==TQt::Key_Delete && ke->state()==TQt::NoButton) {
 			slotRemove();
 			ke->accept();
 			return true;
 		}
 		//override rename action
-		if (ke->key()==TQt::Key_F2 && ke->state()==Qt::NoButton) {
+		if (ke->key()==TQt::Key_F2 && ke->state()==TQt::NoButton) {
 			slotRename();
 			ke->accept();
 			return true;
