@@ -34,7 +34,7 @@ namespace KexiDB {
 */
 class KEXIEXTWIDGETS_EXPORT KexiFieldListView : public TDEListView
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
