@@ -61,7 +61,7 @@ TQValueList<TQVariant> KexiQueryParameters::getParameters(TQWidget *parent,
 				caption, (*it).message, list, 0/*current*/, false /*!editable*/, &ok, parent);
 			if (!ok || result.isEmpty())
 				return TQValueList<TQVariant>(); //cancelled
-			values.append( TQVariant( result==list.first(), 1 ) );
+			values.append( TQVariant( result==list.first() ) );
 			break;
 		}
 		case KexiDB::Field::Date: {
