@@ -49,8 +49,8 @@ KexiSmallToolButton::KexiSmallToolButton(TQWidget* parent, TDEAction* action)
  , m_action(action)
 {
 	init();
-	connect(this, TQT_SIGNAL(clicked()), action, TQT_SLOT(activate()));
-	connect(action, TQT_SIGNAL(enabled(bool)), this, TQT_SLOT(setEnabled(bool)));
+	connect(this, TQ_SIGNAL(clicked()), action, TQ_SLOT(activate()));
+	connect(action, TQ_SIGNAL(enabled(bool)), this, TQ_SLOT(setEnabled(bool)));
 	updateAction();
 }
 
@@ -124,7 +124,7 @@ void KexiSmallToolButton::drawButton( TQPainter *_painter )
 			arrowFlags |= TQStyle::Style_Down;
 		if (isEnabled())
 			arrowFlags |= TQStyle::Style_Enabled;
-		style().tqdrawPrimitive(TQStyle::PE_ArrowDown, _painter,
+		style().drawPrimitive(TQStyle::PE_ArrowDown, _painter,
 			TQRect(width()-7, height()-7, 5, 5), colorGroup(),
 			arrowFlags, TQStyleOption() );
 	}
