@@ -28,7 +28,7 @@ class TQIconSet;
 //! A small tool button with icon and optional text
 class KEXIEXTWIDGETS_EXPORT KexiSmallToolButton : public TQToolButton
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
