@@ -34,7 +34,7 @@ namespace KexiDB {
 //! Internal class for displaying popup table view 
 class KexiComboBoxPopup : public TQFrame
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 //js TODO: more ctors!
