@@ -54,7 +54,7 @@ namespace KexiDB {
 //! \brief The KexiDataAwareObjectInterface is an interface for record-based data object.
 /** This interface is implemented by KexiTableView and KexiFormView 
  and used by KexiDataAwareView. If yu're implementing this interface, 
- add KEXI_DATAAWAREOBJECTINTERFACE convenience macro just after Q_OBJECT.
+ add KEXI_DATAAWAREOBJECTINTERFACE convenience macro just after TQ_OBJECT.
 
  You should add following code to your destructor so data is deleted:
  \code
@@ -896,23 +896,23 @@ inline KexiTableItem *KexiDataAwareObjectInterface::itemAt(int row) const
 #define KEXI_DATAAWAREOBJECTINTERFACE \
 public: \
 	void connectCellSelectedSignal(const TQObject* receiver, const char* intIntMember) { \
-		connect(this, TQT_SIGNAL(cellSelected(int,int)), receiver, intIntMember); \
+		connect(this, TQ_SIGNAL(cellSelected(int,int)), receiver, intIntMember); \
 	} \
 	void connectRowEditStartedSignal(const TQObject* receiver, const char* intMember) { \
-		connect(this, TQT_SIGNAL(rowEditStarted(int)), receiver, intMember); \
+		connect(this, TQ_SIGNAL(rowEditStarted(int)), receiver, intMember); \
 	} \
 	void connectRowEditTerminatedSignal(const TQObject* receiver, const char* voidMember) { \
-		connect(this, TQT_SIGNAL(rowEditTerminated(int)), receiver, voidMember); \
+		connect(this, TQ_SIGNAL(rowEditTerminated(int)), receiver, voidMember); \
 	} \
 	void connectReloadActionsSignal(const TQObject* receiver, const char* voidMember) { \
-		connect(this, TQT_SIGNAL(reloadActions()), receiver, voidMember); \
+		connect(this, TQ_SIGNAL(reloadActions()), receiver, voidMember); \
 	} \
 	void connectDataSetSignal(const TQObject* receiver, \
 		const char* kexiTableViewDataMember) { \
-		connect(this, TQT_SIGNAL(dataSet(KexiTableViewData*)), receiver, kexiTableViewDataMember); \
+		connect(this, TQ_SIGNAL(dataSet(KexiTableViewData*)), receiver, kexiTableViewDataMember); \
 	} \
 	void connectToReloadDataSlot(const TQObject* sender, const char* voidSignal) { \
-		connect(sender, voidSignal, this, TQT_SLOT(reloadData())); \
+		connect(sender, voidSignal, this, TQ_SLOT(reloadData())); \
 	}
 
 #endif
