@@ -63,30 +63,30 @@ KexiImageContextMenu::KexiImageContextMenu(TQWidget* parent)
 	insertTitle(TQString());
 
 	d->insertFromFileAction = new TDEAction(i18n("Insert From &File..."), SmallIconSet("document-open"), 0,
-			TQT_TQOBJECT(this), TQT_SLOT(insertFromFile()), &d->actionCollection, "insert");
+			this, TQ_SLOT(insertFromFile()), &d->actionCollection, "insert");
 	d->insertFromFileAction->plug(this);
-	d->saveAsAction = KStdAction::saveAs(TQT_TQOBJECT(this), TQT_SLOT(saveAs()), &d->actionCollection);
+	d->saveAsAction = KStdAction::saveAs(this, TQ_SLOT(saveAs()), &d->actionCollection);
 //	d->saveAsAction->setText(i18n("&Save &As..."));
 	d->saveAsAction->plug(this);
 	insertSeparator();
-	d->cutAction = KStdAction::cut(TQT_TQOBJECT(this), TQT_SLOT(cut()), &d->actionCollection);
+	d->cutAction = KStdAction::cut(this, TQ_SLOT(cut()), &d->actionCollection);
 	d->cutAction->plug(this);
-	d->copyAction = KStdAction::copy(TQT_TQOBJECT(this), TQT_SLOT(copy()), &d->actionCollection);
+	d->copyAction = KStdAction::copy(this, TQ_SLOT(copy()), &d->actionCollection);
 	d->copyAction->plug(this);
-	d->pasteAction = KStdAction::paste(TQT_TQOBJECT(this), TQT_SLOT(paste()), &d->actionCollection);
+	d->pasteAction = KStdAction::paste(this, TQ_SLOT(paste()), &d->actionCollection);
 	d->pasteAction->plug(this);
 	d->deleteAction = new TDEAction(i18n("&Clear"), SmallIconSet("edit-delete"), 0,
-		TQT_TQOBJECT(this), TQT_SLOT(clear()), &d->actionCollection, "delete");
+		this, TQ_SLOT(clear()), &d->actionCollection, "delete");
 	d->deleteAction->plug(this);
 #ifdef KEXI_NO_UNFINISHED 
 	d->propertiesAction = 0;
 #else
 	insertSeparator();
 	d->propertiesAction = new TDEAction(i18n("Properties"), 0, 0,
-		this, TQT_SLOT(showProperties()), &d->actionCollection, "properties");
+		this, TQ_SLOT(showProperties()), &d->actionCollection, "properties");
 	d->propertiesAction->plug(this);
 #endif
-	connect(this, TQT_SIGNAL(aboutToShow()), this, TQT_SLOT(updateActionsAvailability()));
+	connect(this, TQ_SIGNAL(aboutToShow()), this, TQ_SLOT(updateActionsAvailability()));
 }
 
 KexiImageContextMenu::~KexiImageContextMenu()
