@@ -35,7 +35,7 @@
 class KEXIGUIUTILS_EXPORT KexiGradientWidget : public TQWidget {
 	typedef TQPtrList<TQWidget> WidgetList;
 
-	Q_OBJECT
+	TQ_OBJECT
   
 	TQ_PROPERTY(DisplayMode displayMode READ displayMode WRITE setDisplayMode DESIGNABLE true)
 	TQ_PROPERTY(GradientType gradientType READ gradientType WRITE setGradientType DESIGNABLE true)
