@@ -24,8 +24,8 @@
 #include <tqprinter.h>
 
 #include <kdebug.h>
-#include <kglobal.h>
-#include <klocale.h>
+#include <tdeglobal.h>
+#include <tdelocale.h>
 
 #include <KoGenStyles.h>
 #include <KoZoomHandler.h>
@@ -85,7 +85,7 @@ KoPageLayout Kivio::loadPageLayout(const TQDomElement& e)
     layout.ptRight = XmlReadFloat(e, "marginRight", 0.0);
     layout.ptTop = XmlReadFloat(e, "marginTop", 0.0);
     layout.ptBottom = XmlReadFloat(e, "marginBottom", 0.0);
-    layout.format = KoPageFormat::formatFromString(XmlReadString(e, "format", pageSizeString(KGlobal::locale()->pageSize())));
+    layout.format = KoPageFormat::formatFromString(XmlReadString(e, "format", pageSizeString(TDEGlobal::locale()->pageSize())));
     layout.orientation = Kivio::orientationFromString(XmlReadString(e, "orientation", "Portrait"));
   }
 
@@ -1285,7 +1285,7 @@ TQString Kivio::systemDefaultUnit()
 {
   TQString defMS = "cm";
 
-  if(KGlobal::locale()->measureSystem() == KLocale::Imperial) {
+  if(TDEGlobal::locale()->measureSystem() == TDELocale::Imperial) {
     defMS = "in";
   }
 
@@ -1305,7 +1305,7 @@ TQPixmap Kivio::generatePixmapFromStencil(int width, int height, KivioStencil* s
   TQPixmap pix(width, height);
   pix.fill(TQt::white);
   KivioScreenPainter kpainter;
-  kpainter.start(TQT_TQPAINTDEVICE(&pix));
+  kpainter.start(&pix);
   kpainter.translateBy(-rect.x() + ((width - rect.width()) / 2), -rect.y() + ((height - rect.height()) / 2));
   KivioIntraStencilData data;
   data.painter = &kpainter;
