@@ -31,7 +31,7 @@ namespace Kivio {
   Baseclass for mouse tools (like eg the select tool)*/
   class KIVIO_EXPORT MouseTool : public Kivio::Plugin
   {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
       MouseTool(KivioView* parent = 0, const char* name = 0);
