@@ -47,8 +47,8 @@ namespace Kivio {
     m_stencilSetSplitter->setSizes(sizes);
     updateList();
 
-    connect(m_stencilSetLView, TQT_SIGNAL(selectionChanged(TQListViewItem*)), this, TQT_SLOT(changeStencilSet(TQListViewItem*)));
-    connect(m_addToDocBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(addToDocument()));
+    connect(m_stencilSetLView, TQ_SIGNAL(selectionChanged(TQListViewItem*)), this, TQ_SLOT(changeStencilSet(TQListViewItem*)));
+    connect(m_addToDocBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(addToDocument()));
 
     TQListViewItem* tmp = m_stencilSetLView->firstChild();
 
