@@ -82,7 +82,7 @@ class KivioStraightConnector : public Kivio1DStencil
 
 class KIVIOPLUGINS_EXPORT KivioConnectorFactory : public KivioStencilFactory
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
     KivioConnectorFactory(TQObject *parent=0, const char* name=0, const TQStringList& args = TQStringList());
