@@ -46,7 +46,7 @@ SMLConnector::SMLConnector( KivioView* view )
 {
   m_connectorAction = new TDEToggleAction(i18n("Polyline Connector"), "", 0,
     actionCollection(), "sml_connector");
-  connect(m_connectorAction, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(setActivated(bool)));
+  connect(m_connectorAction, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(setActivated(bool)));
 
   m_mode = stmNone;
 
