@@ -116,7 +116,7 @@ class EntryItemToolTip : public TQToolTip
 */
 class Navigator : public TDEListBox
 {
-    Q_OBJECT
+    TQ_OBJECT
   
   public:
     Navigator(bool _selectable, TDEPopupMenu*, IconSidePane *, TQWidget *parent = 0, const char *name = 0 );
@@ -163,7 +163,7 @@ class Navigator : public TDEListBox
 
 class IconSidePane :public TQVBox
 {
-    Q_OBJECT
+    TQ_OBJECT
   
   public:
     IconSidePane( TQWidget *parent, const char *name = 0 );
