@@ -58,7 +58,7 @@ public:
  */
 class DoubleListViewBase : public TQSplitter
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
 
