@@ -50,7 +50,7 @@ class Resource;
 
 class ResourceAppointmentsView : public DoubleListViewBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
 
