@@ -49,7 +49,7 @@ class Task;
  * The dialog that shows and allows you to alter summary tasks.
  */
 class SummaryTaskDialog : public KDialogBase {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     /**
