@@ -8,7 +8,7 @@ class KPrTextPreview;
 
 class KPrShadowDialogImpl : public ShadowDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
