@@ -265,7 +265,7 @@ void KPrThumbBar::setCurrentPage( int pg )
         if ( it->text().toInt() - 1 == pg ) {
             blockSignals( true );
             setCurrentItem( it );
-            setSelected( it, FALSE ); // to avoid the blue "selected"-mark
+            setSelected( it, false ); // to avoid the blue "selected"-mark
             ensureItemVisible(it);
             refreshItems();
             blockSignals( false );
@@ -283,7 +283,7 @@ TQRect KPrThumbBar::tip(const TQPoint &pos, TQString &title)
     int pagenr =  item->index();
     title = m_doc->pageList().at(pagenr)->pageTitle();
 
-    TQRect r = item->pixmapRect(FALSE);
+    TQRect r = item->pixmapRect(false);
     r = TQRect(contentsToViewport(TQPoint(r.x(), r.y())), TQSize(r.width(), r.height()));
     return r;
 }
