@@ -38,7 +38,7 @@
 using namespace KSpread;
 
 PasteInsertDialog::PasteInsertDialog( View* parent, const char* name,const TQRect &_rect)
-	: KDialogBase( parent, name, TRUE,i18n("Paste Inserting Cells"),Ok|Cancel )
+	: KDialogBase( parent, name, true,i18n("Paste Inserting Cells"),Ok|Cancel )
 {
   m_pView = parent;
   rect=_rect;
@@ -48,7 +48,7 @@ PasteInsertDialog::PasteInsertDialog( View* parent, const char* name,const TQRec
   TQVBoxLayout *lay1 = new TQVBoxLayout( page, 0, spacingHint() );
 
   TQButtonGroup *grp = new TQButtonGroup( 1, TQt::Horizontal, i18n("Insert"),page);
-  grp->setRadioButtonExclusive( TRUE );
+  grp->setRadioButtonExclusive( true );
   grp->layout();
   lay1->addWidget(grp);
   rb1 = new TQRadioButton( i18n("Move towards right"), grp );
