@@ -35,7 +35,7 @@ class View;
 
 class PasteInsertDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     PasteInsertDialog( View* parent, const char* name, const TQRect &_rect );
