@@ -52,7 +52,7 @@
 using namespace KSpread;
 
 reference::reference( View* parent, const char* name )
-  : TQDialog( parent, name,TRUE )
+  : TQDialog( parent, name,true )
 {
   m_pView = parent;
   TQVBoxLayout *lay1 = new TQVBoxLayout( this );
@@ -74,7 +74,7 @@ reference::reference( View* parent, const char* name )
   m_pEdit = bb->addButton( i18n("&Edit...") );
   m_pOk = bb->addButton( KStdGuiItem::ok() );
   m_pCancel = bb->addButton( KStdGuiItem::cancel() );
-  m_pOk->setDefault( TRUE );
+  m_pOk->setDefault( true );
   bb->layout();
   lay1->addWidget( bb );
 
@@ -285,7 +285,7 @@ EditAreaName::EditAreaName( View * parent,
 
   EditAreaNameLayout->addWidget( TextLabel1, 1, 0 );
 
-  m_sheets = new TQComboBox( FALSE, page, "m_sheets" );
+  m_sheets = new TQComboBox( false, page, "m_sheets" );
 
   EditAreaNameLayout->addWidget( m_sheets, 1, 1 );
 
