@@ -41,7 +41,7 @@ class View;
 
 class reference: public TQDialog
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   reference( View* parent, const char* name );
@@ -70,7 +70,7 @@ private:
 
 class EditAreaName : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
