@@ -27,7 +27,7 @@ class TDEAboutData;
 
 class KUGARDESIGNER_EXPORT KudesignerFactory : public KoFactory
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KudesignerFactory( TQObject* parent = 0, const char* name = 0 );
