@@ -135,7 +135,7 @@ bool KugarPart::initDoc( InitDocFlags /*flags*/, TQWidget* /*parentWidget*/ )
     return ok;
 
     // If nothing is loaded, do initialize here
-    return TRUE;
+    return true;
 }
 
 KoView* KugarPart::createViewInstance( TQWidget* parent, const char* name )
