@@ -43,7 +43,7 @@ class KWFormulaFrameSetEdit;
 
 class KWFormulaFrameSet : public KWFrameSet
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KWFormulaFrameSet( KWDocument *doc, const TQString & name );
@@ -121,7 +121,7 @@ private:
 
 class KWFormulaFrameSetEdit : public TQObject, public KWFrameSetEdit
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KWFormulaFrameSetEdit(KWFormulaFrameSet* fs, KWCanvas* canvas);
