@@ -422,7 +422,7 @@ void KWFrame::load( TQDomElement &frameElem, KWFrameSet* frameSet, int syntaxVer
 
 
     if( frameElem.hasAttribute("bkStyle"))
-        m_backgroundColor.setStyle (static_cast<Qt::BrushStyle>(KWDocument::getAttribute( frameElem, "bkStyle", TQt::SolidPattern )));
+        m_backgroundColor.setStyle (static_cast<TQt::BrushStyle>(KWDocument::getAttribute( frameElem, "bkStyle", TQt::SolidPattern )));
 
     m_paddingLeft = frameElem.attribute( "bleftpt" ).toDouble();
     m_paddingRight = frameElem.attribute( "brightpt" ).toDouble();
@@ -456,7 +456,7 @@ void KWFrame::loadBorderProperties( KoStyleStack& styleStack )
     if ( styleStack.hasAttributeNS( KoXmlNS::fo, "background-transparency" ) ) {
         TQString transp = styleStack.attributeNS( KoXmlNS::fo, "background-transparency" );
         if ( transp == "100%" )
-            m_backgroundColor.setStyle( Qt::NoBrush );
+            m_backgroundColor.setStyle( TQt::NoBrush );
     }
 
     // borders (3.11.27)
