@@ -28,7 +28,7 @@ class KWDocument;
 
 class KWInsertPicDia : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KWInsertPicDia( TQWidget *parent, bool _inline, bool _keepRatio, KWDocument *_doc, const char *name = 0 );
