@@ -45,7 +45,7 @@ typedef TQMap<TQString,TQString> DbRecord;
 
 class KWORD_EXPORT KWMailMergeDataSource: public TQObject, public DCOPObject
 {
-    Q_OBJECT
+    TQ_OBJECT
 //    
     K_DCOP
     public:
