@@ -33,7 +33,7 @@ class TQLabel;
  */
 class KWStatisticsDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
