@@ -100,7 +100,7 @@ void KWMailMergeKSpread::initDocument()
 {
   _document = new Doc();
 
-  connect( _document, TQT_SIGNAL( completed() ), TQT_SLOT( initSpreadSheets() ) );
+  connect( _document, TQ_SIGNAL( completed() ), TQ_SLOT( initSpreadSheets() ) );
 
   _document->openURL( _url );
 }
