@@ -31,7 +31,7 @@
 
 class KWMailMergeKSpread: public KWMailMergeDataSource
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
