@@ -40,7 +40,7 @@ KWQtSqlEasyFilter::KWQtSqlEasyFilter( TQWidget *parent)
 	for (int i=0;i<3;i++) w+=m_table->columnWidth(i);
 	w+=m_table->verticalHeader()->headerWidth();
 	m_table->setMinimumWidth(w);
-	connect(m_table,TQT_SIGNAL(valueChanged ( int, int)),this,TQT_SLOT(slotValueChanged ( int, int)));
+	connect(m_table,TQ_SIGNAL(valueChanged ( int, int)),this,TQ_SLOT(slotValueChanged ( int, int)));
 }
 
 void KWQtSqlEasyFilter::createColumn(int i)
