@@ -37,7 +37,7 @@
  ******************************************************************/
 class KWQtSqlSerialDataSourceBase: public KWMailMergeDataSource
 {
-    Q_OBJECT
+    TQ_OBJECT
 //    
     K_DCOP
     public:
