@@ -132,7 +132,7 @@ bool KoApplication::start()
             return false;
         KoMainWindow *shell = new KoMainWindow( doc->instance() );
         shell->show();
-        TQObject::connect(doc, TQT_SIGNAL(sigProgress(int)), shell, TQT_SLOT(slotProgress(int)));
+        TQObject::connect(doc, TQ_SIGNAL(sigProgress(int)), shell, TQ_SLOT(slotProgress(int)));
         // for initDoc to fill in the recent docs list
         // and for KoDocument::slotStarted
         doc->addShell( shell );
@@ -144,7 +144,7 @@ bool KoApplication::start()
         }
 
         // FIXME This needs to be moved someplace else
-	TQObject::disconnect(doc, TQT_SIGNAL(sigProgress(int)), shell, TQT_SLOT(slotProgress(int)));
+	TQObject::disconnect(doc, TQ_SIGNAL(sigProgress(int)), shell, TQ_SLOT(slotProgress(int)));
     } else {
         bool print = koargs->isSet("print");
 	bool doTemplate = koargs->isSet("template");
