@@ -40,7 +40,7 @@
  */
 class KOFFICECORE_EXPORT KoChild : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
 
