@@ -100,11 +100,11 @@ KoTemplatesPane::KoTemplatesPane(TQWidget* parent, TDEInstance* instance,
   TDEConfigGroup cfgGrp(d->m_instance->config(), "TemplateChooserDialog");
   TQString fullTemplateName = cfgGrp.readPathEntry("FullTemplateName");
   d->m_alwaysUseTemplate = cfgGrp.readPathEntry("AlwaysUseTemplate");
-  connect(m_alwaysUseCheckBox, TQT_SIGNAL(clicked()), this, TQT_SLOT(alwaysUseClicked()));
+  connect(m_alwaysUseCheckBox, TQ_SIGNAL(clicked()), this, TQ_SLOT(alwaysUseClicked()));
   changePalette();
 
   if(kapp) {
-    connect(kapp, TQT_SIGNAL(tdedisplayPaletteChanged()), this, TQT_SLOT(changePalette()));
+    connect(kapp, TQ_SIGNAL(tdedisplayPaletteChanged()), this, TQ_SLOT(changePalette()));
   }
 
   TDEListViewItem* selectItem = 0;
@@ -112,7 +112,7 @@ KoTemplatesPane::KoTemplatesPane(TQWidget* parent, TDEInstance* instance,
   for (KoTemplate* t = group->first(); t != 0L; t = group->next()) {
     TDEListViewItem* item = new TDEListViewItem(m_documentList, t->name(), t->description(), t->file());
     TQImage icon = t->loadPicture(instance).convertToImage();
-    icon = icon.smoothScale(64, 64, TQ_ScaleMin);
+    icon = icon.smoothScale(64, 64, TQImage::ScaleMin);
     icon.setAlphaBuffer(true);
     icon = icon.copy((icon.width() - 64) / 2, (icon.height() - 64) / 2, 64, 64);
     item->setPixmap(0, TQPixmap(icon));
@@ -125,13 +125,13 @@ KoTemplatesPane::KoTemplatesPane(TQWidget* parent, TDEInstance* instance,
     }
   }
 
-  connect(m_documentList, TQT_SIGNAL(selectionChanged(TQListViewItem*)),
-          this, TQT_SLOT(selectionChanged(TQListViewItem*)));
-  connect(m_documentList, TQT_SIGNAL(doubleClicked(TQListViewItem*, const TQPoint&, int)),
-          this, TQT_SLOT(openTemplate(TQListViewItem*)));
-  connect(m_documentList, TQT_SIGNAL(returnPressed(TQListViewItem*)),
-          this, TQT_SLOT(openTemplate(TQListViewItem*)));
-  connect(m_openButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(openTemplate()));
+  connect(m_documentList, TQ_SIGNAL(selectionChanged(TQListViewItem*)),
+          this, TQ_SLOT(selectionChanged(TQListViewItem*)));
+  connect(m_documentList, TQ_SIGNAL(doubleClicked(TQListViewItem*, const TQPoint&, int)),
+          this, TQ_SLOT(openTemplate(TQListViewItem*)));
+  connect(m_documentList, TQ_SIGNAL(returnPressed(TQListViewItem*)),
+          this, TQ_SLOT(openTemplate(TQListViewItem*)));
+  connect(m_openButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(openTemplate()));
 
   if(selectItem) {
     m_documentList->setSelected(selectItem, true);
@@ -226,13 +226,13 @@ void KoTemplatesPane::changeAlwaysUseTemplate(KoTemplatesPane* sender, const TQS
 
 bool KoTemplatesPane::eventFilter(TQObject* watched, TQEvent* e)
 {
-  if(TQT_BASE_OBJECT(watched) == m_previewLabel) {
+  if(watched == m_previewLabel) {
     if(e->type() == TQEvent::MouseButtonDblClick) {
       openTemplate();
     }
   }
 
-  if(TQT_BASE_OBJECT(watched) == m_documentList) {
+  if(watched == m_documentList) {
     if((e->type() == TQEvent::Resize) && isShown()) {
       emit splitterResized(this, m_splitter->sizes());
     }
@@ -284,7 +284,7 @@ KoRecentDocumentsPane::KoRecentDocumentsPane(TQWidget* parent, TDEInstance* inst
   changePalette();
 
   if(kapp) {
-    connect(kapp, TQT_SIGNAL(tdedisplayPaletteChanged()), this, TQT_SLOT(changePalette()));
+    connect(kapp, TQ_SIGNAL(tdedisplayPaletteChanged()), this, TQ_SLOT(changePalette()));
   }
 
   TQString oldGroup = instance->config()->group();
@@ -334,23 +334,23 @@ KoRecentDocumentsPane::KoRecentDocumentsPane(TQWidget* parent, TDEInstance* inst
 
   instance->config()->setGroup( oldGroup );
 
-  connect(m_documentList, TQT_SIGNAL(selectionChanged(TQListViewItem*)),
-          this, TQT_SLOT(selectionChanged(TQListViewItem*)));
-  connect(m_documentList, TQT_SIGNAL(clicked(TQListViewItem*)),
-          this, TQT_SLOT(selectionChanged(TQListViewItem*)));
-  connect(m_documentList, TQT_SIGNAL(doubleClicked(TQListViewItem*, const TQPoint&, int)),
-          this, TQT_SLOT(openFile(TQListViewItem*)));
-  connect(m_documentList, TQT_SIGNAL(returnPressed(TQListViewItem*)),
-          this, TQT_SLOT(openFile(TQListViewItem*)));
-  connect(m_openButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(openFile()));
+  connect(m_documentList, TQ_SIGNAL(selectionChanged(TQListViewItem*)),
+          this, TQ_SLOT(selectionChanged(TQListViewItem*)));
+  connect(m_documentList, TQ_SIGNAL(clicked(TQListViewItem*)),
+          this, TQ_SLOT(selectionChanged(TQListViewItem*)));
+  connect(m_documentList, TQ_SIGNAL(doubleClicked(TQListViewItem*, const TQPoint&, int)),
+          this, TQ_SLOT(openFile(TQListViewItem*)));
+  connect(m_documentList, TQ_SIGNAL(returnPressed(TQListViewItem*)),
+          this, TQ_SLOT(openFile(TQListViewItem*)));
+  connect(m_openButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(openFile()));
 
   m_documentList->setSelected(m_documentList->firstChild(), true);
 
   d->m_previewJob = TDEIO::filePreview(fileList, 200, 200);
 
-  connect(d->m_previewJob, TQT_SIGNAL(result(TDEIO::Job*)), this, TQT_SLOT(previewResult(TDEIO::Job*)));
-  connect(d->m_previewJob, TQT_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
-          this, TQT_SLOT(updatePreview(const KFileItem*, const TQPixmap&)));
+  connect(d->m_previewJob, TQ_SIGNAL(result(TDEIO::Job*)), this, TQ_SLOT(previewResult(TDEIO::Job*)));
+  connect(d->m_previewJob, TQ_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
+          this, TQ_SLOT(updatePreview(const KFileItem*, const TQPixmap&)));
 }
 
 KoRecentDocumentsPane::~KoRecentDocumentsPane()
@@ -418,7 +418,7 @@ void KoRecentDocumentsPane::updatePreview(const KFileItem* fileItem, const TQPix
     if(it.current()->text(1) == fileItem->url().url()) {
       it.current()->setPixmap(2, preview);
       TQImage icon = preview.convertToImage();
-      icon = icon.smoothScale(64, 64, TQ_ScaleMin);
+      icon = icon.smoothScale(64, 64, TQImage::ScaleMin);
       icon.setAlphaBuffer(true);
       icon = icon.copy((icon.width() - 64) / 2, (icon.height() - 64) / 2, 64, 64);
       it.current()->setPixmap(0, TQPixmap(icon));
@@ -444,13 +444,13 @@ void KoRecentDocumentsPane::changePalette()
 
 bool KoRecentDocumentsPane::eventFilter(TQObject* watched, TQEvent* e)
 {
-  if(TQT_BASE_OBJECT(watched) == m_previewLabel) {
+  if(watched == m_previewLabel) {
     if(e->type() == TQEvent::MouseButtonDblClick) {
       openFile();
     }
   }
 
-  if(TQT_BASE_OBJECT(watched) == m_documentList) {
+  if(watched == m_documentList) {
     if((e->type() == TQEvent::Resize) && isShown()) {
       emit splitterResized(this, m_splitter->sizes());
     }
