@@ -230,7 +230,7 @@ KoDocument::KoDocument( TQWidget * parentWidget, const char *widgetName, TQObjec
     s_documentList->append(this);
 
     d = new Private;
-    m_bEmpty = TRUE;
+    m_bEmpty = true;
     connect( &d->m_autoSaveTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( slotAutoSave() ) );
     setAutoSave( s_defaultAutoSave );
     d->m_bSingleViewMode = singleViewMode;
@@ -825,7 +825,7 @@ void KoDocument::paintChild( KoDocumentChild *child, TQPainter &painter, KoView
                manager->activeWidget() == (TQWidget *)view ) )
         {
             // painter.setClipRegion( rgn );
-            painter.setClipping( FALSE );
+            painter.setClipping( false );
 
             painter.setPen( black );
             painter.fillRect( -5, -5, w + 10, 5, white );
@@ -855,7 +855,7 @@ void KoDocument::paintChild( KoDocumentChild *child, TQPainter &painter, KoView
                 painter.fillRect( w, h / 2 - 3, 5, 5, color );
             }
 
-            painter.setClipping( TRUE );
+            painter.setClipping( true );
         }
     }
 }
@@ -891,7 +891,7 @@ bool KoDocument::saveChildren( KoStore* _store )
             {
                 //kdDebug(30003) << "KoDocument::saveChildren internal url: /" << i << endl;
                 if ( !childDoc->saveToStore( _store, TQString::number( i++ ) ) )
-                    return FALSE;
+                    return false;
 
                 if (!isExporting ())
                     childDoc->setModified( false );
@@ -1968,7 +1968,7 @@ void KoDocument::setModified( bool mod )
     KParts::ReadWritePart::setModified( mod );
 
     if ( mod ) {
-        m_bEmpty = FALSE;
+        m_bEmpty = false;
     } else {
         // When saving this document, all non-external child documents get saved too.
         TQPtrListIterator<KoDocumentChild> it = children();
@@ -2278,15 +2278,15 @@ void KoDocument::setupXmlReader( TQXmlSimpleReader& reader, bool namespaceProces
 {
     if ( namespaceProcessing )
     {
-        reader.setFeature( "http://xml.org/sax/features/namespaces", TRUE );
-        reader.setFeature( "http://xml.org/sax/features/namespace-prefixes", FALSE );
+        reader.setFeature( "http://xml.org/sax/features/namespaces", true );
+        reader.setFeature( "http://xml.org/sax/features/namespace-prefixes", false );
     }
     else
     {
-        reader.setFeature( "http://xml.org/sax/features/namespaces", FALSE );
-        reader.setFeature( "http://xml.org/sax/features/namespace-prefixes", TRUE );
+        reader.setFeature( "http://xml.org/sax/features/namespaces", false );
+        reader.setFeature( "http://xml.org/sax/features/namespace-prefixes", true );
     }
-    reader.setFeature( "http://trolltech.com/xml/features/report-whitespace-only-CharData", TRUE );
+    reader.setFeature( "http://trolltech.com/xml/features/report-whitespace-only-CharData", true );
 }
 
 
