@@ -27,7 +27,7 @@
 #include <tqframe.h>
 #include <tqpixmap.h>
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 #include <koffice_export.h>
 #include <KoGlobal.h>
 #include <KoTabChooser.h>
@@ -123,7 +123,7 @@ public:
      * example "mm", "pt" or "inch".
      * @deprecated You should use the KoUnit::Unit variant instead.
      */
-    void setUnit( const TQString& unit ) KDE_DEPRECATED ;
+    void setUnit( const TQString& unit ) TDE_DEPRECATED ;
     /**
      * Set the unit to be used.
      */
