@@ -366,7 +366,7 @@ void KoTemplateChooseDia::setupFileDialog(TQWidget * widgetbase, TQGridLayout *
     }
     delete l;
 
-    d->m_filedialog->setSizeGripEnabled ( FALSE );
+    d->m_filedialog->setSizeGripEnabled ( false );
 
     TQStringList mimeFilter = KoFilterManager::mimeFilter( d->m_format, KoFilterManager::Import );
     TQStringList::Iterator mimeFilterIt = mimeFilter.at( 1 );
@@ -810,7 +810,7 @@ void KoTCDRecentFilesIconView::showToolTip( TQIconViewItem* item )
         toolTip->move(toolTip->x(), screen.bottom()-toolTip->y()-toolTip->height()+toolTip->y());
     }
     toolTip->setFont( TQToolTip::font() );
-    toolTip->setPalette( TQToolTip::palette(), TRUE );
+    toolTip->setPalette( TQToolTip::palette(), true );
     toolTip->show();
 }
 
