@@ -41,7 +41,7 @@ class KoTemplateCreateDiaPrivate;
 
 class KOFFICEUI_EXPORT KoTemplateCreateDia : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
