@@ -38,7 +38,7 @@
  */
 class KOPALETTE_EXPORT KoPalette : public TQDockWindow {
 
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
