@@ -18,8 +18,6 @@
  * Boston, MA 02110-1301, USA.
 */
 
-#include "cursoredit.h"
-
 #include <tqmap.h>
 #include <tqvariant.h>
 #include <tqcursor.h>
@@ -27,11 +25,12 @@
 #include <tdelocale.h>
 #include <kdebug.h>
 
+#include "cursoredit.h"
 #include "property.h"
 
 using namespace KoProperty;
 
-//TQMap<TQString, TQVariant> *CursorEdit::m_spValues = 0;
+//TQStringVariantMap *CursorEdit::m_spValues = 0;
 Property::ListData *m_cursorListData = 0;
 
 
@@ -40,7 +39,7 @@ CursorEdit::CursorEdit(Property *property, TQWidget *parent, const char *name)
 {
 	/*
 	if(!m_spValues) {
-		m_spValues = new TQMap<TQString, TQVariant>();
+		m_spValues = new TQStringVariantMap();
 		(*m_spValues)[i18n("Arrow")] = TQt::ArrowCursor;
 		(*m_spValues)[i18n("Up Arrow")] = TQt::UpArrowCursor;
 		(*m_spValues)[i18n("Cross")] = TQt::CrossCursor;
