@@ -30,7 +30,7 @@ namespace KoProperty {
 
 class KOPROPERTY_EXPORT DateEdit : public Widget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
