@@ -38,7 +38,7 @@ RectEdit::RectEdit(Property *property, TQWidget *parent, const char *name)
 {
 	setHasBorders(false);
 	m_edit = new KActiveLabel(this);
-	m_edit->setFocusPolicy(TQ_NoFocus);
+	m_edit->setFocusPolicy(TQWidget::NoFocus);
 	m_edit->setPaletteBackgroundColor(palette().active().base());
 	m_edit->setWordWrap( TQTextEdit::NoWrap );
 	m_edit->setMinimumHeight(5);
