@@ -32,7 +32,7 @@
 
 using namespace KoProperty;
 
-TQMap<TQString, TQVariant> *SizePolicyEdit::m_spValues = 0;
+TQStringVariantMap *SizePolicyEdit::m_spValues = 0;
 
 SizePolicyEdit::SizePolicyEdit(Property *property, TQWidget *parent, const char *name)
  : Widget(property, parent, name)
@@ -50,7 +50,7 @@ SizePolicyEdit::SizePolicyEdit(Property *property, TQWidget *parent, const char
 
 
 	if(!m_spValues) {
-		m_spValues = new TQMap<TQString, TQVariant>();
+		m_spValues = new TQStringVariantMap();
 		(*m_spValues)[i18n("Size Policy", "Fixed")] = TQSizePolicy::Fixed;
 		(*m_spValues)[i18n("Size Policy", "Minimum")] = TQSizePolicy::Minimum;
 		(*m_spValues)[i18n("Size Policy", "Maximum")] = TQSizePolicy::Maximum;
@@ -105,8 +105,8 @@ SizePolicyEdit::findDescription(const TQVariant &value) const
 	if(!m_spValues)
 		return TQString();
 
-	TQMap<TQString, TQVariant>::ConstIterator endIt = m_spValues->constEnd();
-	for (TQMap<TQString, TQVariant>::ConstIterator it = m_spValues->constBegin(); it != endIt; ++ it) {
+	TQStringVariantMap::ConstIterator endIt = m_spValues->constEnd();
+	for (TQStringVariantMap::ConstIterator it = m_spValues->constBegin(); it != endIt; ++ it) {
 		if (it.data() == value)
 			return it.key();
 	}
