@@ -456,7 +456,7 @@ void KoAutoFormat::readAutoCorrectConfig()
         for(uint i = 0; i < nl.count() ; i++) {
             //bug in qmap we overwrite = false doesn't work
             //so we can't add multiple "othernb"
-            m_superScriptEntries.insert( nl.item(i).toElement().attribute("find"), KoAutoFormatEntry(nl.item(i).toElement().attribute("super")),FALSE );
+            m_superScriptEntries.insert( nl.item(i).toElement().attribute("find"), KoAutoFormatEntry(nl.item(i).toElement().attribute("super")),false );
         }
     }
 
