@@ -74,7 +74,7 @@ bool KoSpell::check( KoTextIterator *itr, bool dialog )
         return ret;
 
     d->itr = itr;
-    connect( d->itr, TQT_SIGNAL( currentParagraphDeleted() ), TQT_SLOT( slotCurrentParagraphDeleted() ) );
+    connect( d->itr, TQ_SIGNAL( currentParagraphDeleted() ), TQ_SLOT( slotCurrentParagraphDeleted() ) );
     d->lastTxtDocument = d->itr->currentTextObject()->textDocument();
     d->needsIncrement = false;
     ret = !d->itr->atEnd();
