@@ -1,4 +1,4 @@
-""" 
+"""
 Python script for a GUI-dialog.
 
 Description:
@@ -34,8 +34,8 @@ class TkDialog:
 	""" This class is used to wrap Tkinter into a more abstract interface."""
 
 	def __init__(self, title):
-		import Tkinter
-		self.root = Tkinter.Tk()
+		import tkinter
+		self.root = tkinter.Tk()
 		self.root.title(title)
 		self.root.deiconify()
 
@@ -52,42 +52,42 @@ class TkDialog:
 	class Frame(Widget):
 		def __init__(self, dialog, parent):
 			#TkDialog.Widget.__init__(self, dialog, parent)
-			import Tkinter
-			self.widget = Tkinter.Frame(parent)
+			import tkinter
+			self.widget = tkinter.Frame(parent)
 			self.widget.pack()
 
 	class Label(Widget):
 		def __init__(self, dialog, parent, caption):
 			#TkDialog.Widget.__init__(self, dialog, parent)
-			import Tkinter
-			self.widget = Tkinter.Label(parent, text=caption)
-			self.widget.pack(side=Tkinter.TOP)
+			import tkinter
+			self.widget = tkinter.Label(parent, text=caption)
+			self.widget.pack(side=tkinter.TOP)
 
 	class CheckBox(Widget):
 		def __init__(self, dialog, parent, caption, checked = True):
 			#TkDialog.Widget.__init__(self, dialog, parent)
-			import Tkinter
-			self.checkstate = Tkinter.IntVar()
+			import tkinter
+			self.checkstate = tkinter.IntVar()
 			self.checkstate.set(checked)
-			self.widget = Tkinter.Checkbutton(parent, text=caption, variable=self.checkstate)
-			self.widget.pack(side=Tkinter.TOP)
+			self.widget = tkinter.Checkbutton(parent, text=caption, variable=self.checkstate)
+			self.widget.pack(side=tkinter.TOP)
 		def isChecked(self):
 			return self.checkstate.get()
 
 	class List(Widget):
 		def __init__(self, dialog, parent, caption, items):
 			#TkDialog.Widget.__init__(self, dialog, parent)
-			import Tkinter
+			import tkinter
 
-			listframe = Tkinter.Frame(parent)
+			listframe = tkinter.Frame(parent)
 			listframe.pack()
 
-			Tkinter.Label(listframe, text=caption).pack(side=Tkinter.LEFT)
+			tkinter.Label(listframe, text=caption).pack(side=tkinter.LEFT)
 
 			self.items = items
-			self.variable = Tkinter.StringVar()
-			itemlist = apply(Tkinter.OptionMenu, (listframe, self.variable) + tuple( items ))
-			itemlist.pack(side=Tkinter.LEFT)
+			self.variable = tkinter.StringVar()
+			itemlist = tkinter.OptionMenu(*(listframe, self.variable) + tuple( items ))
+			itemlist.pack(side=tkinter.LEFT)
 		def get(self):
 			return self.variable.get()
 		def set(self, index):
@@ -96,48 +96,48 @@ class TkDialog:
 	class Button(Widget):
 		def __init__(self, dialog, parent, caption, commandmethod):
 			#TkDialog.Widget.__init__(self, dialog, parent)
-			import Tkinter
-			self.widget = Tkinter.Button(parent, text=caption, command=self.doCommand)
+			import tkinter
+			self.widget = tkinter.Button(parent, text=caption, command=self.doCommand)
 			self.commandmethod = commandmethod
-			self.widget.pack(side=Tkinter.LEFT)
+			self.widget.pack(side=tkinter.LEFT)
 		def doCommand(self):
 			try:
 				self.commandmethod()
 			except:
 				#TODO why the heck we arn't able to redirect exceptions?
 				import traceback
-				import StringIO
-				fp = StringIO.StringIO()
+				import io
+				fp = io.StringIO()
 				traceback.print_exc(file=fp)
-				import tkMessageBox
-				tkMessageBox.showerror("Exception", fp.getvalue())
+				import tkinter.messagebox
+				tkinter.messagebox.showerror("Exception", fp.getvalue())
 				#self.dialog.root.destroy()
 
 	class Edit(Widget):
 		def __init__(self, dialog, parent, caption, text):
 			#TkDialog.Widget.__init__(self, dialog, parent)
-			import Tkinter
-			self.widget = Tkinter.Frame(parent)
+			import tkinter
+			self.widget = tkinter.Frame(parent)
 			self.widget.pack()
-			label = Tkinter.Label(self.widget, text=caption)
-			label.pack(side=Tkinter.LEFT)
-			self.entrytext = Tkinter.StringVar()
+			label = tkinter.Label(self.widget, text=caption)
+			label.pack(side=tkinter.LEFT)
+			self.entrytext = tkinter.StringVar()
 			self.entrytext.set(text)
-			self.entry = Tkinter.Entry(self.widget, width=36, textvariable=self.entrytext)
-			self.entry.pack(side=Tkinter.LEFT)
+			self.entry = tkinter.Entry(self.widget, width=36, textvariable=self.entrytext)
+			self.entry.pack(side=tkinter.LEFT)
 		def get(self):
 			return self.entrytext.get()
 
 	class FileChooser(Edit):
 		def __init__(self, dialog, parent, caption, initialfile = None, filetypes = None):
 			TkDialog.Edit.__init__(self, dialog, parent, caption, initialfile)
-			import Tkinter
+			import tkinter
 
 			self.initialfile = initialfile
 			self.entrytext.set(initialfile)
 
-			btn = Tkinter.Button(self.widget, text="...", command=self.browse)
-			btn.pack(side=Tkinter.LEFT)
+			btn = tkinter.Button(self.widget, text="...", command=self.browse)
+			btn.pack(side=tkinter.LEFT)
 
 			if filetypes:
 				self.filetypes = filetypes
@@ -150,8 +150,8 @@ class TkDialog:
 			d = os.path.dirname(text) or os.path.dirname(self.initialfile)
 			f = os.path.basename(text) or os.path.basename(self.initialfile)
 
-			import tkFileDialog
-			file = tkFileDialog.asksaveasfilename(
+			import tkinter.filedialog
+			file = tkinter.filedialog.asksaveasfilename(
 					   initialdir=d,
 					   initialfile=f,
 					   #defaultextension='.html',
@@ -167,81 +167,81 @@ class TkDialog:
 			self.caption = str(caption)
 			self.message = str(message)
 		def show(self):
-			import tkMessageBox
+			import tkinter.messagebox
 			if self.typename == "okcancel":
-				return tkMessageBox.askokcancel(self.caption, self.message,icon=tkmessageBox.QESTION)
+				return tkinter.messagebox.askokcancel(self.caption, self.message,icon=tkmessageBox.QESTION)
 			else:
-				tkMessageBox.showinfo(self.caption, self.message)
+				tkinter.messagebox.showinfo(self.caption, self.message)
 			return True
 
 	def show(self):
 		self.root.mainloop()
-		
+
 	def close(self):
 		self.root.destroy()
 
-class QtDialog:
-	""" This class is used to wrap pyQt/pyKDE into a more abstract interface."""
+class TQtDialog:
+	""" This class is used to wrap PyTQt/PyTDE into a more abstract interface."""
 
 	def __init__(self, title):
-		import qt
-		
-		class Dialog(qt.QDialog):
+		from TQt import tqt
+
+		class Dialog(tqt.TQDialog):
 			def __init__(self, parent = None, name = None, modal = 0, fl = 0):
-				qt.QDialog.__init__(self, parent, name, modal, fl)
-				qt.QDialog.accept = self.accept
-				self.layout = qt.QVBoxLayout(self)
+				tqt.TQDialog.__init__(self, parent, name, modal, fl)
+				tqt.TQDialog.accept = self.accept
+				self.layout = tqt.TQVBoxLayout(self)
 				self.layout.setSpacing(6)
 				self.layout.setMargin(11)
-				
-		class Label(qt.QLabel):
+
+		class Label(tqt.TQLabel):
 			def __init__(self, dialog, parent, caption):
-				qt.QLabel.__init__(self, parent)
+				tqt.TQLabel.__init__(self, parent)
 				self.setText("<qt>%s</qt>" % caption.replace("\n","<br>"))
-				
-		class Frame(qt.QHBox):
+
+		class Frame(tqt.TQHBox):
 			def __init__(self, dialog, parent):
-				qt.QHBox.__init__(self, parent)
+				tqt.TQHBox.__init__(self, parent)
 				self.widget = self
 				self.setSpacing(6)
 
-		class Edit(qt.QHBox):
+		class Edit(tqt.TQHBox):
 			def __init__(self, dialog, parent, caption, text):
-				qt.QHBox.__init__(self, parent)
+				tqt.TQHBox.__init__(self, parent)
 				self.setSpacing(6)
-				label = qt.QLabel(caption, self)
-				self.edit = qt.QLineEdit(self)
+				label = tqt.TQLabel(caption, self)
+				self.edit = tqt.TQLineEdit(self)
 				self.edit.setText( str(text) )
 				self.setStretchFactor(self.edit, 1)
 				label.setBuddy(self.edit)
 			def get(self):
 				return self.edit.text()
 
-		class Button(qt.QPushButton):
+		class Button(tqt.TQPushButton):
 			#def __init__(self, *args):
 			def __init__(self, dialog, parent, caption, commandmethod):
-				#apply(qt.QPushButton.__init__, (self,) + args)
-				qt.QPushButton.__init__(self, parent)
+				#apply(tqt.TQPushButton.__init__, (self,) + args)
+				tqt.TQPushButton.__init__(self, parent)
 				self.commandmethod = commandmethod
 				self.setText(caption)
-				qt.QObject.connect(self, qt.SIGNAL("clicked()"), self.commandmethod)
+				tqt.TQObject.connect(self, tqt.TQ_SIGNAL("clicked()"), self.commandmethod)
 
 
-		class CheckBox(qt.QCheckBox):
+		class CheckBox(tqt.TQCheckBox):
 			def __init__(self, dialog, parent, caption, checked = True):
 				#TkDialog.Widget.__init__(self, dialog, parent)
-				qt.QCheckBox.__init__(self, parent)
+				tqt.TQCheckBox.__init__(self, parent)
 				self.setText(caption)
 				self.setChecked(checked)
 			#def isChecked(self):
 			#	return self.isChecked()
 
-		class List(qt.QHBox):
+		class List(tqt.TQHBox):
 			def __init__(self, dialog, parent, caption, items):
-				qt.QHBox.__init__(self, parent)
+				tqt.TQHBox.__init__(self, parent)
 				self.setSpacing(6)
-				label = qt.QLabel(caption, self)
-				self.combo = qt.QComboBox(self)
+				label = tqt.TQLabel(caption, self)
+				self.combo = tqt.TQComboBox(self)
 				self.setStretchFactor(self.combo, 1)
 				label.setBuddy(self.combo)
 				for item in items:
@@ -251,24 +251,24 @@ class QtDialog:
 			def set(self, index):
 				self.combo.setCurrentItem(index)
 
-		class FileChooser(qt.QHBox):
+		class FileChooser(tqt.TQHBox):
 			def __init__(self, dialog, parent, caption, initialfile = None, filetypes = None):
-				#apply(qt.QHBox.__init__, (self,) + args)
-				qt.QHBox.__init__(self, parent)
+				#apply(tqt.TQHBox.__init__, (self,) + args)
+				tqt.TQHBox.__init__(self, parent)
 				self.setMinimumWidth(400)
 
 				self.initialfile = initialfile
 				self.filetypes = filetypes
-				
-                                self.setSpacing(6)
-				label = qt.QLabel(caption, self)
-				self.edit = qt.QLineEdit(self)
+
+				self.setSpacing(6)
+				label = tqt.TQLabel(caption, self)
+				self.edit = tqt.TQLineEdit(self)
 				self.edit.setText(self.initialfile)
 				self.setStretchFactor(self.edit, 1)
 				label.setBuddy(self.edit)
-				
+
 				browsebutton = Button(dialog, self, "...", self.browseButtonClicked)
-				#qt.QObject.connect(browsebutton, qt.SIGNAL("clicked()"), self.browseButtonClicked)
+				#tqt.TQObject.connect(browsebutton, tqt.TQ_SIGNAL("clicked()"), self.browseButtonClicked)
 
 			def get(self):
 				return self.edit.text()
@@ -276,7 +276,7 @@ class QtDialog:
 			def browseButtonClicked(self):
 				filtermask = ""
 				import types
-				if isinstance(self.filetypes, types.TupleType):
+				if isinstance(self.filetypes, tuple):
 					for ft in self.filetypes:
 						if len(ft) == 1:
 							filtermask += "%s\n" % (ft[0])
@@ -286,20 +286,20 @@ class QtDialog:
 					filtermask = "All files (*.*)"
 				else:
 					filtermask = filtermask[:-1]
-					
+
 				filename = None
 				try:
-					print "QtDialog.FileChooser.browseButtonClicked() tdefile.KFileDialog"
+					print("TQtDialog.FileChooser.browseButtonClicked() tdefile.KFileDialog")
 					# try to use the tdefile module included in pytde
 					import tdefile
 					filename = tdefile.KFileDialog.getOpenFileName(self.initialfile, filtermask, self, "Save to file")
 				except:
-					print "QtDialog.FileChooser.browseButtonClicked() qt.QFileDialog"
-					# fallback to Qt filedialog
-					filename = qt.QFileDialog.getOpenFileName(self.initialfile, filtermask, self, "Save to file")
+					print("TQtDialog.FileChooser.browseButtonClicked() tqt.TQFileDialog")
+					# fallback to TQt filedialog
+					filename = tqt.TQFileDialog.getOpenFileName(self.initialfile, filtermask, self, "Save to file")
 				if filename != None and filename != "":
 					self.edit.setText(filename)
-					
+
 		class MessageBox:
 			def __init__(self, dialog, typename, caption, message):
 				self.widget = dialog.widget
@@ -309,19 +309,19 @@ class QtDialog:
 			def show(self):
 				result = 1
 				if self.typename == "okcancel":
-					result = qt.QMessageBox.question(self.widget, self.caption, self.message, "&Ok", "&Cancel", "", 1)
+					result = tqt.TQMessageBox.question(self.widget, self.caption, self.message, "&Ok", "&Cancel", "", 1)
 				else:
-					qt.QMessageBox.information(self.widget, self.caption, self.message, "&Ok")
+					tqt.TQMessageBox.information(self.widget, self.caption, self.message, "&Ok")
 					result = 0
 				if result == 0:
 					return True
 				return False
 
-		self.app = qt.tqApp
-		self.dialog = Dialog(self.app.mainWidget(), "Dialog", 1, qt.Qt.WDestructiveClose)
+		self.app = tqt.tqApp
+		self.dialog = Dialog(self.app.mainWidget(), "Dialog", 1, tqt.TQt.WDestructiveClose)
 		self.dialog.setCaption(title)
 
-		self.widget = qt.QVBox(self.dialog)
+		self.widget = tqt.TQVBox(self.dialog)
 		self.widget.setSpacing(6)
 		self.dialog.layout.addWidget(self.widget)
 
@@ -333,15 +333,15 @@ class QtDialog:
  		self.List = List
 		self.FileChooser = FileChooser
 		self.MessageBox = MessageBox
-		
+
 	def show(self):
-		import qt
-		qt.QApplication.setOverrideCursor(qt.Qt.arrowCursor)
+		from TQt import tqt
+		tqt.TQApplication.setOverrideCursor(tqt.TQt.arrowCursor)
 		self.dialog.exec_loop()
-		qt.QApplication.restoreOverrideCursor()
+		tqt.TQApplication.restoreOverrideCursor()
 
 	def close(self):
-		print "QtDialog.close()"
+		print("TQtDialog.close()")
 		self.dialog.close()
 		#self.dialog.deleteLater()
 
@@ -352,20 +352,19 @@ class Dialog:
 		self.dialog = None
 
 		try:
-			print "Trying to import PyQt..."
-			self.dialog = QtDialog(title)
-			print "PyQt is our toolkit!"
+			print("Trying to import PyTQt...")
+			self.dialog = TQtDialog(title)
+			print("PyTQt is our toolkit!")
 		except:
 			try:
-				print "Failed to import PyQt. Trying to import TkInter..."
+				print("Failed to import PyTQt. Trying to import TkInter...")
 				self.dialog = TkDialog(title)
-				print "Falling back to TkInter as our toolkit!"
+				print("Falling back to TkInter as our toolkit!")
 			except:
-				raise "Failed to import GUI-toolkit. Please install the PyQt or the Tkinter python module."
+				raise Exception("Failed to import GUI-toolkit. Please install the PyTQt or the Tkinter python module.")
+				self.widget = self.dialog.widget
 
-                self.widget = self.dialog.widget
-
-        def show(self):
+	def show(self):
 		self.dialog.show()
 
 	def close(self):
@@ -391,6 +390,6 @@ class Dialog:
 
 	def addList(self, parentwidget, caption, items):
 		return self.dialog.List(self.dialog, parentwidget.widget, caption, items)
-		
+
 	def showMessageBox(self, typename, caption, message):
 		return self.dialog.MessageBox(self.dialog, typename, caption, message)
