@@ -38,7 +38,7 @@ Scan::Scan(TQObject *parent, const char *name, const TQStringList &)
 {
     setInstance(ScanFactory::instance());
 
-    (void) new TDEAction(i18n("&Scan Image..."), SmallIcon("scanner"), 0, this, TQT_SLOT(slotScan()), actionCollection(), "scan_image");
+    (void) new TDEAction(i18n("&Scan Image..."), SmallIcon("scanner"), 0, this, TQ_SLOT(slotScan()), actionCollection(), "scan_image");
 }
 
 Scan::~Scan()
@@ -55,8 +55,8 @@ void Scan::slotScan()
 	{
 	    scanDialog->setMinimumSize(300, 300);
 
-	    connect(scanDialog, TQT_SIGNAL(finalImage(const TQImage &, int)),
-		    this, TQT_SLOT(slotShowImage(const TQImage &)));
+	    connect(scanDialog, TQ_SIGNAL(finalImage(const TQImage &, int)),
+		    this, TQ_SLOT(slotShowImage(const TQImage &)));
 	}
 	else
         {
